# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dns/v1/dns_firewall_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dns/v1/dns_firewall_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.dns.v1 import dns_firewall_pb2 as yandex_dot_cloud_dot_dns_dot_v1_dot_dns__firewall__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/dns/v1/dns_firewall_service.proto\x12\x13yandex.cloud.dns.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/dns/v1/dns_firewall.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"6\n\x15GetDnsFirewallRequest\x12\x1d\n\x0f\x64ns_firewall_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8d\x01\n\x17ListDnsFirewallsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"l\n\x18ListDnsFirewallsResponse\x12\x37\n\rdns_firewalls\x18\x01 \x03(\x0b\x32 .yandex.cloud.dns.v1.DnsFirewall\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa9\x04\n\x18\x43reateDnsFirewallRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x39.yandex.cloud.dns.v1.CreateDnsFirewallRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x05 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12H\n\x0fresource_config\x18\x07 \x01(\x0b\x32/.yandex.cloud.dns.v1.DnsFirewall.ResourceConfig\x12/\n\x0fwhitelist_fqdns\x18\x08 \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x12/\n\x0f\x62lacklist_fqdns\x18\t \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x19\x43reateDnsFirewallMetadata\x12\x17\n\x0f\x64ns_firewall_id\x18\x01 \x01(\t\"\xda\x04\n\x18UpdateDnsFirewallRequest\x12\x1f\n\x0f\x64ns_firewall_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x39.yandex.cloud.dns.v1.UpdateDnsFirewallRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x07 \x01(\x08\x12H\n\x0fresource_config\x18\x08 \x01(\x0b\x32/.yandex.cloud.dns.v1.DnsFirewall.ResourceConfig\x12/\n\x0fwhitelist_fqdns\x18\t \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x12/\n\x0f\x62lacklist_fqdns\x18\n \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x19UpdateDnsFirewallMetadata\x12\x17\n\x0f\x64ns_firewall_id\x18\x01 \x01(\t\"j\n\x16MoveDnsFirewallRequest\x12#\n\x0f\x64ns_firewall_id\x18\x01 \x01(\tB\n\xe8\xc7\x31\x01\x8a\xc8\x31\x02\x32\x30\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"2\n\x17MoveDnsFirewallMetadata\x12\x17\n\x0f\x64ns_firewall_id\x18\x01 \x01(\t\";\n\x18\x44\x65leteDnsFirewallRequest\x12\x1f\n\x0f\x64ns_firewall_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\"4\n\x19\x44\x65leteDnsFirewallMetadata\x12\x17\n\x0f\x64ns_firewall_id\x18\x01 \x01(\t\"\x9e\x01\n ListDnsFirewallOperationsRequest\x12\x1f\n\x0f\x64ns_firewall_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"s\n!ListDnsFirewallOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xaf\x0e\n\x12\x44nsFirewallService\x12\x80\x01\n\x03Get\x12*.yandex.cloud.dns.v1.GetDnsFirewallRequest\x1a .yandex.cloud.dns.v1.DnsFirewall\"+\x82\xd3\xe4\x93\x02%\x12#/dns/v1/firewalls/{dns_firewall_id}\x12~\n\x04List\x12,.yandex.cloud.dns.v1.ListDnsFirewallsRequest\x1a-.yandex.cloud.dns.v1.ListDnsFirewallsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/dns/v1/firewalls\x12\xa4\x01\n\x06\x43reate\x12-.yandex.cloud.dns.v1.CreateDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2*(\n\x19\x43reateDnsFirewallMetadata\x12\x0b\x44nsFirewall\x82\xd3\xe4\x93\x02\x16\"\x11/dns/v1/firewalls:\x01*\x12\xb6\x01\n\x06Update\x12-.yandex.cloud.dns.v1.UpdateDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*(\n\x19UpdateDnsFirewallMetadata\x12\x0b\x44nsFirewall\x82\xd3\xe4\x93\x02(2#/dns/v1/firewalls/{dns_firewall_id}:\x01*\x12\xb5\x01\n\x04Move\x12+.yandex.cloud.dns.v1.MoveDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*&\n\x17MoveDnsFirewallMetadata\x12\x0b\x44nsFirewall\x82\xd3\xe4\x93\x02-\"(/dns/v1/firewalls/{dns_firewall_id}:move:\x01*\x12\xbd\x01\n\x06\x44\x65lete\x12-.yandex.cloud.dns.v1.DeleteDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*2\n\x19\x44\x65leteDnsFirewallMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02%*#/dns/v1/firewalls/{dns_firewall_id}\x12\xb7\x01\n\x0eListOperations\x12\x35.yandex.cloud.dns.v1.ListDnsFirewallOperationsRequest\x1a\x36.yandex.cloud.dns.v1.ListDnsFirewallOperationsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dns/v1/firewalls/{dns_firewall_id}/operations\x12\xb1\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/dns/v1/firewalls/{resource_id}:listAccessBindings\x12\xe0\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36\"1/dns/v1/firewalls/{resource_id}:setAccessBindings:\x01*\x12\xec\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39\"4/dns/v1/firewalls/{resource_id}:updateAccessBindings:\x01*BV\n\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dns.v1.dns_firewall_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dns'
  _globals['_GETDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._loaded_options = None
  _globals['_GETDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEDNSFIREWALLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['whitelist_fqdns']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['whitelist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['blacklist_fqdns']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['blacklist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_UPDATEDNSFIREWALLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._serialized_options = b'\212\3101\00220'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['whitelist_fqdns']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['whitelist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['blacklist_fqdns']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['blacklist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_MOVEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._loaded_options = None
  _globals['_MOVEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._serialized_options = b'\350\3071\001\212\3101\00220'
  _globals['_MOVEDNSFIREWALLREQUEST'].fields_by_name['destination_folder_id']._loaded_options = None
  _globals['_MOVEDNSFIREWALLREQUEST'].fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._loaded_options = None
  _globals['_DELETEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._serialized_options = b'\212\3101\00220'
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['dns_firewall_id']._loaded_options = None
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['dns_firewall_id']._serialized_options = b'\212\3101\00220'
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002%\022#/dns/v1/firewalls/{dns_firewall_id}'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/dns/v1/firewalls'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateDnsFirewallMetadata\022\013DnsFirewall\202\323\344\223\002\026\"\021/dns/v1/firewalls:\001*'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateDnsFirewallMetadata\022\013DnsFirewall\202\323\344\223\002(2#/dns/v1/firewalls/{dns_firewall_id}:\001*'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Move']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Move']._serialized_options = b'\262\322*&\n\027MoveDnsFirewallMetadata\022\013DnsFirewall\202\323\344\223\002-\"(/dns/v1/firewalls/{dns_firewall_id}:move:\001*'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteDnsFirewallMetadata\022\025google.protobuf.Empty\202\323\344\223\002%*#/dns/v1/firewalls/{dns_firewall_id}'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0020\022./dns/v1/firewalls/{dns_firewall_id}/operations'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0024\0222/dns/v1/firewalls/{resource_id}:listAccessBindings'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0026\"1/dns/v1/firewalls/{resource_id}:setAccessBindings:\001*'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0029\"4/dns/v1/firewalls/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETDNSFIREWALLREQUEST']._serialized_start=314
  _globals['_GETDNSFIREWALLREQUEST']._serialized_end=368
  _globals['_LISTDNSFIREWALLSREQUEST']._serialized_start=371
  _globals['_LISTDNSFIREWALLSREQUEST']._serialized_end=512
  _globals['_LISTDNSFIREWALLSRESPONSE']._serialized_start=514
  _globals['_LISTDNSFIREWALLSRESPONSE']._serialized_end=622
  _globals['_CREATEDNSFIREWALLREQUEST']._serialized_start=625
  _globals['_CREATEDNSFIREWALLREQUEST']._serialized_end=1178
  _globals['_CREATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_start=1133
  _globals['_CREATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_end=1178
  _globals['_CREATEDNSFIREWALLMETADATA']._serialized_start=1180
  _globals['_CREATEDNSFIREWALLMETADATA']._serialized_end=1232
  _globals['_UPDATEDNSFIREWALLREQUEST']._serialized_start=1235
  _globals['_UPDATEDNSFIREWALLREQUEST']._serialized_end=1837
  _globals['_UPDATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_start=1133
  _globals['_UPDATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_end=1178
  _globals['_UPDATEDNSFIREWALLMETADATA']._serialized_start=1839
  _globals['_UPDATEDNSFIREWALLMETADATA']._serialized_end=1891
  _globals['_MOVEDNSFIREWALLREQUEST']._serialized_start=1893
  _globals['_MOVEDNSFIREWALLREQUEST']._serialized_end=1999
  _globals['_MOVEDNSFIREWALLMETADATA']._serialized_start=2001
  _globals['_MOVEDNSFIREWALLMETADATA']._serialized_end=2051
  _globals['_DELETEDNSFIREWALLREQUEST']._serialized_start=2053
  _globals['_DELETEDNSFIREWALLREQUEST']._serialized_end=2112
  _globals['_DELETEDNSFIREWALLMETADATA']._serialized_start=2114
  _globals['_DELETEDNSFIREWALLMETADATA']._serialized_end=2166
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST']._serialized_start=2169
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST']._serialized_end=2327
  _globals['_LISTDNSFIREWALLOPERATIONSRESPONSE']._serialized_start=2329
  _globals['_LISTDNSFIREWALLOPERATIONSRESPONSE']._serialized_end=2444
  _globals['_DNSFIREWALLSERVICE']._serialized_start=2447
  _globals['_DNSFIREWALLSERVICE']._serialized_end=4286
# @@protoc_insertion_point(module_scope)
