"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2
import yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SynchronizationServiceStub:
    """A set of methods for managing synchronization settings."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    SetReplicationToken: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.SetReplicationTokenRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the replication token for synchronization."""

    ResetReplicationToken: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ResetReplicationTokenRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resets the replication token for synchronization."""

    CreateSynchronizationSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.CreateSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates synchronization settings for a subject container."""

    UpdateSynchronizationSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.UpdateSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates synchronization settings for a subject container."""

    DeleteSynchronizationSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.DeleteSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes synchronization settings for a subject container."""

    GetSynchronizationSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.GetSynchronizationSettingsRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationSettings,
    ]
    """Returns synchronization settings for a subject container."""

    ListSupportedAttributes: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesResponse,
    ]
    """Lists supported attributes for synchronization."""

class SynchronizationServiceAsyncStub:
    """A set of methods for managing synchronization settings."""

    SetReplicationToken: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.SetReplicationTokenRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the replication token for synchronization."""

    ResetReplicationToken: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ResetReplicationTokenRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resets the replication token for synchronization."""

    CreateSynchronizationSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.CreateSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates synchronization settings for a subject container."""

    UpdateSynchronizationSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.UpdateSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates synchronization settings for a subject container."""

    DeleteSynchronizationSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.DeleteSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes synchronization settings for a subject container."""

    GetSynchronizationSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.GetSynchronizationSettingsRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationSettings,
    ]
    """Returns synchronization settings for a subject container."""

    ListSupportedAttributes: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesResponse,
    ]
    """Lists supported attributes for synchronization."""

class SynchronizationServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing synchronization settings."""

    @abc.abstractmethod
    def SetReplicationToken(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.SetReplicationTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets the replication token for synchronization."""

    @abc.abstractmethod
    def ResetReplicationToken(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ResetReplicationTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Resets the replication token for synchronization."""

    @abc.abstractmethod
    def CreateSynchronizationSettings(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.CreateSynchronizationSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates synchronization settings for a subject container."""

    @abc.abstractmethod
    def UpdateSynchronizationSettings(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.UpdateSynchronizationSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates synchronization settings for a subject container."""

    @abc.abstractmethod
    def DeleteSynchronizationSettings(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.DeleteSynchronizationSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes synchronization settings for a subject container."""

    @abc.abstractmethod
    def GetSynchronizationSettings(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.GetSynchronizationSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationSettings, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationSettings]]:
        """Returns synchronization settings for a subject container."""

    @abc.abstractmethod
    def ListSupportedAttributes(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesResponse]]:
        """Lists supported attributes for synchronization."""

def add_SynchronizationServiceServicer_to_server(servicer: SynchronizationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
