# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/application/oauth/application.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/application/oauth/application.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKyandex/cloud/organizationmanager/v1/idp/application/oauth/application.proto\x12\x39yandex.cloud.organizationmanager.v1.idp.application.oauth\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xe8\x04\n\x0b\x41pplication\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12m\n\x15group_claims_settings\x18\x05 \x01(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.application.oauth.GroupClaimsSettings\x12\\\n\x0c\x63lient_grant\x18\x06 \x01(\x0b\x32\x46.yandex.cloud.organizationmanager.v1.idp.application.oauth.ClientGrant\x12Q\n\x06status\x18\x07 \x01(\x0e\x32\x41.yandex.cloud.organizationmanager.v1.idp.application.oauth.Status\x12\x62\n\x06labels\x18\x08 \x03(\x0b\x32R.yandex.cloud.organizationmanager.v1.idp.application.oauth.Application.LabelsEntry\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n\x13GroupClaimsSettings\x12q\n\x17group_distribution_type\x18\x01 \x01(\x0e\x32P.yandex.cloud.organizationmanager.v1.idp.application.oauth.GroupDistributionType\"^\n\x0b\x43lientGrant\x12\x1f\n\tclient_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x11\x61uthorized_scopes\x18\x02 \x03(\tB\x13\x82\xc8\x31\x06\x31-1000\x8a\xc8\x31\x05<=255*W\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\r\n\tSUSPENDED\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04*o\n\x15GroupDistributionType\x12\'\n#GROUP_DISTRIBUTION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x13\n\x0f\x41SSIGNED_GROUPS\x10\x02\x12\x0e\n\nALL_GROUPS\x10\x03\x42\xa4\x01\n=yandex.cloud.api.organizationmanager.v1.idp.application.oauthZcgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/oauth;oauthb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n=yandex.cloud.api.organizationmanager.v1.idp.application.oauthZcgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/oauth;oauth'
  _globals['_APPLICATION_LABELSENTRY']._loaded_options = None
  _globals['_APPLICATION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLIENTGRANT'].fields_by_name['client_id']._loaded_options = None
  _globals['_CLIENTGRANT'].fields_by_name['client_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CLIENTGRANT'].fields_by_name['authorized_scopes']._loaded_options = None
  _globals['_CLIENTGRANT'].fields_by_name['authorized_scopes']._serialized_options = b'\202\3101\0061-1000\212\3101\005<=255'
  _globals['_STATUS']._serialized_start=1056
  _globals['_STATUS']._serialized_end=1143
  _globals['_GROUPDISTRIBUTIONTYPE']._serialized_start=1145
  _globals['_GROUPDISTRIBUTIONTYPE']._serialized_end=1256
  _globals['_APPLICATION']._serialized_start=203
  _globals['_APPLICATION']._serialized_end=819
  _globals['_APPLICATION_LABELSENTRY']._serialized_start=774
  _globals['_APPLICATION_LABELSENTRY']._serialized_end=819
  _globals['_GROUPCLAIMSSETTINGS']._serialized_start=822
  _globals['_GROUPCLAIMSSETTINGS']._serialized_end=958
  _globals['_CLIENTGRANT']._serialized_start=960
  _globals['_CLIENTGRANT']._serialized_end=1054
# @@protoc_insertion_point(module_scope)
