# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/usage_records/v1/metadata_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/usage_records/v1/metadata_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.billing.usage_records.v1 import billing_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_billing__types__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/billing/usage_records/v1/metadata_service.proto\x12%yandex.cloud.billing.usage_records.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x39yandex/cloud/billing/usage_records/v1/billing_types.proto\x1a\x1dyandex/cloud/validation.proto\"\x9d\x01\n\x0fGetUsageRequest\x12 \n\x12\x62illing_account_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\nstart_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\"\xb1\x02\n\x10GetUsageResponse\x12<\n\x06\x63louds\x18\x01 \x03(\x0b\x32,.yandex.cloud.billing.usage_records.v1.Cloud\x12\x12\n\nlabel_keys\x18\x02 \x03(\t\x12@\n\x08services\x18\x03 \x03(\x0b\x32..yandex.cloud.billing.usage_records.v1.Service\x12\x38\n\x04skus\x18\x04 \x03(\x0b\x32*.yandex.cloud.billing.usage_records.v1.SKU\x12O\n\x10\x62illing_accounts\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.billing.usage_records.v1.BillingAccount\"\x8e\x02\n\x0fGetLabelRequest\x12 \n\x12\x62illing_account_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\nstart_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x17\n\tlabel_key\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0blabel_value\x18\x05 \x01(\t\x12\x1a\n\x12label_value_filter\x18\x06 \x03(\t\x12\x11\n\tpage_size\x18\x07 \x01(\x03\x12\x12\n\npage_token\x18\x08 \x01(\t\"]\n\x10GetLabelResponse\x12\x14\n\x0clabel_values\x18\x01 \x03(\t\x12\x1a\n\x12label_value_filter\x18\x02 \x03(\t\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\xeb\x01\n\x0fGetCloudRequest\x12 \n\x12\x62illing_account_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\nstart_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x11\n\tcloud_ids\x18\x04 \x03(\t\x12\x12\n\nfolder_ids\x18\x05 \x03(\t\x12\x11\n\tpage_size\x18\x06 \x01(\x03\x12\x12\n\npage_token\x18\x07 \x01(\t\"\x88\x02\n\x10GetCloudResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.yandex.cloud.billing.usage_records.v1.GetCloudResponse.CloudInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\x88\x01\n\tCloudInfo\x12;\n\x05\x63loud\x18\x01 \x01(\x0b\x32,.yandex.cloud.billing.usage_records.v1.Cloud\x12>\n\x07\x66olders\x18\x02 \x03(\x0b\x32-.yandex.cloud.billing.usage_records.v1.Folder\"\xdf\x01\n\x15GetResourceIDsRequest\x12 \n\x12\x62illing_account_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\nstart_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x03\x12\x12\n\npage_token\x18\x06 \x01(\t\"G\n\x16GetResourceIDsResponse\x12\x14\n\x0cresource_ids\x18\x01 \x03(\t\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x98\x04\n\x0fMetadataService\x12{\n\x08GetUsage\x12\x36.yandex.cloud.billing.usage_records.v1.GetUsageRequest\x1a\x37.yandex.cloud.billing.usage_records.v1.GetUsageResponse\x12{\n\x08GetLabel\x12\x36.yandex.cloud.billing.usage_records.v1.GetLabelRequest\x1a\x37.yandex.cloud.billing.usage_records.v1.GetLabelResponse\x12{\n\x08GetCloud\x12\x36.yandex.cloud.billing.usage_records.v1.GetCloudRequest\x1a\x37.yandex.cloud.billing.usage_records.v1.GetCloudResponse\x12\x8d\x01\n\x0eGetResourceIDs\x12<.yandex.cloud.billing.usage_records.v1.GetResourceIDsRequest\x1a=.yandex.cloud.billing.usage_records.v1.GetResourceIDsResponseB\x83\x01\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecordsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.usage_records.v1.metadata_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecords'
  _globals['_GETUSAGEREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_GETUSAGEREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001'
  _globals['_GETUSAGEREQUEST'].fields_by_name['start_date']._loaded_options = None
  _globals['_GETUSAGEREQUEST'].fields_by_name['start_date']._serialized_options = b'\350\3071\001'
  _globals['_GETUSAGEREQUEST'].fields_by_name['end_date']._loaded_options = None
  _globals['_GETUSAGEREQUEST'].fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _globals['_GETLABELREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_GETLABELREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001'
  _globals['_GETLABELREQUEST'].fields_by_name['start_date']._loaded_options = None
  _globals['_GETLABELREQUEST'].fields_by_name['start_date']._serialized_options = b'\350\3071\001'
  _globals['_GETLABELREQUEST'].fields_by_name['end_date']._loaded_options = None
  _globals['_GETLABELREQUEST'].fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _globals['_GETLABELREQUEST'].fields_by_name['label_key']._loaded_options = None
  _globals['_GETLABELREQUEST'].fields_by_name['label_key']._serialized_options = b'\350\3071\001'
  _globals['_GETCLOUDREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_GETCLOUDREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001'
  _globals['_GETCLOUDREQUEST'].fields_by_name['start_date']._loaded_options = None
  _globals['_GETCLOUDREQUEST'].fields_by_name['start_date']._serialized_options = b'\350\3071\001'
  _globals['_GETCLOUDREQUEST'].fields_by_name['end_date']._loaded_options = None
  _globals['_GETCLOUDREQUEST'].fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001'
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['start_date']._loaded_options = None
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['start_date']._serialized_options = b'\350\3071\001'
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['end_date']._loaded_options = None
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _globals['_GETUSAGEREQUEST']._serialized_start=227
  _globals['_GETUSAGEREQUEST']._serialized_end=384
  _globals['_GETUSAGERESPONSE']._serialized_start=387
  _globals['_GETUSAGERESPONSE']._serialized_end=692
  _globals['_GETLABELREQUEST']._serialized_start=695
  _globals['_GETLABELREQUEST']._serialized_end=965
  _globals['_GETLABELRESPONSE']._serialized_start=967
  _globals['_GETLABELRESPONSE']._serialized_end=1060
  _globals['_GETCLOUDREQUEST']._serialized_start=1063
  _globals['_GETCLOUDREQUEST']._serialized_end=1298
  _globals['_GETCLOUDRESPONSE']._serialized_start=1301
  _globals['_GETCLOUDRESPONSE']._serialized_end=1565
  _globals['_GETCLOUDRESPONSE_CLOUDINFO']._serialized_start=1429
  _globals['_GETCLOUDRESPONSE_CLOUDINFO']._serialized_end=1565
  _globals['_GETRESOURCEIDSREQUEST']._serialized_start=1568
  _globals['_GETRESOURCEIDSREQUEST']._serialized_end=1791
  _globals['_GETRESOURCEIDSRESPONSE']._serialized_start=1793
  _globals['_GETRESOURCEIDSRESPONSE']._serialized_end=1864
  _globals['_METADATASERVICE']._serialized_start=1867
  _globals['_METADATASERVICE']._serialized_end=2403
# @@protoc_insertion_point(module_scope)
