# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/mcpgateway/v1/mcp_gateway_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/mcpgateway/v1/mcp_gateway_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.serverless.mcpgateway.v1 import mcp_gateway_pb2 as yandex_dot_cloud_dot_serverless_dot_mcpgateway_dot_v1_dot_mcp__gateway__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?yandex/cloud/serverless/mcpgateway/v1/mcp_gateway_service.proto\x12%yandex.cloud.serverless.mcpgateway.v1\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\x37yandex/cloud/serverless/mcpgateway/v1/mcp_gateway.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"4\n\x14GetMcpGatewayRequest\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"g\n\x15ListMcpGatewayRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"}\n\x16ListMcpGatewayResponse\x12J\n\x08gateways\x18\x01 \x03(\x0b\x32\x38.yandex.cloud.serverless.mcpgateway.v1.McpGatewayPreview\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xad\x04\n\x17\x43reateMcpGatewayRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12?\n\x04name\x18\x02 \x01(\tB1\xe8\xc7\x31\x01\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x8a\xc8\x31\x05<=128\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tB\x0b\x8a\xc8\x31\x07<=65536\x12\x9f\x01\n\x06labels\x18\x04 \x03(\x0b\x32J.yandex.cloud.serverless.mcpgateway.v1.CreateMcpGatewayRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12=\n\x05tools\x18\x05 \x03(\x0b\x32..yandex.cloud.serverless.mcpgateway.v1.McpTool\x12\x46\n\x0blog_options\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.serverless.mcpgateway.v1.LogOptions\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12\x12\n\nnetwork_id\x18\x08 \x01(\t\x12\x0e\n\x06public\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x18\x43reateMcpGatewayMetadata\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tfolder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"\xdf\x04\n\x17UpdateMcpGatewayRequest\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12;\n\x04name\x18\x02 \x01(\tB-\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x8a\xc8\x31\x05<=128\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tB\x0b\x8a\xc8\x31\x07<=65536\x12\x9f\x01\n\x06labels\x18\x04 \x03(\x0b\x32J.yandex.cloud.serverless.mcpgateway.v1.UpdateMcpGatewayRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12=\n\x05tools\x18\x05 \x03(\x0b\x32..yandex.cloud.serverless.mcpgateway.v1.McpTool\x12\x46\n\x0blog_options\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.serverless.mcpgateway.v1.LogOptions\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12\x12\n\nnetwork_id\x18\x08 \x01(\t\x12/\n\x0bupdate_mask\x18\t \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0e\n\x06public\x18\n \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x18UpdateMcpGatewayMetadata\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tfolder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"7\n\x17\x44\x65leteMcpGatewayRequest\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"8\n\x18\x44\x65leteMcpGatewayMetadata\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8f\x01\n\x15ListOperationsRequest\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"h\n\x16ListOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xc4\x0e\n\x11McpGatewayService\x12\xaa\x01\n\x03Get\x12;.yandex.cloud.serverless.mcpgateway.v1.GetMcpGatewayRequest\x1a\x31.yandex.cloud.serverless.mcpgateway.v1.McpGateway\"3\x82\xd3\xe4\x93\x02-\x12+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}\x12\xa7\x01\n\x04List\x12<.yandex.cloud.serverless.mcpgateway.v1.ListMcpGatewayRequest\x1a=.yandex.cloud.serverless.mcpgateway.v1.ListMcpGatewayResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/mcpgateway/v1/mcpGateways\x12\xbc\x01\n\x06\x43reate\x12>.yandex.cloud.serverless.mcpgateway.v1.CreateMcpGatewayRequest\x1a!.yandex.cloud.operation.Operation\"O\xb2\xd2*&\n\x18\x43reateMcpGatewayMetadata\x12\nMcpGateway\x82\xd3\xe4\x93\x02\x1f\"\x1a/mcpgateway/v1/mcpGateways:\x01*\x12\xcd\x01\n\x06Update\x12>.yandex.cloud.serverless.mcpgateway.v1.UpdateMcpGatewayRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*&\n\x18UpdateMcpGatewayMetadata\x12\nMcpGateway\x82\xd3\xe4\x93\x02\x30\x32+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}:\x01*\x12\xd5\x01\n\x06\x44\x65lete\x12>.yandex.cloud.serverless.mcpgateway.v1.DeleteMcpGatewayRequest\x1a!.yandex.cloud.operation.Operation\"h\xb2\xd2*1\n\x18\x44\x65leteMcpGatewayMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02-*+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}\x12\xcd\x01\n\x0eListOperations\x12<.yandex.cloud.serverless.mcpgateway.v1.ListOperationsRequest\x1a=.yandex.cloud.serverless.mcpgateway.v1.ListOperationsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/mcpgateway/v1/mcpGateways/{mcp_gateway_id}/operations\x12\xba\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/mcpgateway/v1/mcpGateways/{resource_id}:listAccessBindings\x12\xea\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?\":/mcpgateway/v1/mcpGateways/{resource_id}:setAccessBindings:\x01*\x12\xf6\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42\x32=/mcpgateway/v1/mcpGateways/{resource_id}:updateAccessBindings:\x01*B\x81\x01\n)yandex.cloud.api.serverless.mcpgateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mcpgateway/v1;mcpgatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.mcpgateway.v1.mcp_gateway_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.serverless.mcpgateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mcpgateway/v1;mcpgateway'
  _globals['_GETMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_GETMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTMCPGATEWAYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTMCPGATEWAYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEMCPGATEWAYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\212\3101\005<=128'
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\007<=65536'
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_CREATEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEMCPGATEWAYMETADATA'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEMCPGATEWAYMETADATA'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEMCPGATEWAYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\212\3101\005<=128'
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\007<=65536'
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_UPDATEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEMCPGATEWAYMETADATA'].fields_by_name['folder_id']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYMETADATA'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_DELETEMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_DELETEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002-\022+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/mcpgateway/v1/mcpGateways'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateMcpGatewayMetadata\022\nMcpGateway\202\323\344\223\002\037\"\032/mcpgateway/v1/mcpGateways:\001*'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateMcpGatewayMetadata\022\nMcpGateway\202\323\344\223\00202+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}:\001*'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteMcpGatewayMetadata\022\025google.protobuf.Empty\202\323\344\223\002-*+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0028\0226/mcpgateway/v1/mcpGateways/{mcp_gateway_id}/operations'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002=\022;/mcpgateway/v1/mcpGateways/{resource_id}:listAccessBindings'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002?\":/mcpgateway/v1/mcpGateways/{resource_id}:setAccessBindings:\001*'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002B2=/mcpgateway/v1/mcpGateways/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETMCPGATEWAYREQUEST']._serialized_start=366
  _globals['_GETMCPGATEWAYREQUEST']._serialized_end=418
  _globals['_LISTMCPGATEWAYREQUEST']._serialized_start=420
  _globals['_LISTMCPGATEWAYREQUEST']._serialized_end=523
  _globals['_LISTMCPGATEWAYRESPONSE']._serialized_start=525
  _globals['_LISTMCPGATEWAYRESPONSE']._serialized_end=650
  _globals['_CREATEMCPGATEWAYREQUEST']._serialized_start=653
  _globals['_CREATEMCPGATEWAYREQUEST']._serialized_end=1210
  _globals['_CREATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_start=1165
  _globals['_CREATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_end=1210
  _globals['_CREATEMCPGATEWAYMETADATA']._serialized_start=1212
  _globals['_CREATEMCPGATEWAYMETADATA']._serialized_end=1293
  _globals['_UPDATEMCPGATEWAYREQUEST']._serialized_start=1296
  _globals['_UPDATEMCPGATEWAYREQUEST']._serialized_end=1903
  _globals['_UPDATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_start=1165
  _globals['_UPDATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_end=1210
  _globals['_UPDATEMCPGATEWAYMETADATA']._serialized_start=1905
  _globals['_UPDATEMCPGATEWAYMETADATA']._serialized_end=1986
  _globals['_DELETEMCPGATEWAYREQUEST']._serialized_start=1988
  _globals['_DELETEMCPGATEWAYREQUEST']._serialized_end=2043
  _globals['_DELETEMCPGATEWAYMETADATA']._serialized_start=2045
  _globals['_DELETEMCPGATEWAYMETADATA']._serialized_end=2101
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=2104
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=2247
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=2249
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=2353
  _globals['_MCPGATEWAYSERVICE']._serialized_start=2356
  _globals['_MCPGATEWAYSERVICE']._serialized_end=4216
# @@protoc_insertion_point(module_scope)
