"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.mdb.mysql.v1.deletion_protection_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Database(google.protobuf.message.Message):
    """An object that represents MySQL database.

    See [the documentation](/docs/managed-mysql/operations/databases) for details.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_MODE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the database."""
    cluster_id: builtins.str
    """ID of the cluster that the database belongs to."""
    deletion_protection_mode: yandex.cloud.mdb.mysql.v1.deletion_protection_pb2.DeletionProtectionMode.ValueType
    """Deletion Protection inhibits deletion of the database

    Default value: `DELETION_PROTECTION_MODE_DISABLED` (protection is disabled)
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        deletion_protection_mode: yandex.cloud.mdb.mysql.v1.deletion_protection_pb2.DeletionProtectionMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "deletion_protection_mode", b"deletion_protection_mode", "name", b"name"]) -> None: ...

global___Database = Database

@typing.final
class DatabaseSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_MODE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the database."""
    deletion_protection_mode: yandex.cloud.mdb.mysql.v1.deletion_protection_pb2.DeletionProtectionMode.ValueType
    """Deletion Protection inhibits deletion of the database

    Default value: `DELETION_PROTECTION_MODE_DISABLED` (protection is disabled)
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        deletion_protection_mode: yandex.cloud.mdb.mysql.v1.deletion_protection_pb2.DeletionProtectionMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection_mode", b"deletion_protection_mode", "name", b"name"]) -> None: ...

global___DatabaseSpec = DatabaseSpec
