# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dns/v1/dns_firewall.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dns/v1/dns_firewall.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/dns/v1/dns_firewall.proto\x12\x13yandex.cloud.dns.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc5\x05\n\x0b\x44nsFirewall\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12<\n\x06labels\x18\x06 \x03(\x0b\x32,.yandex.cloud.dns.v1.DnsFirewall.LabelsEntry\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x08 \x01(\x08\x12H\n\x0fresource_config\x18\t \x01(\x0b\x32/.yandex.cloud.dns.v1.DnsFirewall.ResourceConfig\x12/\n\x0fwhitelist_fqdns\x18\n \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x12/\n\x0f\x62lacklist_fqdns\x18\x0b \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xfc\x01\n\x0eResourceConfig\x12J\n\x04type\x18\x01 \x01(\x0e\x32<.yandex.cloud.dns.v1.DnsFirewall.ResourceConfig.ResourceType\x12+\n\x0cresource_ids\x18\x02 \x03(\tB\x15\x82\xc8\x31\x05\x30-100\x8a\xc8\x31\x04<=64\x90\xc8\x31\x01\x12\x1e\n\x16locking_policy_enabled\x18\x03 \x01(\x08\"Q\n\x0cResourceType\x12\x1d\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07NETWORK\x10\x01\x12\n\n\x06\x46OLDER\x10\x02\x12\t\n\x05\x43LOUD\x10\x03\x42V\n\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dns.v1.dns_firewall_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dns'
  _globals['_DNSFIREWALL_LABELSENTRY']._loaded_options = None
  _globals['_DNSFIREWALL_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_DNSFIREWALL_RESOURCECONFIG'].fields_by_name['resource_ids']._loaded_options = None
  _globals['_DNSFIREWALL_RESOURCECONFIG'].fields_by_name['resource_ids']._serialized_options = b'\202\3101\0050-100\212\3101\004<=64\220\3101\001'
  _globals['_DNSFIREWALL'].fields_by_name['whitelist_fqdns']._loaded_options = None
  _globals['_DNSFIREWALL'].fields_by_name['whitelist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_DNSFIREWALL'].fields_by_name['blacklist_fqdns']._loaded_options = None
  _globals['_DNSFIREWALL'].fields_by_name['blacklist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_DNSFIREWALL']._serialized_start=128
  _globals['_DNSFIREWALL']._serialized_end=837
  _globals['_DNSFIREWALL_LABELSENTRY']._serialized_start=537
  _globals['_DNSFIREWALL_LABELSENTRY']._serialized_end=582
  _globals['_DNSFIREWALL_RESOURCECONFIG']._serialized_start=585
  _globals['_DNSFIREWALL_RESOURCECONFIG']._serialized_end=837
  _globals['_DNSFIREWALL_RESOURCECONFIG_RESOURCETYPE']._serialized_start=756
  _globals['_DNSFIREWALL_RESOURCECONFIG_RESOURCETYPE']._serialized_end=837
# @@protoc_insertion_point(module_scope)
