# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/synchronization_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/synchronization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp import synchronization_settings_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__settings__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEyandex/cloud/organizationmanager/v1/idp/synchronization_service.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x46yandex/cloud/organizationmanager/v1/idp/synchronization_settings.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\"\x8a\x05\n$CreateSynchronizationSettingsRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12T\n\x06\x66ilter\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.SynchronizationFilterB\x04\xe8\xc7\x31\x01\x12%\n\x12replacement_domain\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05\x30-253\x12Y\n\x14remove_user_behavior\x18\x04 \x01(\x0e\x32;.yandex.cloud.organizationmanager.v1.idp.RemoveUserBehavior\x12G\n\x18synchronization_interval\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31\x35m-6h\x12\x1e\n\x16\x61llow_to_capture_users\x18\x06 \x01(\x08\x12\x1f\n\x17\x61llow_to_capture_groups\x18\x07 \x01(\x08\x12h\n\x17user_attribute_mappings\x18\x08 \x03(\x0b\x32=.yandex.cloud.organizationmanager.v1.idp.UserAttributeMappingB\x08\x82\xc8\x31\x04<=50\x12j\n\x18group_attribute_mappings\x18\t \x03(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.GroupAttributeMappingB\x08\x82\xc8\x31\x04<=50\"E\n%CreateSynchronizationSettingsMetadata\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t\"\xb5\x05\n$UpdateSynchronizationSettingsRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12N\n\x06\x66ilter\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.SynchronizationFilter\x12%\n\x12replacement_domain\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05\x30-253\x12Y\n\x14remove_user_behavior\x18\x04 \x01(\x0e\x32;.yandex.cloud.organizationmanager.v1.idp.RemoveUserBehavior\x12G\n\x18synchronization_interval\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31\x35m-6h\x12\x1e\n\x16\x61llow_to_capture_users\x18\x06 \x01(\x08\x12\x1f\n\x17\x61llow_to_capture_groups\x18\x07 \x01(\x08\x12h\n\x17user_attribute_mappings\x18\x08 \x03(\x0b\x32=.yandex.cloud.organizationmanager.v1.idp.UserAttributeMappingB\x08\x82\xc8\x31\x04<=50\x12j\n\x18group_attribute_mappings\x18\t \x03(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.GroupAttributeMappingB\x08\x82\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\n \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"E\n%UpdateSynchronizationSettingsMetadata\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t\"R\n$DeleteSynchronizationSettingsRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"E\n%DeleteSynchronizationSettingsMetadata\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t\"O\n!GetSynchronizationSettingsRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"q\n\x1eListSupportedAttributesRequest\x12O\n\x06\x66lavor\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.organizationmanager.v1.idp.AttributesFlavorB\x04\xe8\xc7\x31\x01\"\xeb\x01\n\x1fListSupportedAttributesResponse\x12\x62\n\x19user_supported_attributes\x18\x01 \x03(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.UserSupportedAttribute\x12\x64\n\x1agroup_supported_attributes\x18\x02 \x03(\x0b\x32@.yandex.cloud.organizationmanager.v1.idp.GroupSupportedAttribute\"\xc6\x01\n\x16UserSupportedAttribute\x12V\n\x10target_attribute\x18\x01 \x01(\x0e\x32<.yandex.cloud.organizationmanager.v1.idp.UserTargetAttribute\x12T\n\x11source_attributes\x18\x02 \x03(\x0b\x32\x39.yandex.cloud.organizationmanager.v1.idp.SourceAttributes\"\xc8\x01\n\x17GroupSupportedAttribute\x12W\n\x10target_attribute\x18\x01 \x01(\x0e\x32=.yandex.cloud.organizationmanager.v1.idp.GroupTargetAttribute\x12T\n\x11source_attributes\x18\x02 \x03(\x0b\x32\x39.yandex.cloud.organizationmanager.v1.idp.SourceAttributes\"j\n\x10SourceAttributes\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.MappingType\x12\x12\n\nattributes\x18\x02 \x03(\t\"\xc5\x01\n\x1aSetReplicationTokenRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x11replication_token\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1000\x12P\n\x0csession_type\x18\x03 \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.SessionTypeB\x04\xe8\xc7\x31\x01\";\n\x1bSetReplicationTokenMetadata\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t\"J\n\x1cResetReplicationTokenRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"=\n\x1dResetReplicationTokenMetadata\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t*K\n\x10\x41ttributesFlavor\x12!\n\x1d\x41TTRIBUTES_FLAVOR_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41\x43TIVE_DIRECTORY\x10\x01\x32\xb5\x0f\n\x16SynchronizationService\x12\x8c\x02\n\x13SetReplicationToken\x12\x43.yandex.cloud.organizationmanager.v1.idp.SetReplicationTokenRequest\x1a!.yandex.cloud.operation.Operation\"\x8c\x01\xb2\xd2*4\n\x1bSetReplicationTokenMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02N\"I/organization-manager/v1/idp/synchronization-settings:setReplicationToken:\x01*\x12\x94\x02\n\x15ResetReplicationToken\x12\x45.yandex.cloud.organizationmanager.v1.idp.ResetReplicationTokenRequest\x1a!.yandex.cloud.operation.Operation\"\x90\x01\xb2\xd2*6\n\x1dResetReplicationTokenMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02P\"K/organization-manager/v1/idp/synchronization-settings:resetReplicationToken:\x01*\x12\x98\x02\n\x1d\x43reateSynchronizationSettings\x12M.yandex.cloud.organizationmanager.v1.idp.CreateSynchronizationSettingsRequest\x1a!.yandex.cloud.operation.Operation\"\x84\x01\xb2\xd2*@\n%CreateSynchronizationSettingsMetadata\x12\x17SynchronizationSettings\x82\xd3\xe4\x93\x02:\"5/organization-manager/v1/idp/synchronization-settings:\x01*\x12\xaf\x02\n\x1dUpdateSynchronizationSettings\x12M.yandex.cloud.organizationmanager.v1.idp.UpdateSynchronizationSettingsRequest\x1a!.yandex.cloud.operation.Operation\"\x9b\x01\xb2\xd2*@\n%UpdateSynchronizationSettingsMetadata\x12\x17SynchronizationSettings\x82\xd3\xe4\x93\x02Q2L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}:\x01*\x12\xaa\x02\n\x1d\x44\x65leteSynchronizationSettings\x12M.yandex.cloud.organizationmanager.v1.idp.DeleteSynchronizationSettingsRequest\x1a!.yandex.cloud.operation.Operation\"\x96\x01\xb2\xd2*>\n%DeleteSynchronizationSettingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02N*L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}\x12\x80\x02\n\x1aGetSynchronizationSettings\x12J.yandex.cloud.organizationmanager.v1.idp.GetSynchronizationSettingsRequest\x1a@.yandex.cloud.organizationmanager.v1.idp.SynchronizationSettings\"T\x82\xd3\xe4\x93\x02N\x12L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}\x12\xf7\x01\n\x17ListSupportedAttributes\x12G.yandex.cloud.organizationmanager.v1.idp.ListSupportedAttributesRequest\x1aH.yandex.cloud.organizationmanager.v1.idp.ListSupportedAttributesResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/organization-manager/v1/idp/synchronization-supported-attributesB~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['filter']._serialized_options = b'\350\3071\001'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['replacement_domain']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['replacement_domain']._serialized_options = b'\212\3101\0050-253'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['synchronization_interval']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['synchronization_interval']._serialized_options = b'\372\3071\00615m-6h'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['user_attribute_mappings']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['user_attribute_mappings']._serialized_options = b'\202\3101\004<=50'
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['group_attribute_mappings']._loaded_options = None
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['group_attribute_mappings']._serialized_options = b'\202\3101\004<=50'
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['replacement_domain']._loaded_options = None
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['replacement_domain']._serialized_options = b'\212\3101\0050-253'
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['synchronization_interval']._loaded_options = None
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['synchronization_interval']._serialized_options = b'\372\3071\00615m-6h'
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['user_attribute_mappings']._loaded_options = None
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['user_attribute_mappings']._serialized_options = b'\202\3101\004<=50'
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['group_attribute_mappings']._loaded_options = None
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['group_attribute_mappings']._serialized_options = b'\202\3101\004<=50'
  _globals['_DELETESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_DELETESYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETSYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_GETSYNCHRONIZATIONSETTINGSREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSUPPORTEDATTRIBUTESREQUEST'].fields_by_name['flavor']._loaded_options = None
  _globals['_LISTSUPPORTEDATTRIBUTESREQUEST'].fields_by_name['flavor']._serialized_options = b'\350\3071\001'
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['replication_token']._loaded_options = None
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['replication_token']._serialized_options = b'\350\3071\001\212\3101\006<=1000'
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['session_type']._loaded_options = None
  _globals['_SETREPLICATIONTOKENREQUEST'].fields_by_name['session_type']._serialized_options = b'\350\3071\001'
  _globals['_RESETREPLICATIONTOKENREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_RESETREPLICATIONTOKENREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['SetReplicationToken']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['SetReplicationToken']._serialized_options = b'\262\322*4\n\033SetReplicationTokenMetadata\022\025google.protobuf.Empty\202\323\344\223\002N\"I/organization-manager/v1/idp/synchronization-settings:setReplicationToken:\001*'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['ResetReplicationToken']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['ResetReplicationToken']._serialized_options = b'\262\322*6\n\035ResetReplicationTokenMetadata\022\025google.protobuf.Empty\202\323\344\223\002P\"K/organization-manager/v1/idp/synchronization-settings:resetReplicationToken:\001*'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['CreateSynchronizationSettings']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['CreateSynchronizationSettings']._serialized_options = b'\262\322*@\n%CreateSynchronizationSettingsMetadata\022\027SynchronizationSettings\202\323\344\223\002:\"5/organization-manager/v1/idp/synchronization-settings:\001*'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['UpdateSynchronizationSettings']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['UpdateSynchronizationSettings']._serialized_options = b'\262\322*@\n%UpdateSynchronizationSettingsMetadata\022\027SynchronizationSettings\202\323\344\223\002Q2L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}:\001*'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['DeleteSynchronizationSettings']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['DeleteSynchronizationSettings']._serialized_options = b'\262\322*>\n%DeleteSynchronizationSettingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002N*L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['GetSynchronizationSettings']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['GetSynchronizationSettings']._serialized_options = b'\202\323\344\223\002N\022L/organization-manager/v1/idp/synchronization-settings/{subject_container_id}'
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['ListSupportedAttributes']._loaded_options = None
  _globals['_SYNCHRONIZATIONSERVICE'].methods_by_name['ListSupportedAttributes']._serialized_options = b'\202\323\344\223\002C\022A/organization-manager/v1/idp/synchronization-supported-attributes'
  _globals['_ATTRIBUTESFLAVOR']._serialized_start=3379
  _globals['_ATTRIBUTESFLAVOR']._serialized_end=3454
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST']._serialized_start=388
  _globals['_CREATESYNCHRONIZATIONSETTINGSREQUEST']._serialized_end=1038
  _globals['_CREATESYNCHRONIZATIONSETTINGSMETADATA']._serialized_start=1040
  _globals['_CREATESYNCHRONIZATIONSETTINGSMETADATA']._serialized_end=1109
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST']._serialized_start=1112
  _globals['_UPDATESYNCHRONIZATIONSETTINGSREQUEST']._serialized_end=1805
  _globals['_UPDATESYNCHRONIZATIONSETTINGSMETADATA']._serialized_start=1807
  _globals['_UPDATESYNCHRONIZATIONSETTINGSMETADATA']._serialized_end=1876
  _globals['_DELETESYNCHRONIZATIONSETTINGSREQUEST']._serialized_start=1878
  _globals['_DELETESYNCHRONIZATIONSETTINGSREQUEST']._serialized_end=1960
  _globals['_DELETESYNCHRONIZATIONSETTINGSMETADATA']._serialized_start=1962
  _globals['_DELETESYNCHRONIZATIONSETTINGSMETADATA']._serialized_end=2031
  _globals['_GETSYNCHRONIZATIONSETTINGSREQUEST']._serialized_start=2033
  _globals['_GETSYNCHRONIZATIONSETTINGSREQUEST']._serialized_end=2112
  _globals['_LISTSUPPORTEDATTRIBUTESREQUEST']._serialized_start=2114
  _globals['_LISTSUPPORTEDATTRIBUTESREQUEST']._serialized_end=2227
  _globals['_LISTSUPPORTEDATTRIBUTESRESPONSE']._serialized_start=2230
  _globals['_LISTSUPPORTEDATTRIBUTESRESPONSE']._serialized_end=2465
  _globals['_USERSUPPORTEDATTRIBUTE']._serialized_start=2468
  _globals['_USERSUPPORTEDATTRIBUTE']._serialized_end=2666
  _globals['_GROUPSUPPORTEDATTRIBUTE']._serialized_start=2669
  _globals['_GROUPSUPPORTEDATTRIBUTE']._serialized_end=2869
  _globals['_SOURCEATTRIBUTES']._serialized_start=2871
  _globals['_SOURCEATTRIBUTES']._serialized_end=2977
  _globals['_SETREPLICATIONTOKENREQUEST']._serialized_start=2980
  _globals['_SETREPLICATIONTOKENREQUEST']._serialized_end=3177
  _globals['_SETREPLICATIONTOKENMETADATA']._serialized_start=3179
  _globals['_SETREPLICATIONTOKENMETADATA']._serialized_end=3238
  _globals['_RESETREPLICATIONTOKENREQUEST']._serialized_start=3240
  _globals['_RESETREPLICATIONTOKENREQUEST']._serialized_end=3314
  _globals['_RESETREPLICATIONTOKENMETADATA']._serialized_start=3316
  _globals['_RESETREPLICATIONTOKENMETADATA']._serialized_end=3377
  _globals['_SYNCHRONIZATIONSERVICE']._serialized_start=3457
  _globals['_SYNCHRONIZATIONSERVICE']._serialized_end=5430
# @@protoc_insertion_point(module_scope)
