# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/stacklandlicenseapi/v1/sync.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/stacklandlicenseapi/v1/sync.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/marketplace/stacklandlicenseapi/v1/sync.proto\x12/yandex.cloud.marketplace.stacklandlicenseapi.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xf4\x03\n\nUsageEntry\x12&\n\x0finstallation_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12R\n\x0cproduct_type\x18\x02 \x01(\x0e\x32<.yandex.cloud.marketplace.stacklandlicenseapi.v1.ProductType\x12\x1b\n\x04type\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12\r\n\x05usage\x18\x04 \x01(\x03\x12\x33\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\'\n\x14hardware_fingerprint\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=500\x12!\n\nlicense_id\x18\x07 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12\x17\n\x0frequested_value\x18\x08 \x01(\x03\x12:\n\x10server_timestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12$\n\x10prev_record_hash\x18\n \x01(\tB\n\xe8\xc7\x31\x01\x8a\xc8\x31\x02\x36\x34\x12\x1f\n\x0brecord_hash\x18\x0b \x01(\tB\n\xe8\xc7\x31\x01\x8a\xc8\x31\x02\x36\x34\x12!\n\tsignature\x18\x0c \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1000\"+\n\x0cLicenseLimit\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x03\"\xe8\x02\n\x07License\x12\x12\n\nlicense_id\x18\x01 \x01(\t\x12R\n\x0cproduct_type\x18\x02 \x01(\x0e\x32<.yandex.cloud.marketplace.stacklandlicenseapi.v1.ProductType\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\x12\x1a\n\x12\x62illing_account_id\x18\x04 \x01(\t\x12-\n\tissued_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bvalid_until\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12M\n\x06limits\x18\x07 \x03(\x0b\x32=.yandex.cloud.marketplace.stacklandlicenseapi.v1.LicenseLimit\x12\x11\n\tsignature\x18\x08 \x01(\t\"\xe0\x01\n\x0bSyncRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12(\n\x12\x62illing_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12(\n\x11license_server_id\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12V\n\x05usage\x18\x04 \x03(\x0b\x32;.yandex.cloud.marketplace.stacklandlicenseapi.v1.UsageEntryB\n\x82\xc8\x31\x06<=1000\"\xc0\x01\n\x0fSyncUsageResult\x12J\n\x08licenses\x18\x01 \x03(\x0b\x32\x38.yandex.cloud.marketplace.stacklandlicenseapi.v1.License\x12P\n\x0bsync_status\x18\x02 \x01(\x0e\x32;.yandex.cloud.marketplace.stacklandlicenseapi.v1.SyncStatus\x12\x0f\n\x07message\x18\x03 \x01(\t\"c\n\x11SyncUsageMetadata\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x1a\n\x12\x62illing_account_id\x18\x02 \x01(\t\x12\x19\n\x11license_server_id\x18\x03 \x01(\t*\xba\x01\n\x0bProductType\x12\x1c\n\x18PRODUCT_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16PRODUCT_TYPE_STACKLAND\x10\x01\x12\x19\n\x15PRODUCT_TYPE_DATALENS\x10\x02\x12\x1a\n\x16PRODUCT_TYPE_AI_STUDIO\x10\x03\x12\x1c\n\x18PRODUCT_TYPE_SPEECHSENSE\x10\x04\x12\x1c\n\x18PRODUCT_TYPE_ROBOTICS_AI\x10\x05*I\n\nSyncStatus\x12\x1b\n\x17SYNC_STATUS_UNSPECIFIED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x42\x9e\x01\n3yandex.cloud.api.marketplace.stacklandlicenseapi.v1Zggithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/stacklandlicenseapi/v1;stacklandlicenseapib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.stacklandlicenseapi.v1.sync_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3yandex.cloud.api.marketplace.stacklandlicenseapi.v1Zggithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/stacklandlicenseapi/v1;stacklandlicenseapi'
  _globals['_USAGEENTRY'].fields_by_name['installation_id']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['installation_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_USAGEENTRY'].fields_by_name['type']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['type']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_USAGEENTRY'].fields_by_name['timestamp']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['timestamp']._serialized_options = b'\350\3071\001'
  _globals['_USAGEENTRY'].fields_by_name['hardware_fingerprint']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['hardware_fingerprint']._serialized_options = b'\212\3101\005<=500'
  _globals['_USAGEENTRY'].fields_by_name['license_id']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['license_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_USAGEENTRY'].fields_by_name['server_timestamp']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['server_timestamp']._serialized_options = b'\350\3071\001'
  _globals['_USAGEENTRY'].fields_by_name['prev_record_hash']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['prev_record_hash']._serialized_options = b'\350\3071\001\212\3101\00264'
  _globals['_USAGEENTRY'].fields_by_name['record_hash']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['record_hash']._serialized_options = b'\350\3071\001\212\3101\00264'
  _globals['_USAGEENTRY'].fields_by_name['signature']._loaded_options = None
  _globals['_USAGEENTRY'].fields_by_name['signature']._serialized_options = b'\350\3071\001\212\3101\006<=1000'
  _globals['_SYNCREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_SYNCREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYNCREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_SYNCREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYNCREQUEST'].fields_by_name['license_server_id']._loaded_options = None
  _globals['_SYNCREQUEST'].fields_by_name['license_server_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_SYNCREQUEST'].fields_by_name['usage']._loaded_options = None
  _globals['_SYNCREQUEST'].fields_by_name['usage']._serialized_options = b'\202\3101\006<=1000'
  _globals['_PRODUCTTYPE']._serialized_start=1610
  _globals['_PRODUCTTYPE']._serialized_end=1796
  _globals['_SYNCSTATUS']._serialized_start=1798
  _globals['_SYNCSTATUS']._serialized_end=1871
  _globals['_USAGEENTRY']._serialized_start=176
  _globals['_USAGEENTRY']._serialized_end=676
  _globals['_LICENSELIMIT']._serialized_start=678
  _globals['_LICENSELIMIT']._serialized_end=721
  _globals['_LICENSE']._serialized_start=724
  _globals['_LICENSE']._serialized_end=1084
  _globals['_SYNCREQUEST']._serialized_start=1087
  _globals['_SYNCREQUEST']._serialized_end=1311
  _globals['_SYNCUSAGERESULT']._serialized_start=1314
  _globals['_SYNCUSAGERESULT']._serialized_end=1506
  _globals['_SYNCUSAGEMETADATA']._serialized_start=1508
  _globals['_SYNCUSAGEMETADATA']._serialized_end=1607
# @@protoc_insertion_point(module_scope)
