# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/trino/v1/resource_management.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/trino/v1/resource_management.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/trino/v1/resource_management.proto\x12\x15yandex.cloud.trino.v1\x1a\x1dyandex/cloud/validation.proto\"\x93\x01\n\x18ResourceManagementConfig\x12\x44\n\x0fresource_groups\x18\x01 \x01(\x0b\x32+.yandex.cloud.trino.v1.ResourceGroupsConfig\x12\x31\n\x05query\x18\x02 \x01(\x0b\x32\".yandex.cloud.trino.v1.QueryConfig\"\x88\x01\n\x0bQueryConfig\x12\x46\n\nproperties\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.trino.v1.QueryConfig.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbf\x01\n\x14ResourceGroupsConfig\x12G\n\x0broot_groups\x18\x01 \x03(\x0b\x32*.yandex.cloud.trino.v1.ResourceGroupConfigB\x06\x82\xc8\x31\x02>0\x12\x44\n\tselectors\x18\x02 \x03(\x0b\x32).yandex.cloud.trino.v1.SelectorRuleConfigB\x06\x82\xc8\x31\x02>0\x12\x18\n\x10\x63pu_quota_period\x18\x03 \x01(\t\"\x87\x04\n\x13ResourceGroupConfig\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\nmax_queued\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x1e\n\x16soft_concurrency_limit\x18\x03 \x01(\x03\x12&\n\x16hard_concurrency_limit\x18\x04 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x19\n\x11soft_memory_limit\x18\x05 \x01(\t\x12\x16\n\x0esoft_cpu_limit\x18\x06 \x01(\t\x12\x16\n\x0ehard_cpu_limit\x18\x07 \x01(\t\x12V\n\x11scheduling_policy\x18\x08 \x01(\x0e\x32;.yandex.cloud.trino.v1.ResourceGroupConfig.SchedulingPolicy\x12\x19\n\x11scheduling_weight\x18\t \x01(\x03\x12>\n\nsub_groups\x18\x0b \x03(\x0b\x32*.yandex.cloud.trino.v1.ResourceGroupConfig\"t\n\x10SchedulingPolicy\x12!\n\x1dSCHEDULING_POLICY_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46\x41IR\x10\x01\x12\x0c\n\x08WEIGHTED\x10\x02\x12\x11\n\rWEIGHTED_FAIR\x10\x03\x12\x12\n\x0eQUERY_PRIORITY\x10\x04J\x04\x08\n\x10\x0b\"\x80\x03\n\x12SelectorRuleConfig\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nuser_group\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\x12G\n\nquery_type\x18\x06 \x01(\x0e\x32\x33.yandex.cloud.trino.v1.SelectorRuleConfig.QueryType\x12\x13\n\x0b\x63lient_tags\x18\x07 \x03(\t\x12\x13\n\x05group\x18\x08 \x01(\tB\x04\xe8\xc7\x31\x01\"\xb8\x01\n\tQueryType\x12\x1a\n\x16QUERY_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06SELECT\x10\x01\x12\x0b\n\x07\x45XPLAIN\x10\x02\x12\x0c\n\x08\x44\x45SCRIBE\x10\x03\x12\n\n\x06INSERT\x10\x04\x12\n\n\x06UPDATE\x10\x05\x12\t\n\x05MERGE\x10\x06\x12\n\n\x06\x44\x45LETE\x10\x07\x12\x0b\n\x07\x41NALYZE\x10\x08\x12\x13\n\x0f\x44\x41TA_DEFINITION\x10\t\x12\x17\n\x13\x41LTER_TABLE_EXECUTE\x10\nJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\x42\\\n\x19yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trinob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.trino.v1.resource_management_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trino'
  _globals['_QUERYCONFIG_PROPERTIESENTRY']._loaded_options = None
  _globals['_QUERYCONFIG_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCEGROUPSCONFIG'].fields_by_name['root_groups']._loaded_options = None
  _globals['_RESOURCEGROUPSCONFIG'].fields_by_name['root_groups']._serialized_options = b'\202\3101\002>0'
  _globals['_RESOURCEGROUPSCONFIG'].fields_by_name['selectors']._loaded_options = None
  _globals['_RESOURCEGROUPSCONFIG'].fields_by_name['selectors']._serialized_options = b'\202\3101\002>0'
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['name']._loaded_options = None
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['max_queued']._loaded_options = None
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['max_queued']._serialized_options = b'\372\3071\002>0'
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['hard_concurrency_limit']._loaded_options = None
  _globals['_RESOURCEGROUPCONFIG'].fields_by_name['hard_concurrency_limit']._serialized_options = b'\372\3071\002>0'
  _globals['_SELECTORRULECONFIG'].fields_by_name['group']._loaded_options = None
  _globals['_SELECTORRULECONFIG'].fields_by_name['group']._serialized_options = b'\350\3071\001'
  _globals['_RESOURCEMANAGEMENTCONFIG']._serialized_start=106
  _globals['_RESOURCEMANAGEMENTCONFIG']._serialized_end=253
  _globals['_QUERYCONFIG']._serialized_start=256
  _globals['_QUERYCONFIG']._serialized_end=392
  _globals['_QUERYCONFIG_PROPERTIESENTRY']._serialized_start=343
  _globals['_QUERYCONFIG_PROPERTIESENTRY']._serialized_end=392
  _globals['_RESOURCEGROUPSCONFIG']._serialized_start=395
  _globals['_RESOURCEGROUPSCONFIG']._serialized_end=586
  _globals['_RESOURCEGROUPCONFIG']._serialized_start=589
  _globals['_RESOURCEGROUPCONFIG']._serialized_end=1108
  _globals['_RESOURCEGROUPCONFIG_SCHEDULINGPOLICY']._serialized_start=986
  _globals['_RESOURCEGROUPCONFIG_SCHEDULINGPOLICY']._serialized_end=1102
  _globals['_SELECTORRULECONFIG']._serialized_start=1111
  _globals['_SELECTORRULECONFIG']._serialized_end=1495
  _globals['_SELECTORRULECONFIG_QUERYTYPE']._serialized_start=1299
  _globals['_SELECTORRULECONFIG_QUERYTYPE']._serialized_end=1483
# @@protoc_insertion_point(module_scope)
