# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/access_policy_template_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/access_policy_template_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/iam/v1/access_policy_template_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/access/access.proto\x1a\x1dyandex/cloud/validation.proto\"a\n ListAccessPolicyTemplatesRequest\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\x80\x01\n!ListAccessPolicyTemplatesResponse\x12\x42\n\x17\x61\x63\x63\x65ss_policy_templates\x18\x01 \x03(\x0b\x32!.yandex.cloud.access.AccessPolicy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xbc\x01\n\x1b\x41\x63\x63\x65ssPolicyTemplateService\x12\x9c\x01\n\x04List\x12\x35.yandex.cloud.iam.v1.ListAccessPolicyTemplatesRequest\x1a\x36.yandex.cloud.iam.v1.ListAccessPolicyTemplatesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/iam/v1/accessPolicyTemplatesBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.access_policy_template_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_ACCESSPOLICYTEMPLATESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ACCESSPOLICYTEMPLATESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\037\022\035/iam/v1/accessPolicyTemplates'
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST']._serialized_start=176
  _globals['_LISTACCESSPOLICYTEMPLATESREQUEST']._serialized_end=273
  _globals['_LISTACCESSPOLICYTEMPLATESRESPONSE']._serialized_start=276
  _globals['_LISTACCESSPOLICYTEMPLATESRESPONSE']._serialized_end=404
  _globals['_ACCESSPOLICYTEMPLATESERVICE']._serialized_start=407
  _globals['_ACCESSPOLICYTEMPLATESERVICE']._serialized_end=595
# @@protoc_insertion_point(module_scope)
