# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/config.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/mdb/greenplum/v1/config.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"\xd2\x02\n\x16\x43onnectionPoolerConfig\x12L\n\x04mode\x18\x01 \x01(\x0e\x32>.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig.PoolMode\x12)\n\x04size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13\x63lient_idle_timeout\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bidle_in_transaction_timeout\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"C\n\x08PoolMode\x12\x19\n\x15POOL_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\x0f\n\x0bTRANSACTION\x10\x02\"O\n\x19\x42\x61\x63kgroundActivityStartAt\x12\x17\n\x05hours\x18\x01 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-23\x12\x19\n\x07minutes\x18\x02 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-59\"_\n\nTableSizes\x12Q\n\x06starts\x18\x01 \x03(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.BackgroundActivityStartAtB\x07\x82\xc8\x31\x03<=4\"\xe6\x01\n\x10\x41nalyzeAndVacuum\x12G\n\x05start\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.BackgroundActivityStartAt\x12\x44\n\x0f\x61nalyze_timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n7200-86399\x12\x43\n\x0evacuum_timeout\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n7200-86399\"\xfa\x01\n\x1a\x42\x61\x63kgroundActivitiesConfig\x12>\n\x0btable_sizes\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.greenplum.v1.TableSizes\x12K\n\x12\x61nalyze_and_vacuum\x18\x02 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.AnalyzeAndVacuum\x12O\n\x14query_killer_scripts\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.mdb.greenplum.v1.QueryKillerScripts\"\x8a\x01\n\x0bQueryKiller\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x07max_age\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x31-86400\x12\x14\n\x0cignore_users\x18\x03 \x03(\t\"\xd9\x01\n\x12QueryKillerScripts\x12\x38\n\x04idle\x18\x01 \x01(\x0b\x32*.yandex.cloud.mdb.greenplum.v1.QueryKiller\x12G\n\x13idle_in_transaction\x18\x02 \x01(\x0b\x32*.yandex.cloud.mdb.greenplum.v1.QueryKiller\x12@\n\x0clong_running\x18\x03 \x01(\x0b\x32*.yandex.cloud.mdb.greenplum.v1.QueryKiller\"U\n\x16MasterSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"V\n\x17SegmentSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"\xbe\x13\n\x10GreenplumConfig6\x12\x41\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35\x30-1000\x12O\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x30-214748364800\x12K\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x13\xfa\xc7\x31\x0f\x30-1099511627776\x12T\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x30-100000\x12L\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x35\x30-10000\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12S\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x1b\xfa\xc7\x31\x17\x31\x33\x34\x32\x31\x37\x37\x32\x38-1099511627776\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\x12H\n$gp_add_column_inherits_table_setting\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x46\n\"gp_enable_global_deadlock_detector\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12G\n\"gp_global_deadlock_detector_period\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\rgp_max_slices\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31\x30-100\x12M\n\x1egp_cached_segworkers_threshold\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x30-10\x12\x43\n\x0clock_timeout\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12Z\n#idle_in_transaction_session_timeout\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12S\n#runaway_detector_activation_percent\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12V\n%gp_vmem_protect_segworker_cache_limit\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-4096\x12\x44\n gp_enable_zstd_memory_accounting\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12G\n\x10gp_max_plan_size\x18\x14 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12I\n\x11gp_autostats_mode\x18\x15 \x01(\x0e\x32..yandex.cloud.mdb.greenplum.v1.GPAutostatsMode\x12W\n gp_autostats_on_change_threshold\x18\x16 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12Q\n\x1egp_resource_group_memory_limit\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.1-0.8\x12\x33\n\x0flog_connections\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12log_disconnections\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0clog_hostname\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13log_statement_stats\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12R\n\x1alog_min_duration_statement\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12R\n\x15master_shared_buffers\x18\x1d \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x16\xfa\xc7\x31\x12\x31\x30\x34\x38\x35\x37\x36-2147483647\x12L\n\x19max_locks_per_transaction\x18\x1e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x32\x38-2048\x12S\n\x16segment_shared_buffers\x18\x1f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x16\xfa\xc7\x31\x12\x31\x30\x34\x38\x35\x37\x36-2147483647\x12M\n\x13log_error_verbosity\x18  \x01(\x0e\x32\x30.yandex.cloud.mdb.greenplum.v1.LogErrorVerbosity\x12H\n\x10log_min_messages\x18! \x01(\x0e\x32..yandex.cloud.mdb.greenplum.v1.LogLevelMessage\"\xf7\x12\n\x13GreenplumConfigCBDB\x12\x41\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35\x30-1000\x12O\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x30-214748364800\x12K\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x13\xfa\xc7\x31\x0f\x30-1099511627776\x12T\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x30-100000\x12L\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x35\x30-10000\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12S\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x1b\xfa\xc7\x31\x17\x31\x33\x34\x32\x31\x37\x37\x32\x38-1099511627776\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\x12\x46\n\"gp_enable_global_deadlock_detector\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12G\n\"gp_global_deadlock_detector_period\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\rgp_max_slices\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31\x30-100\x12M\n\x1egp_cached_segworkers_threshold\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x30-10\x12\x43\n\x0clock_timeout\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12Z\n#idle_in_transaction_session_timeout\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12S\n#runaway_detector_activation_percent\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12V\n%gp_vmem_protect_segworker_cache_limit\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-4096\x12\x44\n gp_enable_zstd_memory_accounting\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12G\n\x10gp_max_plan_size\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12I\n\x11gp_autostats_mode\x18\x14 \x01(\x0e\x32..yandex.cloud.mdb.greenplum.v1.GPAutostatsMode\x12W\n gp_autostats_on_change_threshold\x18\x15 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12Q\n\x1egp_resource_group_memory_limit\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.1-0.8\x12\x33\n\x0flog_connections\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12log_disconnections\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0clog_hostname\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13log_statement_stats\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12R\n\x1alog_min_duration_statement\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12R\n\x15master_shared_buffers\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x16\xfa\xc7\x31\x12\x31\x30\x34\x38\x35\x37\x36-2147483647\x12L\n\x19max_locks_per_transaction\x18\x1d \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x32\x38-2048\x12S\n\x16segment_shared_buffers\x18\x1e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x16\xfa\xc7\x31\x12\x31\x30\x34\x38\x35\x37\x36-2147483647\x12M\n\x13log_error_verbosity\x18\x1f \x01(\x0e\x32\x30.yandex.cloud.mdb.greenplum.v1.LogErrorVerbosity\x12H\n\x10log_min_messages\x18  \x01(\x0e\x32..yandex.cloud.mdb.greenplum.v1.LogLevelMessage\"\xf5\x01\n\x13GreenplumConfigSet6\x12O\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6B\x04\xe8\xc7\x31\x01\x12\x44\n\x0buser_config\x18\x02 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6\x12G\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6\"\x8d\x02\n\x19\x43onnectionPoolerConfigSet\x12U\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfigB\x04\xe8\xc7\x31\x01\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig\"\x81\x02\n\x16GreenplumConfigSetCBDB\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfigCBDBB\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfigCBDB\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfigCBDB*]\n\x11LogErrorVerbosity\x12#\n\x1fLOG_ERROR_VERBOSITY_UNSPECIFIED\x10\x00\x12\t\n\x05TERSE\x10\x01\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x02\x12\x0b\n\x07VERBOSE\x10\x03*\xb4\x01\n\x0fLogLevelMessage\x12!\n\x1dLOG_LEVEL_MESSAGE_UNSPECIFIED\x10\x00\x12\n\n\x06\x44\x45\x42UG5\x10\x01\x12\n\n\x06\x44\x45\x42UG4\x10\x02\x12\n\n\x06\x44\x45\x42UG3\x10\x03\x12\n\n\x06\x44\x45\x42UG2\x10\x04\x12\n\n\x06\x44\x45\x42UG1\x10\x05\x12\x08\n\x04INFO\x10\x06\x12\n\n\x06NOTICE\x10\x07\x12\x0b\n\x07WARNING\x10\x08\x12\t\n\x05\x45RROR\x10\t\x12\t\n\x05\x46\x41TAL\x10\n\x12\t\n\x05PANIC\x10\x0b*R\n\x0cLogStatement\x12\x1d\n\x19LOG_STATEMENT_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03\x44\x44L\x10\x02\x12\x07\n\x03MOD\x10\x03\x12\x07\n\x03\x41LL\x10\x04*\x94\x01\n\x0fGPAutostatsMode\x12!\n\x1dGP_AUTOSTATS_MODE_UNSPECIFIED\x10\x00\x12\x1a\n\x16GP_AUTOSTATS_MODE_NONE\x10\x01\x12\x1f\n\x1bGP_AUTOSTATS_MODE_ON_CHANGE\x10\x02\x12!\n\x1dGP_AUTOSTATS_MODE_ON_NO_STATS\x10\x03\x42p\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['hours']._loaded_options = None
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['hours']._serialized_options = b'\372\3071\0040-23'
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['minutes']._loaded_options = None
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['minutes']._serialized_options = b'\372\3071\0040-59'
  _globals['_TABLESIZES'].fields_by_name['starts']._loaded_options = None
  _globals['_TABLESIZES'].fields_by_name['starts']._serialized_options = b'\202\3101\003<=4'
  _globals['_ANALYZEANDVACUUM'].fields_by_name['analyze_timeout']._loaded_options = None
  _globals['_ANALYZEANDVACUUM'].fields_by_name['analyze_timeout']._serialized_options = b'\372\3071\n7200-86399'
  _globals['_ANALYZEANDVACUUM'].fields_by_name['vacuum_timeout']._loaded_options = None
  _globals['_ANALYZEANDVACUUM'].fields_by_name['vacuum_timeout']._serialized_options = b'\372\3071\n7200-86399'
  _globals['_QUERYKILLER'].fields_by_name['max_age']._loaded_options = None
  _globals['_QUERYKILLER'].fields_by_name['max_age']._serialized_options = b'\372\3071\0071-86400'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_connections']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_connections']._serialized_options = b'\372\3071\00750-1000'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_slot_wal_keep_size']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_slot_wal_keep_size']._serialized_options = b'\372\3071\0160-214748364800'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_per_segment']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_per_segment']._serialized_options = b'\372\3071\003>=0'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_per_query']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_per_query']._serialized_options = b'\372\3071\0170-1099511627776'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_files_per_query']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_files_per_query']._serialized_options = b'\372\3071\0100-100000'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_prepared_transactions']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_prepared_transactions']._serialized_options = b'\372\3071\01050-10000'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_statement_mem']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_statement_mem']._serialized_options = b'\372\3071\027134217728-1099511627776'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_max_slices']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_max_slices']._serialized_options = b'\372\3071\00610-100'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_cached_segworkers_threshold']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_cached_segworkers_threshold']._serialized_options = b'\372\3071\0040-10'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['lock_timeout']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['lock_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['idle_in_transaction_session_timeout']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['idle_in_transaction_session_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['runaway_detector_activation_percent']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['runaway_detector_activation_percent']._serialized_options = b'\372\3071\0050-100'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_vmem_protect_segworker_cache_limit']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_vmem_protect_segworker_cache_limit']._serialized_options = b'\372\3071\0060-4096'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_max_plan_size']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_max_plan_size']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_autostats_on_change_threshold']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_autostats_on_change_threshold']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_resource_group_memory_limit']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_resource_group_memory_limit']._serialized_options = b'\372\3071\0070.1-0.8'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['log_min_duration_statement']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['log_min_duration_statement']._serialized_options = b'\372\3071\r-1-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['master_shared_buffers']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['master_shared_buffers']._serialized_options = b'\372\3071\0221048576-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_locks_per_transaction']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_locks_per_transaction']._serialized_options = b'\372\3071\010128-2048'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['segment_shared_buffers']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['segment_shared_buffers']._serialized_options = b'\372\3071\0221048576-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_connections']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_connections']._serialized_options = b'\372\3071\00750-1000'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_slot_wal_keep_size']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_slot_wal_keep_size']._serialized_options = b'\372\3071\0160-214748364800'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_per_segment']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_per_segment']._serialized_options = b'\372\3071\003>=0'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_per_query']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_per_query']._serialized_options = b'\372\3071\0170-1099511627776'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_files_per_query']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_files_per_query']._serialized_options = b'\372\3071\0100-100000'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_prepared_transactions']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_prepared_transactions']._serialized_options = b'\372\3071\01050-10000'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_statement_mem']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_statement_mem']._serialized_options = b'\372\3071\027134217728-1099511627776'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_max_slices']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_max_slices']._serialized_options = b'\372\3071\00610-100'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_cached_segworkers_threshold']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_cached_segworkers_threshold']._serialized_options = b'\372\3071\0040-10'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['lock_timeout']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['lock_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['idle_in_transaction_session_timeout']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['idle_in_transaction_session_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['runaway_detector_activation_percent']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['runaway_detector_activation_percent']._serialized_options = b'\372\3071\0050-100'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_vmem_protect_segworker_cache_limit']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_vmem_protect_segworker_cache_limit']._serialized_options = b'\372\3071\0060-4096'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_max_plan_size']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_max_plan_size']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_autostats_on_change_threshold']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_autostats_on_change_threshold']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_resource_group_memory_limit']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_resource_group_memory_limit']._serialized_options = b'\372\3071\0070.1-0.8'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['log_min_duration_statement']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['log_min_duration_statement']._serialized_options = b'\372\3071\r-1-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['master_shared_buffers']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['master_shared_buffers']._serialized_options = b'\372\3071\0221048576-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_locks_per_transaction']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_locks_per_transaction']._serialized_options = b'\372\3071\010128-2048'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['segment_shared_buffers']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['segment_shared_buffers']._serialized_options = b'\372\3071\0221048576-2147483647'
  _globals['_GREENPLUMCONFIGSET6'].fields_by_name['effective_config']._loaded_options = None
  _globals['_GREENPLUMCONFIGSET6'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_CONNECTIONPOOLERCONFIGSET'].fields_by_name['effective_config']._loaded_options = None
  _globals['_CONNECTIONPOOLERCONFIGSET'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_GREENPLUMCONFIGSETCBDB'].fields_by_name['effective_config']._loaded_options = None
  _globals['_GREENPLUMCONFIGSETCBDB'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_LOGERRORVERBOSITY']._serialized_start=7466
  _globals['_LOGERRORVERBOSITY']._serialized_end=7559
  _globals['_LOGLEVELMESSAGE']._serialized_start=7562
  _globals['_LOGLEVELMESSAGE']._serialized_end=7742
  _globals['_LOGSTATEMENT']._serialized_start=7744
  _globals['_LOGSTATEMENT']._serialized_end=7826
  _globals['_GPAUTOSTATSMODE']._serialized_start=7829
  _globals['_GPAUTOSTATSMODE']._serialized_end=7977
  _globals['_RESOURCES']._serialized_start=140
  _globals['_RESOURCES']._serialized_end=220
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_start=223
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_end=561
  _globals['_CONNECTIONPOOLERCONFIG_POOLMODE']._serialized_start=494
  _globals['_CONNECTIONPOOLERCONFIG_POOLMODE']._serialized_end=561
  _globals['_BACKGROUNDACTIVITYSTARTAT']._serialized_start=563
  _globals['_BACKGROUNDACTIVITYSTARTAT']._serialized_end=642
  _globals['_TABLESIZES']._serialized_start=644
  _globals['_TABLESIZES']._serialized_end=739
  _globals['_ANALYZEANDVACUUM']._serialized_start=742
  _globals['_ANALYZEANDVACUUM']._serialized_end=972
  _globals['_BACKGROUNDACTIVITIESCONFIG']._serialized_start=975
  _globals['_BACKGROUNDACTIVITIESCONFIG']._serialized_end=1225
  _globals['_QUERYKILLER']._serialized_start=1228
  _globals['_QUERYKILLER']._serialized_end=1366
  _globals['_QUERYKILLERSCRIPTS']._serialized_start=1369
  _globals['_QUERYKILLERSCRIPTS']._serialized_end=1586
  _globals['_MASTERSUBCLUSTERCONFIG']._serialized_start=1588
  _globals['_MASTERSUBCLUSTERCONFIG']._serialized_end=1673
  _globals['_SEGMENTSUBCLUSTERCONFIG']._serialized_start=1675
  _globals['_SEGMENTSUBCLUSTERCONFIG']._serialized_end=1761
  _globals['_GREENPLUMCONFIG6']._serialized_start=1764
  _globals['_GREENPLUMCONFIG6']._serialized_end=4258
  _globals['_GREENPLUMCONFIGCBDB']._serialized_start=4261
  _globals['_GREENPLUMCONFIGCBDB']._serialized_end=6684
  _globals['_GREENPLUMCONFIGSET6']._serialized_start=6687
  _globals['_GREENPLUMCONFIGSET6']._serialized_end=6932
  _globals['_CONNECTIONPOOLERCONFIGSET']._serialized_start=6935
  _globals['_CONNECTIONPOOLERCONFIGSET']._serialized_end=7204
  _globals['_GREENPLUMCONFIGSETCBDB']._serialized_start=7207
  _globals['_GREENPLUMCONFIGSETCBDB']._serialized_end=7464
# @@protoc_insertion_point(module_scope)
