"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.connectionmanager.v1.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OpenSearchAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def user_password(self) -> yandex.cloud.connectionmanager.v1.common_pb2.UserPasswordAuth: ...
    def __init__(
        self,
        *,
        user_password: yandex.cloud.connectionmanager.v1.common_pb2.UserPasswordAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["security", b"security", "user_password", b"user_password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["security", b"security", "user_password", b"user_password"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["security", b"security"]) -> typing.Literal["user_password"] | None: ...

global___OpenSearchAuth = OpenSearchAuth

@typing.final
class OpenSearchCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Host(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _GroupRole:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _GroupRoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[OpenSearchCluster.Host._GroupRole.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            GROUP_ROLE_UNSPECIFIED: OpenSearchCluster.Host._GroupRole.ValueType  # 0
            DATA: OpenSearchCluster.Host._GroupRole.ValueType  # 1
            MANAGER: OpenSearchCluster.Host._GroupRole.ValueType  # 2

        class GroupRole(_GroupRole, metaclass=_GroupRoleEnumTypeWrapper): ...
        GROUP_ROLE_UNSPECIFIED: OpenSearchCluster.Host.GroupRole.ValueType  # 0
        DATA: OpenSearchCluster.Host.GroupRole.ValueType  # 1
        MANAGER: OpenSearchCluster.Host.GroupRole.ValueType  # 2

        class _Health:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[OpenSearchCluster.Host._Health.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            HEALTH_UNSPECIFIED: OpenSearchCluster.Host._Health.ValueType  # 0
            ALIVE: OpenSearchCluster.Host._Health.ValueType  # 1
            DEAD: OpenSearchCluster.Host._Health.ValueType  # 2
            DEGRADED: OpenSearchCluster.Host._Health.ValueType  # 3
            READONLY: OpenSearchCluster.Host._Health.ValueType  # 4

        class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
        HEALTH_UNSPECIFIED: OpenSearchCluster.Host.Health.ValueType  # 0
        ALIVE: OpenSearchCluster.Host.Health.ValueType  # 1
        DEAD: OpenSearchCluster.Host.Health.ValueType  # 2
        DEGRADED: OpenSearchCluster.Host.Health.ValueType  # 3
        READONLY: OpenSearchCluster.Host.Health.ValueType  # 4

        HOST_FIELD_NUMBER: builtins.int
        PORT_FIELD_NUMBER: builtins.int
        HEALTH_FIELD_NUMBER: builtins.int
        ROLES_FIELD_NUMBER: builtins.int
        host: builtins.str
        port: builtins.int
        health: global___OpenSearchCluster.Host.Health.ValueType
        @property
        def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___OpenSearchCluster.Host.GroupRole.ValueType]: ...
        def __init__(
            self,
            *,
            host: builtins.str = ...,
            port: builtins.int = ...,
            health: global___OpenSearchCluster.Host.Health.ValueType = ...,
            roles: collections.abc.Iterable[global___OpenSearchCluster.Host.GroupRole.ValueType] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["health", b"health", "host", b"host", "port", b"port", "roles", b"roles"]) -> None: ...

    HOSTS_FIELD_NUMBER: builtins.int
    TLS_PARAMS_FIELD_NUMBER: builtins.int
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OpenSearchCluster.Host]: ...
    @property
    def tls_params(self) -> yandex.cloud.connectionmanager.v1.common_pb2.TLSParams: ...
    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[global___OpenSearchCluster.Host] | None = ...,
        tls_params: yandex.cloud.connectionmanager.v1.common_pb2.TLSParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_params", b"tls_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "tls_params", b"tls_params"]) -> None: ...

global___OpenSearchCluster = OpenSearchCluster

@typing.final
class OpenSearchConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    MANAGED_CLUSTER_ID_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    managed_cluster_id: builtins.str
    """When creating/updating Connection, the field "managed_cluster_id" is
    mutually exclusive with "cluster".
    """
    @property
    def cluster(self) -> global___OpenSearchCluster:
        """When creating/updating Connection, the field "cluster" is mutually
        exclusive with "managed_cluster_id".
        """

    @property
    def auth(self) -> global___OpenSearchAuth: ...
    def __init__(
        self,
        *,
        cluster: global___OpenSearchCluster | None = ...,
        managed_cluster_id: builtins.str = ...,
        auth: global___OpenSearchAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster", "managed_cluster_id", b"managed_cluster_id"]) -> None: ...

global___OpenSearchConnection = OpenSearchConnection
