"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SynchronizationSessionServiceStub:
    """A set of methods for managing synchronization sessions."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    OpenSession: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.OpenSessionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Opens a new synchronization session."""

    CloseSession: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.CloseSessionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Closes a synchronization session."""

    ReportSessionProgress: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ReportSessionProgressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reports progress for a synchronization session."""

    Heartbeat: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.HeartbeatRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sends a heartbeat for a synchronization session."""

    GetSession: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionResponse,
    ]
    """Returns the specified synchronization session."""

    ListSessions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsResponse,
    ]
    """Lists synchronization sessions for a subject container."""

class SynchronizationSessionServiceAsyncStub:
    """A set of methods for managing synchronization sessions."""

    OpenSession: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.OpenSessionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Opens a new synchronization session."""

    CloseSession: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.CloseSessionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Closes a synchronization session."""

    ReportSessionProgress: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ReportSessionProgressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reports progress for a synchronization session."""

    Heartbeat: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.HeartbeatRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sends a heartbeat for a synchronization session."""

    GetSession: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionResponse,
    ]
    """Returns the specified synchronization session."""

    ListSessions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsResponse,
    ]
    """Lists synchronization sessions for a subject container."""

class SynchronizationSessionServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing synchronization sessions."""

    @abc.abstractmethod
    def OpenSession(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.OpenSessionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Opens a new synchronization session."""

    @abc.abstractmethod
    def CloseSession(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.CloseSessionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Closes a synchronization session."""

    @abc.abstractmethod
    def ReportSessionProgress(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ReportSessionProgressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Reports progress for a synchronization session."""

    @abc.abstractmethod
    def Heartbeat(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.HeartbeatRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sends a heartbeat for a synchronization session."""

    @abc.abstractmethod
    def GetSession(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionResponse]]:
        """Returns the specified synchronization session."""

    @abc.abstractmethod
    def ListSessions(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsResponse]]:
        """Lists synchronization sessions for a subject container."""

def add_SynchronizationSessionServiceServicer_to_server(servicer: SynchronizationSessionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
