# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/application/saml/signature_certificate_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/application/saml/signature_certificate_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp.application.saml import signature_certificate_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_application_dot_saml_dot_signature__certificate__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\\yandex/cloud/organizationmanager/v1/idp/application/saml/signature_certificate_service.proto\x12\x38yandex.cloud.organizationmanager.v1.idp.application.saml\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1aTyandex/cloud/organizationmanager/v1/idp/application/saml/signature_certificate.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"P\n\x1eGetSignatureCertificateRequest\x12.\n\x18signature_certificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xa3\x01\n ListSignatureCertificatesRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xac\x01\n!ListSignatureCertificatesResponse\x12n\n\x16signature_certificates\x18\x01 \x03(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.application.saml.SignatureCertificate\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9f\x01\n!CreateSignatureCertificateRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"F\n\"CreateSignatureCertificateMetadata\x12 \n\x18signature_certificate_id\x18\x01 \x01(\t\"\xd8\x01\n!UpdateSignatureCertificateRequest\x12.\n\x18signature_certificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\"F\n\"UpdateSignatureCertificateMetadata\x12 \n\x18signature_certificate_id\x18\x01 \x01(\t\"O\n!DeleteSignatureCertificateRequest\x12*\n\x18signature_certificate_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"F\n\"DeleteSignatureCertificateMetadata\x12 \n\x18signature_certificate_id\x18\x01 \x01(\t2\xcd\x0b\n\x1bSignatureCertificateService\x12\x98\x02\n\x03Get\x12X.yandex.cloud.organizationmanager.v1.idp.application.saml.GetSignatureCertificateRequest\x1aN.yandex.cloud.organizationmanager.v1.idp.application.saml.SignatureCertificate\"g\x82\xd3\xe4\x93\x02\x61\x12_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}\x12\x8d\x02\n\x04List\x12Z.yandex.cloud.organizationmanager.v1.idp.application.saml.ListSignatureCertificatesRequest\x1a[.yandex.cloud.organizationmanager.v1.idp.application.saml.ListSignatureCertificatesResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/organization-manager/v1/idp/application/saml/signature-certificates\x12\x98\x02\n\x06\x43reate\x12[.yandex.cloud.organizationmanager.v1.idp.application.saml.CreateSignatureCertificateRequest\x1a!.yandex.cloud.operation.Operation\"\x8d\x01\xb2\xd2*:\n\"CreateSignatureCertificateMetadata\x12\x14SignatureCertificate\x82\xd3\xe4\x93\x02I\"D/organization-manager/v1/idp/application/saml/signature-certificates:\x01*\x12\xb3\x02\n\x06Update\x12[.yandex.cloud.organizationmanager.v1.idp.application.saml.UpdateSignatureCertificateRequest\x1a!.yandex.cloud.operation.Operation\"\xa8\x01\xb2\xd2*:\n\"UpdateSignatureCertificateMetadata\x12\x14SignatureCertificate\x82\xd3\xe4\x93\x02\x64\x32_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}:\x01*\x12\xb1\x02\n\x06\x44\x65lete\x12[.yandex.cloud.organizationmanager.v1.idp.application.saml.DeleteSignatureCertificateRequest\x1a!.yandex.cloud.operation.Operation\"\xa6\x01\xb2\xd2*;\n\"DeleteSignatureCertificateMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x61*_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}B\xa1\x01\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;samlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.application.saml.signature_certificate_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;saml'
  _globals['_GETSIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._loaded_options = None
  _globals['_GETSIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._loaded_options = None
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_DELETESIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._loaded_options = None
  _globals['_DELETESIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002a\022_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}'
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002F\022D/organization-manager/v1/idp/application/saml/signature-certificates'
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*:\n\"CreateSignatureCertificateMetadata\022\024SignatureCertificate\202\323\344\223\002I\"D/organization-manager/v1/idp/application/saml/signature-certificates:\001*'
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*:\n\"UpdateSignatureCertificateMetadata\022\024SignatureCertificate\202\323\344\223\002d2_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}:\001*'
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*;\n\"DeleteSignatureCertificateMetadata\022\025google.protobuf.Empty\202\323\344\223\002a*_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}'
  _globals['_GETSIGNATURECERTIFICATEREQUEST']._serialized_start=409
  _globals['_GETSIGNATURECERTIFICATEREQUEST']._serialized_end=489
  _globals['_LISTSIGNATURECERTIFICATESREQUEST']._serialized_start=492
  _globals['_LISTSIGNATURECERTIFICATESREQUEST']._serialized_end=655
  _globals['_LISTSIGNATURECERTIFICATESRESPONSE']._serialized_start=658
  _globals['_LISTSIGNATURECERTIFICATESRESPONSE']._serialized_end=830
  _globals['_CREATESIGNATURECERTIFICATEREQUEST']._serialized_start=833
  _globals['_CREATESIGNATURECERTIFICATEREQUEST']._serialized_end=992
  _globals['_CREATESIGNATURECERTIFICATEMETADATA']._serialized_start=994
  _globals['_CREATESIGNATURECERTIFICATEMETADATA']._serialized_end=1064
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST']._serialized_start=1067
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST']._serialized_end=1283
  _globals['_UPDATESIGNATURECERTIFICATEMETADATA']._serialized_start=1285
  _globals['_UPDATESIGNATURECERTIFICATEMETADATA']._serialized_end=1355
  _globals['_DELETESIGNATURECERTIFICATEREQUEST']._serialized_start=1357
  _globals['_DELETESIGNATURECERTIFICATEREQUEST']._serialized_end=1436
  _globals['_DELETESIGNATURECERTIFICATEMETADATA']._serialized_start=1438
  _globals['_DELETESIGNATURECERTIFICATEMETADATA']._serialized_end=1508
  _globals['_SIGNATURECERTIFICATESERVICE']._serialized_start=1511
  _globals['_SIGNATURECERTIFICATESERVICE']._serialized_end=2996
# @@protoc_insertion_point(module_scope)
