"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LabelList(google.protobuf.message.Message):
    """Represents a list of label values for filtering or grouping in usage reports.
    For example, to filter resources with label key "env" that have value "prod" or "test",
    a LabelList with values ["prod", "test"] would be used for the key "env".
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of label values associated with a specific label key."""

    def __init__(
        self,
        *,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["values", b"values"]) -> None: ...

global___LabelList = LabelList

@typing.final
class BillingAccount(google.protobuf.message.Message):
    """Represents a billing account entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the billing_account entity."""
    name: builtins.str
    """Human-readable display name of the billing account."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name"]) -> None: ...

global___BillingAccount = BillingAccount

@typing.final
class Cloud(google.protobuf.message.Message):
    """Represents a cloud entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the cloud entity."""
    name: builtins.str
    """Human-readable display name of the cloud."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name"]) -> None: ...

global___Cloud = Cloud

@typing.final
class Folder(google.protobuf.message.Message):
    """Represents a folder entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the folder entity."""
    name: builtins.str
    """Human-readable display name of the folder."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name"]) -> None: ...

global___Folder = Folder

@typing.final
class Service(google.protobuf.message.Message):
    """Represents a service entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the service entity."""
    name: builtins.str
    """Service display name."""
    description: builtins.str
    """Service description."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "id", b"id", "name", b"name"]) -> None: ...

global___Service = Service

@typing.final
class SKU(google.protobuf.message.Message):
    """Represents a SKU (Stock Keeping Unit)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RU_TRANSLATION_FIELD_NUMBER: builtins.int
    EN_TRANSLATION_FIELD_NUMBER: builtins.int
    PRICING_UNIT_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the entity (SKU)."""
    name: builtins.str
    """Product (SKU) name."""
    ru_translation: builtins.str
    """Russian-language display name"""
    en_translation: builtins.str
    """English-language display name"""
    pricing_unit: builtins.str
    """Unit of measurement for pricing (e.g., "hour", "byte", "1m*request")."""
    service_id: builtins.str
    """The service ID this SKU belongs to;"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        ru_translation: builtins.str = ...,
        en_translation: builtins.str = ...,
        pricing_unit: builtins.str = ...,
        service_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["en_translation", b"en_translation", "id", b"id", "name", b"name", "pricing_unit", b"pricing_unit", "ru_translation", b"ru_translation", "service_id", b"service_id"]) -> None: ...

global___SKU = SKU

@typing.final
class Resource(google.protobuf.message.Message):
    """Represents a resource entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the resource entity."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___Resource = Resource

@typing.final
class Label(google.protobuf.message.Message):
    """Represents a key-value label pair attached to resources for custom metadata tagging.
    Labels allow grouping and filtering resources by user-defined dimensions.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """Label key (e.g., "region", "environment", "team", "project")."""
    value: builtins.str
    """The label value (e.g., "usa", "mexico", "prod", "test", "finance", "backend")"""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

global___Label = Label
