# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/synchronization_settings.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/synchronization_settings.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFyandex/cloud/organizationmanager/v1/idp/synchronization_settings.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xee\x04\n\x17SynchronizationSettings\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t\x12N\n\x06\x66ilter\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.SynchronizationFilter\x12Y\n\x14remove_user_behavior\x18\x03 \x01(\x0e\x32;.yandex.cloud.organizationmanager.v1.idp.RemoveUserBehavior\x12;\n\x18synchronization_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1e\n\x16\x61llow_to_capture_users\x18\x05 \x01(\x08\x12\x1f\n\x17\x61llow_to_capture_groups\x18\x06 \x01(\x08\x12^\n\x17user_attribute_mappings\x18\x07 \x03(\x0b\x32=.yandex.cloud.organizationmanager.v1.idp.UserAttributeMapping\x12`\n\x18group_attribute_mappings\x18\x08 \x03(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.GroupAttributeMapping\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12replacement_domain\x18\n \x01(\t\"\x88\x01\n\x15SynchronizationFilter\x12\x1d\n\x06\x64omain\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-253\x12!\n\x06groups\x18\x02 \x03(\tB\x11\x82\xc8\x31\x04<=10\x8a\xc8\x31\x05\x31-253\x12-\n\x12organization_units\x18\x03 \x03(\tB\x11\x82\xc8\x31\x04<=10\x8a\xc8\x31\x05\x31-253\"\xcf\x01\n\x14UserAttributeMapping\x12\x19\n\x06source\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x30-253\x12R\n\x06target\x18\x02 \x01(\x0e\x32<.yandex.cloud.organizationmanager.v1.idp.UserTargetAttributeB\x04\xe8\xc7\x31\x01\x12H\n\x04type\x18\x03 \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.MappingTypeB\x04\xe8\xc7\x31\x01\"\xd1\x01\n\x15GroupAttributeMapping\x12\x19\n\x06source\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x30-253\x12S\n\x06target\x18\x02 \x01(\x0e\x32=.yandex.cloud.organizationmanager.v1.idp.GroupTargetAttributeB\x04\xe8\xc7\x31\x01\x12H\n\x04type\x18\x03 \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.MappingTypeB\x04\xe8\xc7\x31\x01*B\n\x0bMappingType\x12\x1c\n\x18MAPPING_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x44IRECT\x10\x01\x12\t\n\x05\x45MPTY\x10\x02*\xd9\x01\n\x13UserTargetAttribute\x12%\n!USER_TARGET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\r\n\tFULL_NAME\x10\x01\x12\x0e\n\nGIVEN_NAME\x10\x02\x12\x0f\n\x0b\x46\x41MILY_NAME\x10\x03\x12\t\n\x05\x45MAIL\x10\x04\x12\x10\n\x0cPHONE_NUMBER\x10\x05\x12\x0c\n\x08USERNAME\x10\x06\x12\x10\n\x0c\x43OMPANY_NAME\x10\x07\x12\r\n\tJOB_TITLE\x10\x08\x12\x0e\n\nDEPARTMENT\x10\t\x12\x0f\n\x0b\x45MPLOYEE_ID\x10\n*Y\n\x14GroupTargetAttribute\x12&\n\"GROUP_TARGET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x02*Q\n\x12RemoveUserBehavior\x12$\n REMOVE_USER_BEHAVIOR_UNSPECIFIED\x10\x00\x12\n\n\x06REMOVE\x10\x01\x12\t\n\x05\x42LOCK\x10\x02*c\n\x0bSessionType\x12\x1c\n\x18SESSION_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x41\x44_SYNC\x10\x01\x12\x14\n\x10\x41\x44_PASSWORD_HASH\x10\x02\x12\x13\n\x0f\x41\x44_USER_CONTROL\x10\x03\x42~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['domain']._loaded_options = None
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['domain']._serialized_options = b'\350\3071\001\212\3101\0051-253'
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['groups']._loaded_options = None
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['groups']._serialized_options = b'\202\3101\004<=10\212\3101\0051-253'
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['organization_units']._loaded_options = None
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['organization_units']._serialized_options = b'\202\3101\004<=10\212\3101\0051-253'
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['source']._loaded_options = None
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['source']._serialized_options = b'\212\3101\0050-253'
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['target']._loaded_options = None
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['target']._serialized_options = b'\350\3071\001'
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['type']._loaded_options = None
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['source']._loaded_options = None
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['source']._serialized_options = b'\212\3101\0050-253'
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['target']._loaded_options = None
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['target']._serialized_options = b'\350\3071\001'
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['type']._loaded_options = None
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_MAPPINGTYPE']._serialized_start=1397
  _globals['_MAPPINGTYPE']._serialized_end=1463
  _globals['_USERTARGETATTRIBUTE']._serialized_start=1466
  _globals['_USERTARGETATTRIBUTE']._serialized_end=1683
  _globals['_GROUPTARGETATTRIBUTE']._serialized_start=1685
  _globals['_GROUPTARGETATTRIBUTE']._serialized_end=1774
  _globals['_REMOVEUSERBEHAVIOR']._serialized_start=1776
  _globals['_REMOVEUSERBEHAVIOR']._serialized_end=1857
  _globals['_SESSIONTYPE']._serialized_start=1859
  _globals['_SESSIONTYPE']._serialized_end=1958
  _globals['_SYNCHRONIZATIONSETTINGS']._serialized_start=212
  _globals['_SYNCHRONIZATIONSETTINGS']._serialized_end=834
  _globals['_SYNCHRONIZATIONFILTER']._serialized_start=837
  _globals['_SYNCHRONIZATIONFILTER']._serialized_end=973
  _globals['_USERATTRIBUTEMAPPING']._serialized_start=976
  _globals['_USERATTRIBUTEMAPPING']._serialized_end=1183
  _globals['_GROUPATTRIBUTEMAPPING']._serialized_start=1186
  _globals['_GROUPATTRIBUTEMAPPING']._serialized_end=1395
# @@protoc_insertion_point(module_scope)
