"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SortOrder:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SortOrderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SortOrder.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SORT_ORDER_UNSPECIFIED: _SortOrder.ValueType  # 0
    """Not specified."""
    ASC: _SortOrder.ValueType  # 1
    """Asceding sort order."""
    DESC: _SortOrder.ValueType  # 2
    """Desceding sort order."""

class SortOrder(_SortOrder, metaclass=_SortOrderEnumTypeWrapper): ...

SORT_ORDER_UNSPECIFIED: SortOrder.ValueType  # 0
"""Not specified."""
ASC: SortOrder.ValueType  # 1
"""Asceding sort order."""
DESC: SortOrder.ValueType  # 2
"""Desceding sort order."""
global___SortOrder = SortOrder
