# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/usage_records/v1/consumption_core.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/usage_records/v1/consumption_core.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.billing.usage_records.v1 import billing_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_billing__types__pb2
from yandex.cloud.billing.usage_records.v1 import common_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_common__types__pb2
from yandex.cloud.billing.usage_records.v1 import credit_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_credit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/billing/usage_records/v1/consumption_core.proto\x12%yandex.cloud.billing.usage_records.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x39yandex/cloud/billing/usage_records/v1/billing_types.proto\x1a\x38yandex/cloud/billing/usage_records/v1/common_types.proto\x1a\x32yandex/cloud/billing/usage_records/v1/credit.proto\"\xa0\x03\n#BillingAccountUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12N\n\x0f\x62illing_account\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.billing.usage_records.v1.BillingAccount\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\x84\x03\n\x1a\x43loudUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12;\n\x05\x63loud\x18\x04 \x01(\x0b\x32,.yandex.cloud.billing.usage_records.v1.Cloud\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\x87\x03\n\x1b\x46olderUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12=\n\x06\x66older\x18\x04 \x01(\x0b\x32-.yandex.cloud.billing.usage_records.v1.Folder\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\x8a\x03\n\x1cServiceUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12?\n\x07service\x18\x04 \x01(\x0b\x32..yandex.cloud.billing.usage_records.v1.Service\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\xce\x03\n\x18SKUUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12N\n\x10pricing_quantity\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12\x37\n\x03sku\x18\x05 \x01(\x0b\x32*.yandex.cloud.billing.usage_records.v1.SKU\x12P\n\x08periodic\x18\x06 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\x8d\x03\n\x1dResourceUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12\x41\n\x08resource\x18\x04 \x01(\x0b\x32/.yandex.cloud.billing.usage_records.v1.Resource\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\x84\x03\n\x1aLabelUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12;\n\x05label\x18\x04 \x01(\x0b\x32,.yandex.cloud.billing.usage_records.v1.Label\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\xa1\x02\n\x17UsageReportPeriodicData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x83\x01\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecordsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.usage_records.v1.consumption_core_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecords'
  _globals['_BILLINGACCOUNTUSAGEREPORTENTITYDATA']._serialized_start=306
  _globals['_BILLINGACCOUNTUSAGEREPORTENTITYDATA']._serialized_end=722
  _globals['_CLOUDUSAGEREPORTENTITYDATA']._serialized_start=725
  _globals['_CLOUDUSAGEREPORTENTITYDATA']._serialized_end=1113
  _globals['_FOLDERUSAGEREPORTENTITYDATA']._serialized_start=1116
  _globals['_FOLDERUSAGEREPORTENTITYDATA']._serialized_end=1507
  _globals['_SERVICEUSAGEREPORTENTITYDATA']._serialized_start=1510
  _globals['_SERVICEUSAGEREPORTENTITYDATA']._serialized_end=1904
  _globals['_SKUUSAGEREPORTENTITYDATA']._serialized_start=1907
  _globals['_SKUUSAGEREPORTENTITYDATA']._serialized_end=2369
  _globals['_RESOURCEUSAGEREPORTENTITYDATA']._serialized_start=2372
  _globals['_RESOURCEUSAGEREPORTENTITYDATA']._serialized_end=2769
  _globals['_LABELUSAGEREPORTENTITYDATA']._serialized_start=2772
  _globals['_LABELUSAGEREPORTENTITYDATA']._serialized_end=3160
  _globals['_USAGEREPORTPERIODICDATA']._serialized_start=3163
  _globals['_USAGEREPORTPERIODICDATA']._serialized_end=3452
# @@protoc_insertion_point(module_scope)
