# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/application/saml/application_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/application/saml/application_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.organizationmanager.v1.idp.application.saml import application_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_application_dot_saml_dot_application__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRyandex/cloud/organizationmanager/v1/idp/application/saml/application_service.proto\x12\x38yandex.cloud.organizationmanager.v1.idp.application.saml\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1aJyandex/cloud/organizationmanager/v1/idp/application/saml/application.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"=\n\x15GetApplicationRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x9b\x01\n\x17ListApplicationsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x90\x01\n\x18ListApplicationsResponse\x12[\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32\x45.yandex.cloud.organizationmanager.v1.idp.application.saml.Application\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9e\x06\n\x18\x43reateApplicationRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x04name\x18\x02 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\xab\x01\n\x06labels\x18\x04 \x03(\x0b\x32^.yandex.cloud.organizationmanager.v1.idp.application.saml.CreateApplicationRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x63\n\x10service_provider\x18\x05 \x01(\x0b\x32I.yandex.cloud.organizationmanager.v1.idp.application.saml.ServiceProvider\x12i\n\x11security_settings\x18\x06 \x01(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.application.saml.SecuritySettingsSpec\x12i\n\x11\x61ttribute_mapping\x18\x07 \x01(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.application.saml.AttributeMappingSpec\x12l\n\x15group_claims_settings\x18\x08 \x01(\x0b\x32M.yandex.cloud.organizationmanager.v1.idp.application.saml.GroupClaimsSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n\x14SecuritySettingsSpec\x12p\n\x0esignature_mode\x18\x01 \x01(\x0e\x32X.yandex.cloud.organizationmanager.v1.idp.application.saml.SecuritySettings.SignatureMode\"k\n\nNameIdSpec\x12]\n\x06\x66ormat\x18\x01 \x01(\x0e\x32G.yandex.cloud.organizationmanager.v1.idp.application.saml.NameId.FormatB\x04\xe8\xc7\x31\x01\"\xd6\x01\n\x14\x41ttributeMappingSpec\x12[\n\x07name_id\x18\x01 \x01(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.idp.application.saml.NameIdSpecB\x04\xe8\xc7\x31\x01\x12\x61\n\nattributes\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.idp.application.saml.AttributeB\x08\x82\xc8\x31\x04<=50\"3\n\x19\x43reateApplicationMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\"\xc7\x06\n\x18UpdateApplicationRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\xab\x01\n\x06labels\x18\x05 \x03(\x0b\x32^.yandex.cloud.organizationmanager.v1.idp.application.saml.UpdateApplicationRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x63\n\x10service_provider\x18\x06 \x01(\x0b\x32I.yandex.cloud.organizationmanager.v1.idp.application.saml.ServiceProvider\x12\x65\n\x11security_settings\x18\x07 \x01(\x0b\x32J.yandex.cloud.organizationmanager.v1.idp.application.saml.SecuritySettings\x12i\n\x11\x61ttribute_mapping\x18\x08 \x01(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.application.saml.AttributeMappingSpec\x12l\n\x15group_claims_settings\x18\t \x01(\x0b\x32M.yandex.cloud.organizationmanager.v1.idp.application.saml.GroupClaimsSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x19UpdateApplicationMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\"@\n\x18\x44\x65leteApplicationRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x19\x44\x65leteApplicationMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\"A\n\x19SuspendApplicationRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"4\n\x1aSuspendApplicationMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\"D\n\x1cReactivateApplicationRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"7\n\x1dReactivateApplicationMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\"%\n#ListSupportedAttributeValuesRequest\"\x9d\x01\n$ListSupportedAttributeValuesResponse\x12u\n\x1asupported_attribute_values\x18\x01 \x03(\x0b\x32Q.yandex.cloud.organizationmanager.v1.idp.application.saml.SupportedAttributeValue\"(\n\x17SupportedAttributeValue\x12\r\n\x05value\x18\x01 \x01(\t\"\x83\x01\n ListApplicationOperationsRequest\x12 \n\x0e\x61pplication_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"s\n!ListApplicationOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"/\n\nAssignment\x12!\n\nsubject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\"\xd3\x01\n\x0f\x41ssignmentDelta\x12`\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32J.yandex.cloud.organizationmanager.v1.idp.application.saml.AssignmentActionB\x04\xe8\xc7\x31\x01\x12^\n\nassignment\x18\x02 \x01(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.idp.application.saml.AssignmentB\x04\xe8\xc7\x31\x01\"\x81\x01\n\x19UpdateAssignmentsResponse\x12\x64\n\x11\x61ssignment_deltas\x18\x01 \x03(\x0b\x32I.yandex.cloud.organizationmanager.v1.idp.application.saml.AssignmentDelta\"}\n\x16ListAssignmentsRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\x8d\x01\n\x17ListAssignmentsResponse\x12Y\n\x0b\x61ssignments\x18\x01 \x03(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.idp.application.saml.Assignment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb2\x01\n\x18UpdateAssignmentsRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12p\n\x11\x61ssignment_deltas\x18\x02 \x03(\x0b\x32I.yandex.cloud.organizationmanager.v1.idp.application.saml.AssignmentDeltaB\n\x82\xc8\x31\x06\x31-1000\"3\n\x19UpdateAssignmentsMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t*J\n\x10\x41ssignmentAction\x12!\n\x1d\x41SSIGNMENT_ACTION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x32\x95\x1e\n\x12\x41pplicationService\x12\xf2\x01\n\x03Get\x12O.yandex.cloud.organizationmanager.v1.idp.application.saml.GetApplicationRequest\x1a\x45.yandex.cloud.organizationmanager.v1.idp.application.saml.Application\"S\x82\xd3\xe4\x93\x02M\x12K/organization-manager/v1/idp/application/saml/applications/{application_id}\x12\xf1\x01\n\x04List\x12Q.yandex.cloud.organizationmanager.v1.idp.application.saml.ListApplicationsRequest\x1aR.yandex.cloud.organizationmanager.v1.idp.application.saml.ListApplicationsResponse\"B\x82\xd3\xe4\x93\x02<\x12:/organization-manager/v1/idp/application/saml/applications\x12\xf2\x01\n\x06\x43reate\x12R.yandex.cloud.organizationmanager.v1.idp.application.saml.CreateApplicationRequest\x1a!.yandex.cloud.operation.Operation\"q\xb2\xd2*(\n\x19\x43reateApplicationMetadata\x12\x0b\x41pplication\x82\xd3\xe4\x93\x02?\":/organization-manager/v1/idp/application/saml/applications:\x01*\x12\x84\x02\n\x06Update\x12R.yandex.cloud.organizationmanager.v1.idp.application.saml.UpdateApplicationRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*(\n\x19UpdateApplicationMetadata\x12\x0b\x41pplication\x82\xd3\xe4\x93\x02P2K/organization-manager/v1/idp/application/saml/applications/{application_id}:\x01*\x12\x8b\x02\n\x06\x44\x65lete\x12R.yandex.cloud.organizationmanager.v1.idp.application.saml.DeleteApplicationRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*2\n\x19\x44\x65leteApplicationMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02M*K/organization-manager/v1/idp/application/saml/applications/{application_id}\x12\x8f\x02\n\x07Suspend\x12S.yandex.cloud.organizationmanager.v1.idp.application.saml.SuspendApplicationRequest\x1a!.yandex.cloud.operation.Operation\"\x8b\x01\xb2\xd2*)\n\x1aSuspendApplicationMetadata\x12\x0b\x41pplication\x82\xd3\xe4\x93\x02X\"S/organization-manager/v1/idp/application/saml/applications/{application_id}:suspend:\x01*\x12\x9b\x02\n\nReactivate\x12V.yandex.cloud.organizationmanager.v1.idp.application.saml.ReactivateApplicationRequest\x1a!.yandex.cloud.operation.Operation\"\x91\x01\xb2\xd2*,\n\x1dReactivateApplicationMetadata\x12\x0b\x41pplication\x82\xd3\xe4\x93\x02[\"V/organization-manager/v1/idp/application/saml/applications/{application_id}:reactivate:\x01*\x12\xbe\x02\n\x1cListSupportedAttributeValues\x12].yandex.cloud.organizationmanager.v1.idp.application.saml.ListSupportedAttributeValuesRequest\x1a^.yandex.cloud.organizationmanager.v1.idp.application.saml.ListSupportedAttributeValuesResponse\"_\x82\xd3\xe4\x93\x02Y\x12W/organization-manager/v1/idp/application/saml/applications:listSupportedAttributeValues\x12\xa9\x02\n\x0eListOperations\x12Z.yandex.cloud.organizationmanager.v1.idp.application.saml.ListApplicationOperationsRequest\x1a[.yandex.cloud.organizationmanager.v1.idp.application.saml.ListApplicationOperationsResponse\"^\x82\xd3\xe4\x93\x02X\x12V/organization-manager/v1/idp/application/saml/applications/{application_id}/operations\x12\xda\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"c\x82\xd3\xe4\x93\x02]\x12[/organization-manager/v1/idp/application/saml/applications/{resource_id}:listAccessBindings\x12\x99\x02\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\xb1\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02_\"Z/organization-manager/v1/idp/application/saml/applications/{resource_id}:setAccessBindings:\x01*\x12\xa5\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\xb7\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x62\x32]/organization-manager/v1/idp/application/saml/applications/{resource_id}:updateAccessBindings:\x01*\x12\x9b\x02\n\x0fListAssignments\x12P.yandex.cloud.organizationmanager.v1.idp.application.saml.ListAssignmentsRequest\x1aQ.yandex.cloud.organizationmanager.v1.idp.application.saml.ListAssignmentsResponse\"c\x82\xd3\xe4\x93\x02]\x12[/organization-manager/v1/idp/application/saml/applications/{application_id}:listAssignments\x12\xaf\x02\n\x11UpdateAssignments\x12R.yandex.cloud.organizationmanager.v1.idp.application.saml.UpdateAssignmentsRequest\x1a!.yandex.cloud.operation.Operation\"\xa2\x01\xb2\xd2*6\n\x19UpdateAssignmentsMetadata\x12\x19UpdateAssignmentsResponse\x82\xd3\xe4\x93\x02\x62\x32]/organization-manager/v1/idp/application/saml/applications/{application_id}:updateAssignments:\x01*B\xa1\x01\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;samlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.application.saml.application_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;saml'
  _globals['_GETAPPLICATIONREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_GETAPPLICATIONREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEAPPLICATIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_NAMEIDSPEC'].fields_by_name['format']._loaded_options = None
  _globals['_NAMEIDSPEC'].fields_by_name['format']._serialized_options = b'\350\3071\001'
  _globals['_ATTRIBUTEMAPPINGSPEC'].fields_by_name['name_id']._loaded_options = None
  _globals['_ATTRIBUTEMAPPINGSPEC'].fields_by_name['name_id']._serialized_options = b'\350\3071\001'
  _globals['_ATTRIBUTEMAPPINGSPEC'].fields_by_name['attributes']._loaded_options = None
  _globals['_ATTRIBUTEMAPPINGSPEC'].fields_by_name['attributes']._serialized_options = b'\202\3101\004<=50'
  _globals['_UPDATEAPPLICATIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEAPPLICATIONREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_DELETEAPPLICATIONREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SUSPENDAPPLICATIONREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_SUSPENDAPPLICATIONREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REACTIVATEAPPLICATIONREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_REACTIVATEAPPLICATIONREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['application_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_ASSIGNMENT'].fields_by_name['subject_id']._loaded_options = None
  _globals['_ASSIGNMENT'].fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_ASSIGNMENTDELTA'].fields_by_name['action']._loaded_options = None
  _globals['_ASSIGNMENTDELTA'].fields_by_name['action']._serialized_options = b'\350\3071\001'
  _globals['_ASSIGNMENTDELTA'].fields_by_name['assignment']._loaded_options = None
  _globals['_ASSIGNMENTDELTA'].fields_by_name['assignment']._serialized_options = b'\350\3071\001'
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_UPDATEASSIGNMENTSREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_UPDATEASSIGNMENTSREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEASSIGNMENTSREQUEST'].fields_by_name['assignment_deltas']._loaded_options = None
  _globals['_UPDATEASSIGNMENTSREQUEST'].fields_by_name['assignment_deltas']._serialized_options = b'\202\3101\0061-1000'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002M\022K/organization-manager/v1/idp/application/saml/applications/{application_id}'
  _globals['_APPLICATIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002<\022:/organization-manager/v1/idp/application/saml/applications'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateApplicationMetadata\022\013Application\202\323\344\223\002?\":/organization-manager/v1/idp/application/saml/applications:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateApplicationMetadata\022\013Application\202\323\344\223\002P2K/organization-manager/v1/idp/application/saml/applications/{application_id}:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteApplicationMetadata\022\025google.protobuf.Empty\202\323\344\223\002M*K/organization-manager/v1/idp/application/saml/applications/{application_id}'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Suspend']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Suspend']._serialized_options = b'\262\322*)\n\032SuspendApplicationMetadata\022\013Application\202\323\344\223\002X\"S/organization-manager/v1/idp/application/saml/applications/{application_id}:suspend:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Reactivate']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Reactivate']._serialized_options = b'\262\322*,\n\035ReactivateApplicationMetadata\022\013Application\202\323\344\223\002[\"V/organization-manager/v1/idp/application/saml/applications/{application_id}:reactivate:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListSupportedAttributeValues']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListSupportedAttributeValues']._serialized_options = b'\202\323\344\223\002Y\022W/organization-manager/v1/idp/application/saml/applications:listSupportedAttributeValues'
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002X\022V/organization-manager/v1/idp/application/saml/applications/{application_id}/operations'
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002]\022[/organization-manager/v1/idp/application/saml/applications/{resource_id}:listAccessBindings'
  _globals['_APPLICATIONSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002_\"Z/organization-manager/v1/idp/application/saml/applications/{resource_id}:setAccessBindings:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002b2]/organization-manager/v1/idp/application/saml/applications/{resource_id}:updateAccessBindings:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListAssignments']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListAssignments']._serialized_options = b'\202\323\344\223\002]\022[/organization-manager/v1/idp/application/saml/applications/{application_id}:listAssignments'
  _globals['_APPLICATIONSERVICE'].methods_by_name['UpdateAssignments']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['UpdateAssignments']._serialized_options = b'\262\322*6\n\031UpdateAssignmentsMetadata\022\031UpdateAssignmentsResponse\202\323\344\223\002b2]/organization-manager/v1/idp/application/saml/applications/{application_id}:updateAssignments:\001*'
  _globals['_ASSIGNMENTACTION']._serialized_start=4764
  _globals['_ASSIGNMENTACTION']._serialized_end=4838
  _globals['_GETAPPLICATIONREQUEST']._serialized_start=423
  _globals['_GETAPPLICATIONREQUEST']._serialized_end=484
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_start=487
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_end=642
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_start=645
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_end=789
  _globals['_CREATEAPPLICATIONREQUEST']._serialized_start=792
  _globals['_CREATEAPPLICATIONREQUEST']._serialized_end=1590
  _globals['_CREATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_start=1545
  _globals['_CREATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_end=1590
  _globals['_SECURITYSETTINGSSPEC']._serialized_start=1593
  _globals['_SECURITYSETTINGSSPEC']._serialized_end=1729
  _globals['_NAMEIDSPEC']._serialized_start=1731
  _globals['_NAMEIDSPEC']._serialized_end=1838
  _globals['_ATTRIBUTEMAPPINGSPEC']._serialized_start=1841
  _globals['_ATTRIBUTEMAPPINGSPEC']._serialized_end=2055
  _globals['_CREATEAPPLICATIONMETADATA']._serialized_start=2057
  _globals['_CREATEAPPLICATIONMETADATA']._serialized_end=2108
  _globals['_UPDATEAPPLICATIONREQUEST']._serialized_start=2111
  _globals['_UPDATEAPPLICATIONREQUEST']._serialized_end=2950
  _globals['_UPDATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_start=1545
  _globals['_UPDATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_end=1590
  _globals['_UPDATEAPPLICATIONMETADATA']._serialized_start=2952
  _globals['_UPDATEAPPLICATIONMETADATA']._serialized_end=3003
  _globals['_DELETEAPPLICATIONREQUEST']._serialized_start=3005
  _globals['_DELETEAPPLICATIONREQUEST']._serialized_end=3069
  _globals['_DELETEAPPLICATIONMETADATA']._serialized_start=3071
  _globals['_DELETEAPPLICATIONMETADATA']._serialized_end=3122
  _globals['_SUSPENDAPPLICATIONREQUEST']._serialized_start=3124
  _globals['_SUSPENDAPPLICATIONREQUEST']._serialized_end=3189
  _globals['_SUSPENDAPPLICATIONMETADATA']._serialized_start=3191
  _globals['_SUSPENDAPPLICATIONMETADATA']._serialized_end=3243
  _globals['_REACTIVATEAPPLICATIONREQUEST']._serialized_start=3245
  _globals['_REACTIVATEAPPLICATIONREQUEST']._serialized_end=3313
  _globals['_REACTIVATEAPPLICATIONMETADATA']._serialized_start=3315
  _globals['_REACTIVATEAPPLICATIONMETADATA']._serialized_end=3370
  _globals['_LISTSUPPORTEDATTRIBUTEVALUESREQUEST']._serialized_start=3372
  _globals['_LISTSUPPORTEDATTRIBUTEVALUESREQUEST']._serialized_end=3409
  _globals['_LISTSUPPORTEDATTRIBUTEVALUESRESPONSE']._serialized_start=3412
  _globals['_LISTSUPPORTEDATTRIBUTEVALUESRESPONSE']._serialized_end=3569
  _globals['_SUPPORTEDATTRIBUTEVALUE']._serialized_start=3571
  _globals['_SUPPORTEDATTRIBUTEVALUE']._serialized_end=3611
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST']._serialized_start=3614
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST']._serialized_end=3745
  _globals['_LISTAPPLICATIONOPERATIONSRESPONSE']._serialized_start=3747
  _globals['_LISTAPPLICATIONOPERATIONSRESPONSE']._serialized_end=3862
  _globals['_ASSIGNMENT']._serialized_start=3864
  _globals['_ASSIGNMENT']._serialized_end=3911
  _globals['_ASSIGNMENTDELTA']._serialized_start=3914
  _globals['_ASSIGNMENTDELTA']._serialized_end=4125
  _globals['_UPDATEASSIGNMENTSRESPONSE']._serialized_start=4128
  _globals['_UPDATEASSIGNMENTSRESPONSE']._serialized_end=4257
  _globals['_LISTASSIGNMENTSREQUEST']._serialized_start=4259
  _globals['_LISTASSIGNMENTSREQUEST']._serialized_end=4384
  _globals['_LISTASSIGNMENTSRESPONSE']._serialized_start=4387
  _globals['_LISTASSIGNMENTSRESPONSE']._serialized_end=4528
  _globals['_UPDATEASSIGNMENTSREQUEST']._serialized_start=4531
  _globals['_UPDATEASSIGNMENTSREQUEST']._serialized_end=4709
  _globals['_UPDATEASSIGNMENTSMETADATA']._serialized_start=4711
  _globals['_UPDATEASSIGNMENTSMETADATA']._serialized_end=4762
  _globals['_APPLICATIONSERVICE']._serialized_start=4841
  _globals['_APPLICATIONSERVICE']._serialized_end=8702
# @@protoc_insertion_point(module_scope)
