# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/usage_records/v1/common_types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/usage_records/v1/common_types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/billing/usage_records/v1/common_types.proto\x12%yandex.cloud.billing.usage_records.v1\"\x1e\n\rStringDecimal\x12\r\n\x05value\x18\x01 \x01(\t*b\n\x0cTimeGrouping\x12\x1d\n\x19TIME_GROUPING_UNSPECIFIED\x10\x00\x12\x07\n\x03\x44\x41Y\x10\x01\x12\x08\n\x04WEEK\x10\x02\x12\t\n\x05MONTH\x10\x03\x12\x0b\n\x07QUARTER\x10\x04\x12\x08\n\x04YEAR\x10\x05*H\n\x08\x43urrency\x12\x18\n\x14\x43URRENCY_UNSPECIFIED\x10\x00\x12\x07\n\x03RUB\x10\x01\x12\x07\n\x03USD\x10\x02\x12\x07\n\x03KZT\x10\x03\x12\x07\n\x03\x45UR\x10\x04\x42\x83\x01\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecordsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.usage_records.v1.common_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecords'
  _globals['_TIMEGROUPING']._serialized_start=131
  _globals['_TIMEGROUPING']._serialized_end=229
  _globals['_CURRENCY']._serialized_start=231
  _globals['_CURRENCY']._serialized_end=303
  _globals['_STRINGDECIMAL']._serialized_start=99
  _globals['_STRINGDECIMAL']._serialized_end=129
# @@protoc_insertion_point(module_scope)
