# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/stacklandlicenseapi/v1/license_server_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/stacklandlicenseapi/v1/license_server_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.marketplace.stacklandlicenseapi.v1 import license_server_pb2 as yandex_dot_cloud_dot_marketplace_dot_stacklandlicenseapi_dot_v1_dot_license__server__pb2
from yandex.cloud.marketplace.stacklandlicenseapi.v1 import sync_pb2 as yandex_dot_cloud_dot_marketplace_dot_stacklandlicenseapi_dot_v1_dot_sync__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLyandex/cloud/marketplace/stacklandlicenseapi/v1/license_server_service.proto\x12/yandex.cloud.marketplace.stacklandlicenseapi.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x44yandex/cloud/marketplace/stacklandlicenseapi/v1/license_server.proto\x1a:yandex/cloud/marketplace/stacklandlicenseapi/v1/sync.proto\x1a&yandex/cloud/operation/operation.proto2\xde\x03\n\x14LicenseServerService\x12\xe7\x01\n\x08Register\x12@.yandex.cloud.marketplace.stacklandlicenseapi.v1.RegisterRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*.\n\x1dRegisterLicenseServerMetadata\x12\rLicenseServer\x82\xd3\xe4\x93\x02>\"9/marketplace/stackland-license/v1/licenseServers:register:\x01*\x12\xdb\x01\n\tSyncUsage\x12<.yandex.cloud.marketplace.stacklandlicenseapi.v1.SyncRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*$\n\x11SyncUsageMetadata\x12\x0fSyncUsageResult\x82\xd3\xe4\x93\x02?\":/marketplace/stackland-license/v1/licenseServers:syncUsage:\x01*B\x9e\x01\n3yandex.cloud.api.marketplace.stacklandlicenseapi.v1Zggithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/stacklandlicenseapi/v1;stacklandlicenseapib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.stacklandlicenseapi.v1.license_server_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3yandex.cloud.api.marketplace.stacklandlicenseapi.v1Zggithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/stacklandlicenseapi/v1;stacklandlicenseapi'
  _globals['_LICENSESERVERSERVICE'].methods_by_name['Register']._loaded_options = None
  _globals['_LICENSESERVERSERVICE'].methods_by_name['Register']._serialized_options = b'\262\322*.\n\035RegisterLicenseServerMetadata\022\rLicenseServer\202\323\344\223\002>\"9/marketplace/stackland-license/v1/licenseServers:register:\001*'
  _globals['_LICENSESERVERSERVICE'].methods_by_name['SyncUsage']._loaded_options = None
  _globals['_LICENSESERVERSERVICE'].methods_by_name['SyncUsage']._serialized_options = b'\262\322*$\n\021SyncUsageMetadata\022\017SyncUsageResult\202\323\344\223\002?\":/marketplace/stackland-license/v1/licenseServers:syncUsage:\001*'
  _globals['_LICENSESERVERSERVICE']._serialized_start=364
  _globals['_LICENSESERVERSERVICE']._serialized_end=842
# @@protoc_insertion_point(module_scope)
