# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/usage_records/v1/consumption_core_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/usage_records/v1/consumption_core_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.billing.usage_records.v1 import billing_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_billing__types__pb2
from yandex.cloud.billing.usage_records.v1 import common_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_common__types__pb2
from yandex.cloud.billing.usage_records.v1 import credit_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_credit__pb2
from yandex.cloud.billing.usage_records.v1 import consumption_core_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_consumption__core__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDyandex/cloud/billing/usage_records/v1/consumption_core_service.proto\x12%yandex.cloud.billing.usage_records.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x39yandex/cloud/billing/usage_records/v1/billing_types.proto\x1a\x38yandex/cloud/billing/usage_records/v1/common_types.proto\x1a\x32yandex/cloud/billing/usage_records/v1/credit.proto\x1a<yandex/cloud/billing/usage_records/v1/consumption_core.proto\x1a\x1dyandex/cloud/validation.proto\"\x8c\x04\n\x12UsageReportRequest\x12 \n\x12\x62illing_account_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\nstart_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x11\n\tcloud_ids\x18\x04 \x03(\t\x12\x12\n\nfolder_ids\x18\x05 \x03(\t\x12\x13\n\x0bservice_ids\x18\x06 \x03(\t\x12\x0f\n\x07sku_ids\x18\x07 \x03(\t\x12U\n\x06labels\x18\x08 \x03(\x0b\x32\x45.yandex.cloud.billing.usage_records.v1.UsageReportRequest.LabelsEntry\x12\x14\n\x0cresource_ids\x18\t \x03(\t\x12O\n\x12\x61ggregation_period\x18\n \x01(\x0e\x32\x33.yandex.cloud.billing.usage_records.v1.TimeGrouping\x1a_\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.billing.usage_records.v1.LabelList:\x02\x38\x01\"\xa2\x03\n!BillingAccountUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12\x61\n\rentities_data\x18\x05 \x03(\x0b\x32J.yandex.cloud.billing.usage_records.v1.BillingAccountUsageReportEntityData\"\x90\x03\n\x18\x43loudUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12X\n\rentities_data\x18\x05 \x03(\x0b\x32\x41.yandex.cloud.billing.usage_records.v1.CloudUsageReportEntityData\"\x92\x03\n\x19\x46olderUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12Y\n\rentities_data\x18\x05 \x03(\x0b\x32\x42.yandex.cloud.billing.usage_records.v1.FolderUsageReportEntityData\"\x94\x03\n\x1aServiceUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12Z\n\rentities_data\x18\x05 \x03(\x0b\x32\x43.yandex.cloud.billing.usage_records.v1.ServiceUsageReportEntityData\"\x8c\x03\n\x16SKUUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12V\n\rentities_data\x18\x05 \x03(\x0b\x32?.yandex.cloud.billing.usage_records.v1.SKUUsageReportEntityData\"\x96\x03\n\x1bResourceUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12[\n\rentities_data\x18\x05 \x03(\x0b\x32\x44.yandex.cloud.billing.usage_records.v1.ResourceUsageReportEntityData\"\x93\x03\n\x1bLabelKeyUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12X\n\rentities_data\x18\x05 \x03(\x0b\x32\x41.yandex.cloud.billing.usage_records.v1.LabelUsageReportEntityData2\xc4\x08\n\x16\x43onsumptionCoreService\x12\xa3\x01\n\x1cGetBillingAccountUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1aH.yandex.cloud.billing.usage_records.v1.BillingAccountUsageReportResponse\x12\x91\x01\n\x13GetCloudUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a?.yandex.cloud.billing.usage_records.v1.CloudUsageReportResponse\x12\x93\x01\n\x14GetFolderUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a@.yandex.cloud.billing.usage_records.v1.FolderUsageReportResponse\x12\x95\x01\n\x15GetServiceUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a\x41.yandex.cloud.billing.usage_records.v1.ServiceUsageReportResponse\x12\x8d\x01\n\x11GetSKUUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a=.yandex.cloud.billing.usage_records.v1.SKUUsageReportResponse\x12\x97\x01\n\x16GetResourceUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a\x42.yandex.cloud.billing.usage_records.v1.ResourceUsageReportResponse\x12\x97\x01\n\x16GetLabelKeyUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a\x42.yandex.cloud.billing.usage_records.v1.LabelKeyUsageReportResponseB\x83\x01\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecordsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecords'
  _globals['_USAGEREPORTREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_USAGEREPORTREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_USAGEREPORTREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_USAGEREPORTREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001'
  _globals['_USAGEREPORTREQUEST'].fields_by_name['start_date']._loaded_options = None
  _globals['_USAGEREPORTREQUEST'].fields_by_name['start_date']._serialized_options = b'\350\3071\001'
  _globals['_USAGEREPORTREQUEST'].fields_by_name['end_date']._loaded_options = None
  _globals['_USAGEREPORTREQUEST'].fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _globals['_USAGEREPORTREQUEST']._serialized_start=407
  _globals['_USAGEREPORTREQUEST']._serialized_end=931
  _globals['_USAGEREPORTREQUEST_LABELSENTRY']._serialized_start=836
  _globals['_USAGEREPORTREQUEST_LABELSENTRY']._serialized_end=931
  _globals['_BILLINGACCOUNTUSAGEREPORTRESPONSE']._serialized_start=934
  _globals['_BILLINGACCOUNTUSAGEREPORTRESPONSE']._serialized_end=1352
  _globals['_CLOUDUSAGEREPORTRESPONSE']._serialized_start=1355
  _globals['_CLOUDUSAGEREPORTRESPONSE']._serialized_end=1755
  _globals['_FOLDERUSAGEREPORTRESPONSE']._serialized_start=1758
  _globals['_FOLDERUSAGEREPORTRESPONSE']._serialized_end=2160
  _globals['_SERVICEUSAGEREPORTRESPONSE']._serialized_start=2163
  _globals['_SERVICEUSAGEREPORTRESPONSE']._serialized_end=2567
  _globals['_SKUUSAGEREPORTRESPONSE']._serialized_start=2570
  _globals['_SKUUSAGEREPORTRESPONSE']._serialized_end=2966
  _globals['_RESOURCEUSAGEREPORTRESPONSE']._serialized_start=2969
  _globals['_RESOURCEUSAGEREPORTRESPONSE']._serialized_end=3375
  _globals['_LABELKEYUSAGEREPORTRESPONSE']._serialized_start=3378
  _globals['_LABELKEYUSAGEREPORTRESPONSE']._serialized_end=3781
  _globals['_CONSUMPTIONCORESERVICE']._serialized_start=3784
  _globals['_CONSUMPTIONCORESERVICE']._serialized_end=4876
# @@protoc_insertion_point(module_scope)
