"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CreateMfaEnforcementRequest._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: CreateMfaEnforcementRequest._Status.ValueType  # 0
        """status upspecified"""
        STATUS_ACTIVE: CreateMfaEnforcementRequest._Status.ValueType  # 1
        """active"""
        STATUS_INACTIVE: CreateMfaEnforcementRequest._Status.ValueType  # 2
        """inactive"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: CreateMfaEnforcementRequest.Status.ValueType  # 0
    """status upspecified"""
    STATUS_ACTIVE: CreateMfaEnforcementRequest.Status.ValueType  # 1
    """active"""
    STATUS_INACTIVE: CreateMfaEnforcementRequest.Status.ValueType  # 2
    """inactive"""

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    ACR_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    APPLY_AT_FIELD_NUMBER: builtins.int
    ENROLL_WINDOW_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """organization id of the MFA enforcement"""
    acr_id: builtins.str
    """acr id for the MFA enforcement. one of 'any-mfa' or 'phr',
    specification https://yandex.cloud/en/docs/organization/concepts/mfa?utm_referrer=https%3A%2F%2Fa.yandex-team.ru%2F#mfa-factors
    """
    status: global___CreateMfaEnforcementRequest.Status.ValueType
    """the MFA enforcement status"""
    name: builtins.str
    """the MFA enforcement name"""
    description: builtins.str
    """the MFA enforcement description"""
    @property
    def ttl(self) -> google.protobuf.duration_pb2.Duration:
        """the period during which the entered MFA factor will be considered valid and the
        corresponding acr will be regarded as satisfied
        max 1 year
        """

    @property
    def apply_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the MFA enforcement application start time"""

    @property
    def enroll_window(self) -> google.protobuf.duration_pb2.Duration:
        """the MFA enforcement enroll window"""

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        acr_id: builtins.str = ...,
        ttl: google.protobuf.duration_pb2.Duration | None = ...,
        status: global___CreateMfaEnforcementRequest.Status.ValueType = ...,
        apply_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        enroll_window: google.protobuf.duration_pb2.Duration | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["apply_at", b"apply_at", "enroll_window", b"enroll_window", "ttl", b"ttl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["acr_id", b"acr_id", "apply_at", b"apply_at", "description", b"description", "enroll_window", b"enroll_window", "name", b"name", "organization_id", b"organization_id", "status", b"status", "ttl", b"ttl"]) -> None: ...

global___CreateMfaEnforcementRequest = CreateMfaEnforcementRequest

@typing.final
class CreateMfaEnforcementMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """organization id of the MFA enforcement"""
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id", "organization_id", b"organization_id"]) -> None: ...

global___CreateMfaEnforcementMetadata = CreateMfaEnforcementMetadata

@typing.final
class UpdateMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UpdateMfaEnforcementRequest._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: UpdateMfaEnforcementRequest._Status.ValueType  # 0
        """status upspecified"""
        STATUS_ACTIVE: UpdateMfaEnforcementRequest._Status.ValueType  # 1
        """active"""
        STATUS_INACTIVE: UpdateMfaEnforcementRequest._Status.ValueType  # 2
        """inactive"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: UpdateMfaEnforcementRequest.Status.ValueType  # 0
    """status upspecified"""
    STATUS_ACTIVE: UpdateMfaEnforcementRequest.Status.ValueType  # 1
    """active"""
    STATUS_INACTIVE: UpdateMfaEnforcementRequest.Status.ValueType  # 2
    """inactive"""

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    ACR_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    APPLY_AT_FIELD_NUMBER: builtins.int
    ENROLL_WINDOW_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    acr_id: builtins.str
    """acr id for the MFA enforcement. one of 'any-mfa' or 'phr',
    specification https://yandex.cloud/en/docs/organization/concepts/mfa?utm_referrer=https%3A%2F%2Fa.yandex-team.ru%2F#mfa-factors
    """
    status: global___UpdateMfaEnforcementRequest.Status.ValueType
    """the MFA enforcement status"""
    name: builtins.str
    """the MFA enforcement name"""
    description: builtins.str
    """the MFA enforcement description"""
    @property
    def ttl(self) -> google.protobuf.duration_pb2.Duration:
        """the period during which the entered MFA factor will be considered valid and the
        corresponding acr will be regarded as satisfied
        max 1 year
        """

    @property
    def apply_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the MFA enforcement application start time"""

    @property
    def enroll_window(self) -> google.protobuf.duration_pb2.Duration:
        """the MFA enforcement enroll window"""

    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """field mask to specify which fields of the MFA enforcement resource should be updated"""

    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        acr_id: builtins.str = ...,
        ttl: google.protobuf.duration_pb2.Duration | None = ...,
        status: global___UpdateMfaEnforcementRequest.Status.ValueType = ...,
        apply_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        enroll_window: google.protobuf.duration_pb2.Duration | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["apply_at", b"apply_at", "enroll_window", b"enroll_window", "ttl", b"ttl", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["acr_id", b"acr_id", "apply_at", b"apply_at", "description", b"description", "enroll_window", b"enroll_window", "mfa_enforcement_id", b"mfa_enforcement_id", "name", b"name", "status", b"status", "ttl", b"ttl", "update_mask", b"update_mask"]) -> None: ...

global___UpdateMfaEnforcementRequest = UpdateMfaEnforcementRequest

@typing.final
class UpdateMfaEnforcementMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateMfaEnforcementMetadata = UpdateMfaEnforcementMetadata

@typing.final
class ActivateMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___ActivateMfaEnforcementRequest = ActivateMfaEnforcementRequest

@typing.final
class ActivateMfaEnforcementMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___ActivateMfaEnforcementMetadata = ActivateMfaEnforcementMetadata

@typing.final
class DeactivateMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___DeactivateMfaEnforcementRequest = DeactivateMfaEnforcementRequest

@typing.final
class DeactivateMfaEnforcementMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___DeactivateMfaEnforcementMetadata = DeactivateMfaEnforcementMetadata

@typing.final
class DeleteMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___DeleteMfaEnforcementRequest = DeleteMfaEnforcementRequest

@typing.final
class DeleteMfaEnforcementMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___DeleteMfaEnforcementMetadata = DeleteMfaEnforcementMetadata

@typing.final
class GetMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___GetMfaEnforcementRequest = GetMfaEnforcementRequest

@typing.final
class ListMfaEnforcementsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """organization id"""
    page_size: builtins.int
    """the maximum number of results per page to return"""
    page_token: builtins.str
    """page token"""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListMfaEnforcementsRequest = ListMfaEnforcementsRequest

@typing.final
class ListMfaEnforcementsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """token to get the next page of results"""
    @property
    def mfa_enforcements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2.MfaEnforcement]:
        """list of MFA enforcements for the specified organization"""

    def __init__(
        self,
        *,
        mfa_enforcements: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2.MfaEnforcement] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcements", b"mfa_enforcements", "next_page_token", b"next_page_token"]) -> None: ...

global___ListMfaEnforcementsResponse = ListMfaEnforcementsResponse

@typing.final
class UpdateAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    AUDIENCE_DELTAS_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    @property
    def audience_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudienceDelta]:
        """MFA enforcement's audience to update"""

    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        audience_deltas: collections.abc.Iterable[global___AudienceDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["audience_deltas", b"audience_deltas", "mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateAudienceRequest = UpdateAudienceRequest

@typing.final
class UpdateAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    EFFECTIVE_DELTAS_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    @property
    def effective_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudienceDelta]:
        """updated MFA enforcement's audience"""

    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        effective_deltas: collections.abc.Iterable[global___AudienceDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["effective_deltas", b"effective_deltas", "mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateAudienceResponse = UpdateAudienceResponse

@typing.final
class AudienceDelta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AudienceDelta._Action.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACTION_UNSPECIFIED: AudienceDelta._Action.ValueType  # 0
        """action unspecified"""
        ACTION_ADD: AudienceDelta._Action.ValueType  # 1
        """add subject to audience"""
        ACTION_REMOVE: AudienceDelta._Action.ValueType  # 2
        """remove subject from audience"""

    class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
    ACTION_UNSPECIFIED: AudienceDelta.Action.ValueType  # 0
    """action unspecified"""
    ACTION_ADD: AudienceDelta.Action.ValueType  # 1
    """add subject to audience"""
    ACTION_REMOVE: AudienceDelta.Action.ValueType  # 2
    """remove subject from audience"""

    ACTION_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    action: global___AudienceDelta.Action.ValueType
    """action to perform"""
    subject_id: builtins.str
    """subject id"""
    def __init__(
        self,
        *,
        action: global___AudienceDelta.Action.ValueType = ...,
        subject_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "subject_id", b"subject_id"]) -> None: ...

global___AudienceDelta = AudienceDelta

@typing.final
class UpdateAudienceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateAudienceMetadata = UpdateAudienceMetadata

@typing.final
class ListAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    page_size: builtins.int
    """the maximum number of results per page to return"""
    page_token: builtins.str
    """page token"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAudienceRequest = ListAudienceRequest

@typing.final
class ListAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Subject(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        id: builtins.str
        """subject id"""
        type: builtins.str
        """subject type"""
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            type: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["id", b"id", "type", b"type"]) -> None: ...

    SUBJECTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """token to get the next page of results"""
    @property
    def subjects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListAudienceResponse.Subject]:
        """MFA enforcement's audience"""

    def __init__(
        self,
        *,
        subjects: collections.abc.Iterable[global___ListAudienceResponse.Subject] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "subjects", b"subjects"]) -> None: ...

global___ListAudienceResponse = ListAudienceResponse

@typing.final
class UpdateExcludedAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    AUDIENCE_DELTAS_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    @property
    def audience_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudienceDelta]:
        """updated MFA enforcement's excluded audience"""

    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        audience_deltas: collections.abc.Iterable[global___AudienceDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["audience_deltas", b"audience_deltas", "mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateExcludedAudienceRequest = UpdateExcludedAudienceRequest

@typing.final
class UpdateExcludedAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    EFFECTIVE_DELTAS_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    @property
    def effective_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudienceDelta]:
        """updated MFA enforcement's excluded audience"""

    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        effective_deltas: collections.abc.Iterable[global___AudienceDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["effective_deltas", b"effective_deltas", "mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateExcludedAudienceResponse = UpdateExcludedAudienceResponse

@typing.final
class UpdateExcludedAudienceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateExcludedAudienceMetadata = UpdateExcludedAudienceMetadata

@typing.final
class ListExcludedAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    page_size: builtins.int
    """the maximum number of results per page to return"""
    page_token: builtins.str
    """page token"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListExcludedAudienceRequest = ListExcludedAudienceRequest

@typing.final
class ListExcludedAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Subject(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        id: builtins.str
        """subject id"""
        type: builtins.str
        """subject type"""
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            type: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["id", b"id", "type", b"type"]) -> None: ...

    SUBJECTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """token to get the next page of results"""
    @property
    def subjects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListExcludedAudienceResponse.Subject]:
        """MFA enforcement's audience"""

    def __init__(
        self,
        *,
        subjects: collections.abc.Iterable[global___ListExcludedAudienceResponse.Subject] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "subjects", b"subjects"]) -> None: ...

global___ListExcludedAudienceResponse = ListExcludedAudienceResponse
