# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/public_prefix_pool_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/public_prefix_pool_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.baremetal.v1alpha import public_prefix_pool_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_public__prefix__pool__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?yandex/cloud/baremetal/v1alpha/public_prefix_pool_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x37yandex/cloud/baremetal/v1alpha/public_prefix_pool.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"Y\n\x1aGetPublicPrefixPoolRequest\x12;\n\x15public_prefix_pool_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=20\"\x8b\x01\n\x1bListPublicPrefixPoolRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x1d\n\tpage_size\x18\x64 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\tJ\x04\x08\x02\x10\x64\"\x8c\x01\n\x1cListPublicPrefixPoolResponse\x12M\n\x13public_prefix_pools\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.baremetal.v1alpha.PublicPrefixPool\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xb4\x03\n\x1dUpdatePublicPrefixPoolRequest\x12;\n\x15public_prefix_pool_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=20\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-63\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x97\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32I.yandex.cloud.baremetal.v1alpha.UpdatePublicPrefixPoolRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x05\x10\xc8\x01\"?\n\x1e\x43reatePublicPrefixPoolMetadata\x12\x1d\n\x15public_prefix_pool_id\x18\x01 \x01(\t\"?\n\x1eUpdatePublicPrefixPoolMetadata\x12\x1d\n\x15public_prefix_pool_id\x18\x01 \x01(\t\"?\n\x1e\x44\x65letePublicPrefixPoolMetadata\x12\x1d\n\x15public_prefix_pool_id\x18\x01 \x01(\t\"\x7f\n%ListPublicPrefixPoolOperationsRequest\x12\x1d\n\x15public_prefix_pool_id\x18\x01 \x01(\t\x12\x1d\n\tpage_size\x18\x64 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x12\n\npage_token\x18\x65 \x01(\tJ\x04\x08\x02\x10\x64\"~\n&ListPublicPrefixPoolOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\x32\xdf\x04\n\x17PublicPrefixPoolService\x12u\n\x03Get\x12:.yandex.cloud.baremetal.v1alpha.GetPublicPrefixPoolRequest\x1a\x30.yandex.cloud.baremetal.v1alpha.PublicPrefixPool\"\x00\x12\x83\x01\n\x04List\x12;.yandex.cloud.baremetal.v1alpha.ListPublicPrefixPoolRequest\x1a<.yandex.cloud.baremetal.v1alpha.ListPublicPrefixPoolResponse\"\x00\x12\xa2\x01\n\x06Update\x12=.yandex.cloud.baremetal.v1alpha.UpdatePublicPrefixPoolRequest\x1a!.yandex.cloud.operation.Operation\"6\xb2\xd2*2\n\x1eUpdatePublicPrefixPoolMetadata\x12\x10PublicPrefixPool\x12\xa1\x01\n\x0eListOperations\x12\x45.yandex.cloud.baremetal.v1alpha.ListPublicPrefixPoolOperationsRequest\x1a\x46.yandex.cloud.baremetal.v1alpha.ListPublicPrefixPoolOperationsResponse\"\x00\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.public_prefix_pool_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETPUBLICPREFIXPOOLREQUEST'].fields_by_name['public_prefix_pool_id']._loaded_options = None
  _globals['_GETPUBLICPREFIXPOOLREQUEST'].fields_by_name['public_prefix_pool_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=20'
  _globals['_LISTPUBLICPREFIXPOOLREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPUBLICPREFIXPOOLREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['public_prefix_pool_id']._loaded_options = None
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['public_prefix_pool_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=20'
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-63'
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_PUBLICPREFIXPOOLSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PUBLICPREFIXPOOLSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*2\n\036UpdatePublicPrefixPoolMetadata\022\020PublicPrefixPool'
  _globals['_GETPUBLICPREFIXPOOLREQUEST']._serialized_start=295
  _globals['_GETPUBLICPREFIXPOOLREQUEST']._serialized_end=384
  _globals['_LISTPUBLICPREFIXPOOLREQUEST']._serialized_start=387
  _globals['_LISTPUBLICPREFIXPOOLREQUEST']._serialized_end=526
  _globals['_LISTPUBLICPREFIXPOOLRESPONSE']._serialized_start=529
  _globals['_LISTPUBLICPREFIXPOOLRESPONSE']._serialized_end=669
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST']._serialized_start=672
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST']._serialized_end=1108
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST_LABELSENTRY']._serialized_start=1056
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST_LABELSENTRY']._serialized_end=1101
  _globals['_CREATEPUBLICPREFIXPOOLMETADATA']._serialized_start=1110
  _globals['_CREATEPUBLICPREFIXPOOLMETADATA']._serialized_end=1173
  _globals['_UPDATEPUBLICPREFIXPOOLMETADATA']._serialized_start=1175
  _globals['_UPDATEPUBLICPREFIXPOOLMETADATA']._serialized_end=1238
  _globals['_DELETEPUBLICPREFIXPOOLMETADATA']._serialized_start=1240
  _globals['_DELETEPUBLICPREFIXPOOLMETADATA']._serialized_end=1303
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSREQUEST']._serialized_start=1305
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSREQUEST']._serialized_end=1432
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSRESPONSE']._serialized_start=1434
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSRESPONSE']._serialized_end=1560
  _globals['_PUBLICPREFIXPOOLSERVICE']._serialized_start=1563
  _globals['_PUBLICPREFIXPOOLSERVICE']._serialized_end=2170
# @@protoc_insertion_point(module_scope)
