"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _LogErrorVerbosity:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogErrorVerbosityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogErrorVerbosity.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOG_ERROR_VERBOSITY_UNSPECIFIED: _LogErrorVerbosity.ValueType  # 0
    TERSE: _LogErrorVerbosity.ValueType  # 1
    DEFAULT: _LogErrorVerbosity.ValueType  # 2
    VERBOSE: _LogErrorVerbosity.ValueType  # 3

class LogErrorVerbosity(_LogErrorVerbosity, metaclass=_LogErrorVerbosityEnumTypeWrapper): ...

LOG_ERROR_VERBOSITY_UNSPECIFIED: LogErrorVerbosity.ValueType  # 0
TERSE: LogErrorVerbosity.ValueType  # 1
DEFAULT: LogErrorVerbosity.ValueType  # 2
VERBOSE: LogErrorVerbosity.ValueType  # 3
global___LogErrorVerbosity = LogErrorVerbosity

class _LogLevelMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogLevelMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogLevelMessage.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOG_LEVEL_MESSAGE_UNSPECIFIED: _LogLevelMessage.ValueType  # 0
    DEBUG5: _LogLevelMessage.ValueType  # 1
    DEBUG4: _LogLevelMessage.ValueType  # 2
    DEBUG3: _LogLevelMessage.ValueType  # 3
    DEBUG2: _LogLevelMessage.ValueType  # 4
    DEBUG1: _LogLevelMessage.ValueType  # 5
    INFO: _LogLevelMessage.ValueType  # 6
    NOTICE: _LogLevelMessage.ValueType  # 7
    WARNING: _LogLevelMessage.ValueType  # 8
    ERROR: _LogLevelMessage.ValueType  # 9
    FATAL: _LogLevelMessage.ValueType  # 10
    PANIC: _LogLevelMessage.ValueType  # 11

class LogLevelMessage(_LogLevelMessage, metaclass=_LogLevelMessageEnumTypeWrapper): ...

LOG_LEVEL_MESSAGE_UNSPECIFIED: LogLevelMessage.ValueType  # 0
DEBUG5: LogLevelMessage.ValueType  # 1
DEBUG4: LogLevelMessage.ValueType  # 2
DEBUG3: LogLevelMessage.ValueType  # 3
DEBUG2: LogLevelMessage.ValueType  # 4
DEBUG1: LogLevelMessage.ValueType  # 5
INFO: LogLevelMessage.ValueType  # 6
NOTICE: LogLevelMessage.ValueType  # 7
WARNING: LogLevelMessage.ValueType  # 8
ERROR: LogLevelMessage.ValueType  # 9
FATAL: LogLevelMessage.ValueType  # 10
PANIC: LogLevelMessage.ValueType  # 11
global___LogLevelMessage = LogLevelMessage

class _LogStatement:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogStatementEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogStatement.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOG_STATEMENT_UNSPECIFIED: _LogStatement.ValueType  # 0
    """LogStatement not explicitly set (uses defaults)."""
    NONE: _LogStatement.ValueType  # 1
    """None statements are logged."""
    DDL: _LogStatement.ValueType  # 2
    """Logs all data definition commands like `CREATE`, `ALTER`, and `DROP`. Default value."""
    MOD: _LogStatement.ValueType  # 3
    """Logs all `DDL` statements, plus `INSERT`, `UPDATE`, `DELETE`, `TRUNCATE`, and `COPY FROM`."""
    ALL: _LogStatement.ValueType  # 4
    """Logs all statements."""

class LogStatement(_LogStatement, metaclass=_LogStatementEnumTypeWrapper): ...

LOG_STATEMENT_UNSPECIFIED: LogStatement.ValueType  # 0
"""LogStatement not explicitly set (uses defaults)."""
NONE: LogStatement.ValueType  # 1
"""None statements are logged."""
DDL: LogStatement.ValueType  # 2
"""Logs all data definition commands like `CREATE`, `ALTER`, and `DROP`. Default value."""
MOD: LogStatement.ValueType  # 3
"""Logs all `DDL` statements, plus `INSERT`, `UPDATE`, `DELETE`, `TRUNCATE`, and `COPY FROM`."""
ALL: LogStatement.ValueType  # 4
"""Logs all statements."""
global___LogStatement = LogStatement

class _GPAutostatsMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GPAutostatsModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GPAutostatsMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GP_AUTOSTATS_MODE_UNSPECIFIED: _GPAutostatsMode.ValueType  # 0
    """GPAutostatsMode not explicitly set (uses defaults)."""
    GP_AUTOSTATS_MODE_NONE: _GPAutostatsMode.ValueType  # 1
    """Disable auto-ANALYZE completely. Stats will be updated only via manual ANALYZE calls."""
    GP_AUTOSTATS_MODE_ON_CHANGE: _GPAutostatsMode.ValueType  # 2
    """Run ANALYZE when data changes exceed threshold (e.g., after INSERT/UPDATE/DELETE)."""
    GP_AUTOSTATS_MODE_ON_NO_STATS: _GPAutostatsMode.ValueType  # 3
    """Run ANALYZE only if no stats exist (e.g., new or cleared table)."""

class GPAutostatsMode(_GPAutostatsMode, metaclass=_GPAutostatsModeEnumTypeWrapper):
    """Specifies the mode for triggering automatic statistics collection with ANALYZE.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_autostats_mode
    """

GP_AUTOSTATS_MODE_UNSPECIFIED: GPAutostatsMode.ValueType  # 0
"""GPAutostatsMode not explicitly set (uses defaults)."""
GP_AUTOSTATS_MODE_NONE: GPAutostatsMode.ValueType  # 1
"""Disable auto-ANALYZE completely. Stats will be updated only via manual ANALYZE calls."""
GP_AUTOSTATS_MODE_ON_CHANGE: GPAutostatsMode.ValueType  # 2
"""Run ANALYZE when data changes exceed threshold (e.g., after INSERT/UPDATE/DELETE)."""
GP_AUTOSTATS_MODE_ON_NO_STATS: GPAutostatsMode.ValueType  # 3
"""Run ANALYZE only if no stats exist (e.g., new or cleared table)."""
global___GPAutostatsMode = GPAutostatsMode

@typing.final
class Resources(google.protobuf.message.Message):
    """A list of computational resources allocated to a host."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources allocated to a host.

    Available presets are listed in the [documentation](/docs/managed-greenplum/concepts/instance-types).
    """
    disk_size: builtins.int
    """Volume of the storage used by the host, in bytes."""
    disk_type_id: builtins.str
    """Type of the storage used by the host: `network-hdd`, `network-ssd` or `local-ssd`."""
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class ConnectionPoolerConfig(google.protobuf.message.Message):
    """Route server configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PoolMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PoolModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ConnectionPoolerConfig._PoolMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        POOL_MODE_UNSPECIFIED: ConnectionPoolerConfig._PoolMode.ValueType  # 0
        """PoolMode not explicitly set (uses defaults)."""
        SESSION: ConnectionPoolerConfig._PoolMode.ValueType  # 1
        """Assign server connection to a client until it disconnects. Default value."""
        TRANSACTION: ConnectionPoolerConfig._PoolMode.ValueType  # 2
        """Assign server connection to a client for a transaction processing."""

    class PoolMode(_PoolMode, metaclass=_PoolModeEnumTypeWrapper):
        """Route server pool mode."""

    POOL_MODE_UNSPECIFIED: ConnectionPoolerConfig.PoolMode.ValueType  # 0
    """PoolMode not explicitly set (uses defaults)."""
    SESSION: ConnectionPoolerConfig.PoolMode.ValueType  # 1
    """Assign server connection to a client until it disconnects. Default value."""
    TRANSACTION: ConnectionPoolerConfig.PoolMode.ValueType  # 2
    """Assign server connection to a client for a transaction processing."""

    MODE_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    CLIENT_IDLE_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_TIMEOUT_FIELD_NUMBER: builtins.int
    mode: global___ConnectionPoolerConfig.PoolMode.ValueType
    """Route server pool mode."""
    @property
    def size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of servers in the server pool. Clients are placed in a wait queue when all servers are busy.

        Set to zero to disable the limit.
        """

    @property
    def client_idle_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Client pool idle timeout, in seconds.

        Drop stale client connection after this much seconds of idleness, which is not in transaction.

        Set to zero to disable.
        """

    @property
    def idle_in_transaction_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Client pool idle in transaction timeout, in seconds.

        Drop client connection in transaction after this much seconds of idleness.

        Set to zero to disable.
        """

    def __init__(
        self,
        *,
        mode: global___ConnectionPoolerConfig.PoolMode.ValueType = ...,
        size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        client_idle_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        idle_in_transaction_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["client_idle_timeout", b"client_idle_timeout", "idle_in_transaction_timeout", b"idle_in_transaction_timeout", "size", b"size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["client_idle_timeout", b"client_idle_timeout", "idle_in_transaction_timeout", b"idle_in_transaction_timeout", "mode", b"mode", "size", b"size"]) -> None: ...

global___ConnectionPoolerConfig = ConnectionPoolerConfig

@typing.final
class BackgroundActivityStartAt(google.protobuf.message.Message):
    """Start time for background activity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOURS_FIELD_NUMBER: builtins.int
    MINUTES_FIELD_NUMBER: builtins.int
    hours: builtins.int
    """hours"""
    minutes: builtins.int
    """minutes"""
    def __init__(
        self,
        *,
        hours: builtins.int = ...,
        minutes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hours", b"hours", "minutes", b"minutes"]) -> None: ...

global___BackgroundActivityStartAt = BackgroundActivityStartAt

@typing.final
class TableSizes(google.protobuf.message.Message):
    """Enables scripts that collects tables sizes to `*_sizes` tables in `mdb_toolkit` schema."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STARTS_FIELD_NUMBER: builtins.int
    @property
    def starts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BackgroundActivityStartAt]:
        """Time when start "table_sizes" script"""

    def __init__(
        self,
        *,
        starts: collections.abc.Iterable[global___BackgroundActivityStartAt] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["starts", b"starts"]) -> None: ...

global___TableSizes = TableSizes

@typing.final
class AnalyzeAndVacuum(google.protobuf.message.Message):
    """Configuration for `ANALYZE` and `VACUUM` operations."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_FIELD_NUMBER: builtins.int
    ANALYZE_TIMEOUT_FIELD_NUMBER: builtins.int
    VACUUM_TIMEOUT_FIELD_NUMBER: builtins.int
    @property
    def start(self) -> global___BackgroundActivityStartAt:
        """Time when analyze will start"""

    @property
    def analyze_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum duration of the `ANALYZE` operation, in seconds. The default value is `36000`. As soon as this period expires, the `ANALYZE` operation will be forced to terminate."""

    @property
    def vacuum_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum duration of the `VACUUM` operation, in seconds. The default value is `36000`. As soon as this period expires, the `VACUUM` operation will be forced to terminate."""

    def __init__(
        self,
        *,
        start: global___BackgroundActivityStartAt | None = ...,
        analyze_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["analyze_timeout", b"analyze_timeout", "start", b"start", "vacuum_timeout", b"vacuum_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["analyze_timeout", b"analyze_timeout", "start", b"start", "vacuum_timeout", b"vacuum_timeout"]) -> None: ...

global___AnalyzeAndVacuum = AnalyzeAndVacuum

@typing.final
class BackgroundActivitiesConfig(google.protobuf.message.Message):
    """Configuration for long running queries killer."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_SIZES_FIELD_NUMBER: builtins.int
    ANALYZE_AND_VACUUM_FIELD_NUMBER: builtins.int
    QUERY_KILLER_SCRIPTS_FIELD_NUMBER: builtins.int
    @property
    def table_sizes(self) -> global___TableSizes:
        """Enables scripts that collects tables sizes to `*_sizes` tables in `mdb_toolkit` schema."""

    @property
    def analyze_and_vacuum(self) -> global___AnalyzeAndVacuum:
        """Configuration for `ANALYZE` and `VACUUM` operations."""

    @property
    def query_killer_scripts(self) -> global___QueryKillerScripts:
        """Configuration for long running queries killer."""

    def __init__(
        self,
        *,
        table_sizes: global___TableSizes | None = ...,
        analyze_and_vacuum: global___AnalyzeAndVacuum | None = ...,
        query_killer_scripts: global___QueryKillerScripts | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["analyze_and_vacuum", b"analyze_and_vacuum", "query_killer_scripts", b"query_killer_scripts", "table_sizes", b"table_sizes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["analyze_and_vacuum", b"analyze_and_vacuum", "query_killer_scripts", b"query_killer_scripts", "table_sizes", b"table_sizes"]) -> None: ...

global___BackgroundActivitiesConfig = BackgroundActivitiesConfig

@typing.final
class QueryKiller(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    IGNORE_USERS_FIELD_NUMBER: builtins.int
    @property
    def enable(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Use query killer or not"""

    @property
    def max_age(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum duration for this type of queries (in seconds)."""

    @property
    def ignore_users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Ignore these users when considering queries to terminate"""

    def __init__(
        self,
        *,
        enable: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_age: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ignore_users: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enable", b"enable", "max_age", b"max_age"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["enable", b"enable", "ignore_users", b"ignore_users", "max_age", b"max_age"]) -> None: ...

global___QueryKiller = QueryKiller

@typing.final
class QueryKillerScripts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDLE_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_FIELD_NUMBER: builtins.int
    LONG_RUNNING_FIELD_NUMBER: builtins.int
    @property
    def idle(self) -> global___QueryKiller:
        """Configuration of script that kills long running queries that are in `idle` state."""

    @property
    def idle_in_transaction(self) -> global___QueryKiller:
        """Configuration of script that kills long running queries that are in `idle in transaction` state."""

    @property
    def long_running(self) -> global___QueryKiller:
        """Configuration of script that kills long running queries (in any state)."""

    def __init__(
        self,
        *,
        idle: global___QueryKiller | None = ...,
        idle_in_transaction: global___QueryKiller | None = ...,
        long_running: global___QueryKiller | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["idle", b"idle", "idle_in_transaction", b"idle_in_transaction", "long_running", b"long_running"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["idle", b"idle", "idle_in_transaction", b"idle_in_transaction", "long_running", b"long_running"]) -> None: ...

global___QueryKillerScripts = QueryKillerScripts

@typing.final
class MasterSubclusterConfig(google.protobuf.message.Message):
    """Configuration of the master subcluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> global___Resources:
        """Computational resources allocated to Greenplum® master subcluster hosts."""

    def __init__(
        self,
        *,
        resources: global___Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___MasterSubclusterConfig = MasterSubclusterConfig

@typing.final
class SegmentSubclusterConfig(google.protobuf.message.Message):
    """Configuration of the segment subcluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> global___Resources:
        """Computational resources allocated to Greenplum® segment subcluster hosts."""

    def __init__(
        self,
        *,
        resources: global___Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___SegmentSubclusterConfig = SegmentSubclusterConfig

@typing.final
class GreenplumConfig6(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_SLOT_WAL_KEEP_SIZE_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_SEGMENT_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_QUERY_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_FILES_PER_QUERY_FIELD_NUMBER: builtins.int
    MAX_PREPARED_TRANSACTIONS_FIELD_NUMBER: builtins.int
    GP_WORKFILE_COMPRESSION_FIELD_NUMBER: builtins.int
    MAX_STATEMENT_MEM_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    GP_ADD_COLUMN_INHERITS_TABLE_SETTING_FIELD_NUMBER: builtins.int
    GP_ENABLE_GLOBAL_DEADLOCK_DETECTOR_FIELD_NUMBER: builtins.int
    GP_GLOBAL_DEADLOCK_DETECTOR_PERIOD_FIELD_NUMBER: builtins.int
    GP_MAX_SLICES_FIELD_NUMBER: builtins.int
    GP_CACHED_SEGWORKERS_THRESHOLD_FIELD_NUMBER: builtins.int
    LOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    RUNAWAY_DETECTOR_ACTIVATION_PERCENT_FIELD_NUMBER: builtins.int
    GP_VMEM_PROTECT_SEGWORKER_CACHE_LIMIT_FIELD_NUMBER: builtins.int
    GP_ENABLE_ZSTD_MEMORY_ACCOUNTING_FIELD_NUMBER: builtins.int
    GP_MAX_PLAN_SIZE_FIELD_NUMBER: builtins.int
    GP_AUTOSTATS_MODE_FIELD_NUMBER: builtins.int
    GP_AUTOSTATS_ON_CHANGE_THRESHOLD_FIELD_NUMBER: builtins.int
    GP_RESOURCE_GROUP_MEMORY_LIMIT_FIELD_NUMBER: builtins.int
    LOG_CONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DISCONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_HOSTNAME_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_STATS_FIELD_NUMBER: builtins.int
    LOG_MIN_DURATION_STATEMENT_FIELD_NUMBER: builtins.int
    MASTER_SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    MAX_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    SEGMENT_SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    LOG_ERROR_VERBOSITY_FIELD_NUMBER: builtins.int
    LOG_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    log_statement: global___LogStatement.ValueType
    """Controls which SQL statements are logged. DDL logs all data definition commands like CREATE, ALTER, and DROP commands.
    MOD logs all DDL statements, plus INSERT, UPDATE, DELETE, TRUNCATE, and COPY FROM.
    PREPARE and EXPLAIN ANALYZE statements are also logged if their contained command is of an appropriate type.
    https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#log_statement
    Default value is ddl
    """
    gp_autostats_mode: global___GPAutostatsMode.ValueType
    """Specifies the mode for triggering automatic statistics collection after DML.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_autostats_mode
    """
    log_error_verbosity: global___LogErrorVerbosity.ValueType
    """Controls the amount of detail written in the server log for each message that is logged.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_error_verbosity
    """
    log_min_messages: global___LogLevelMessage.ValueType
    """Controls which message levels are written to the server log.
    Each level includes all the levels that follow it. The later the level, the fewer messages are sent to the log.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_min_messages
    """
    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of inbound connections on master segment"""

    @property
    def max_slot_wal_keep_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specify the maximum size of WAL files that replication slots are allowed to retain in the pg_wal directory at checkpoint time.
        https://www.postgresql.org/docs/current/runtime-config-replication.html
        """

    @property
    def gp_workfile_limit_per_segment(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum total disk size that all running queries are allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_limit_per_segment
        """

    @property
    def gp_workfile_limit_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum disk size an individual query is allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_limit_per_query
        """

    @property
    def gp_workfile_limit_files_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of temporary spill files (also known as workfiles) allowed per query per segment.
        Spill files are created when executing a query that requires more memory than it is allocated.
        The current query is terminated when the limit is exceeded.
        Set the value to 0 (zero) to allow an unlimited number of spill files. master session reload
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_limit_files_per_query
        Default value is 10000
        """

    @property
    def max_prepared_transactions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of transactions that can be in the "prepared" state simultaneously
        https://www.postgresql.org/docs/9.6/runtime-config-resource.html
        """

    @property
    def gp_workfile_compression(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies whether the temporary files created, when a hash aggregation or hash join operation spills to disk, are compressed.
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_compression
        """

    @property
    def max_statement_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum memory limit for a query. Helps avoid out-of-memory errors on a segment host during query processing as a result of setting statement_mem too high.
        Taking into account the configuration of a single segment host, calculate max_statement_mem as follows:
        (seghost_physical_memory) / (average_number_concurrent_queries)
        When changing both max_statement_mem and statement_mem, max_statement_mem must be changed first, or listed first in the postgresql.conf file.
        https://greenplum.docs.pivotal.io/6-19/ref_guide/config_params/guc-list.html#max_statement_mem
        Default value is 2097152000 (2000MB)
        in bytes
        """

    @property
    def gp_add_column_inherits_table_setting(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_add_column_inherits_table_setting"""

    @property
    def gp_enable_global_deadlock_detector(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Controls whether the Greenplum Database Global Deadlock Detector is enabled to manage concurrent UPDATE and DELETE operations on heap tables to improve performance. See Inserting, Updating, and Deleting Datain the Greenplum Database Administrator Guide. The default is off, the Global Deadlock Detector is deactivated.
        If the Global Deadlock Detector is deactivated (the default), Greenplum Database runs concurrent update and delete operations on a heap table serially.
        If the Global Deadlock Detector is enabled, concurrent updates are permitted and the Global Deadlock Detector determines when a deadlock exists, and breaks the deadlock by cancelling one or more backend processes associated with the youngest transaction(s) involved.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_enable_global_deadlock_detector
        """

    @property
    def gp_global_deadlock_detector_period(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the executing interval (in seconds) of the global deadlock detector background worker process.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_global_deadlock_detector_period
        """

    @property
    def gp_max_slices(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max amount of slice-processes for one query in one segment.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_max_slices
        """

    @property
    def gp_cached_segworkers_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Define amount of working processes in segment, that keeping in warm cash after end of query for usage again in next queries.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_cached_segworkers_threshold
        """

    @property
    def lock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max time (in ms) which query will wait lock free on object
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#lock_timeout
        """

    @property
    def idle_in_transaction_session_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max time (in ms) which session can idle in open transaction
        https://postgrespro.ru/docs/postgrespro/current/runtime-config-client#GUC-IDLE-IN-TRANSACTION-SESSION-TIMEOUT
        """

    @property
    def runaway_detector_activation_percent(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Percent of utilized Greenplum Database vmem that triggers the termination of queries.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#runaway_detector_activation_percent
        """

    @property
    def gp_vmem_protect_segworker_cache_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Set memory limit (in MB) for working process. If a query executor process consumes more than this configured amount, then the process will not be cached for use in subsequent queries after the process completes.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_vmem_protect_segworker_cache_limit
        """

    @property
    def gp_enable_zstd_memory_accounting(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Forces ZSTD lib use Greenplum memory allocation system."""

    @property
    def gp_max_plan_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the total maximum uncompressed size of a query execution plan multiplied by the number of Motion operators (slices) in the plan.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_max_plan_size
        """

    @property
    def gp_autostats_on_change_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the threshold for automatic statistics collection when gp_autostats_mode is set to on_change.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_autostats_on_change_threshold
        """

    @property
    def gp_resource_group_memory_limit(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Identifies the maximum percentage of system memory resources to allocate to resource groups on each Greenplum Database segment node.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_resource_group_memory_limit
        """

    @property
    def log_connections(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This outputs a line to the server log detailing each successful connection. Some client programs, like psql,
        attempt to connect twice while determining if a password is required, so duplicate "connection received" messages
        do not always indicate a problem.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_connections
        """

    @property
    def log_disconnections(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This outputs a line in the server log at termination of a client session, and includes the duration of the session.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_disconnections
        """

    @property
    def log_hostname(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """By default, connection log messages only show the IP address of the connecting host.
        Turning on this option causes logging of the host name as well. Note that depending on your host name
        resolution setup this might impose a non-negligible performance penalty.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_hostname
        """

    @property
    def log_statement_stats(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """For each query, write total performance statistics of the query parser, planner, and executor to the server log.
        This is a crude profiling instrument.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_statement_stats
        """

    @property
    def log_min_duration_statement(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Logs the statement and its duration on a single log line if its duration is greater than or equal
        to the specified number of milliseconds. Setting this to 0 will print all statements and their durations.
        -1 deactivates the feature. For example, if you set it to 250 then all SQL statements that run 250ms or longer will be logged.
        Enabling this option can be useful in tracking down unoptimized queries in your applications.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_min_duration_statement
        in milliseconds.
        """

    @property
    def master_shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the amount of memory a Greenplum Database master instance uses for shared memory buffers.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#shared_buffers
        """

    @property
    def max_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The shared lock table is created with room to describe locks on max_locks_per_transaction * (max_connections + max_prepared_transactions) objects,
        so no more than this many distinct objects can be locked at any one time.
        This is not a hard limit on the number of locks taken by any one transaction, but rather a maximum average value.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#max_locks_per_transaction
        """

    @property
    def segment_shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the amount of memory a Greenplum Database segment instance uses for shared memory buffers.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#shared_buffers
        """

    def __init__(
        self,
        *,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_slot_wal_keep_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_segment: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_files_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_transactions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_compression: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_statement_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_statement: global___LogStatement.ValueType = ...,
        gp_add_column_inherits_table_setting: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        gp_enable_global_deadlock_detector: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        gp_global_deadlock_detector_period: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_max_slices: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_cached_segworkers_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        idle_in_transaction_session_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        runaway_detector_activation_percent: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_vmem_protect_segworker_cache_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_enable_zstd_memory_accounting: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        gp_max_plan_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_autostats_mode: global___GPAutostatsMode.ValueType = ...,
        gp_autostats_on_change_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_resource_group_memory_limit: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        log_connections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_disconnections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_hostname: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_statement_stats: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_min_duration_statement: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        master_shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        segment_shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_error_verbosity: global___LogErrorVerbosity.ValueType = ...,
        log_min_messages: global___LogLevelMessage.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gp_add_column_inherits_table_setting", b"gp_add_column_inherits_table_setting", "gp_autostats_on_change_threshold", b"gp_autostats_on_change_threshold", "gp_cached_segworkers_threshold", b"gp_cached_segworkers_threshold", "gp_enable_global_deadlock_detector", b"gp_enable_global_deadlock_detector", "gp_enable_zstd_memory_accounting", b"gp_enable_zstd_memory_accounting", "gp_global_deadlock_detector_period", b"gp_global_deadlock_detector_period", "gp_max_plan_size", b"gp_max_plan_size", "gp_max_slices", b"gp_max_slices", "gp_resource_group_memory_limit", b"gp_resource_group_memory_limit", "gp_vmem_protect_segworker_cache_limit", b"gp_vmem_protect_segworker_cache_limit", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "lock_timeout", b"lock_timeout", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_hostname", b"log_hostname", "log_min_duration_statement", b"log_min_duration_statement", "log_statement_stats", b"log_statement_stats", "master_shared_buffers", b"master_shared_buffers", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem", "runaway_detector_activation_percent", b"runaway_detector_activation_percent", "segment_shared_buffers", b"segment_shared_buffers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gp_add_column_inherits_table_setting", b"gp_add_column_inherits_table_setting", "gp_autostats_mode", b"gp_autostats_mode", "gp_autostats_on_change_threshold", b"gp_autostats_on_change_threshold", "gp_cached_segworkers_threshold", b"gp_cached_segworkers_threshold", "gp_enable_global_deadlock_detector", b"gp_enable_global_deadlock_detector", "gp_enable_zstd_memory_accounting", b"gp_enable_zstd_memory_accounting", "gp_global_deadlock_detector_period", b"gp_global_deadlock_detector_period", "gp_max_plan_size", b"gp_max_plan_size", "gp_max_slices", b"gp_max_slices", "gp_resource_group_memory_limit", b"gp_resource_group_memory_limit", "gp_vmem_protect_segworker_cache_limit", b"gp_vmem_protect_segworker_cache_limit", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "lock_timeout", b"lock_timeout", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_error_verbosity", b"log_error_verbosity", "log_hostname", b"log_hostname", "log_min_duration_statement", b"log_min_duration_statement", "log_min_messages", b"log_min_messages", "log_statement", b"log_statement", "log_statement_stats", b"log_statement_stats", "master_shared_buffers", b"master_shared_buffers", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem", "runaway_detector_activation_percent", b"runaway_detector_activation_percent", "segment_shared_buffers", b"segment_shared_buffers"]) -> None: ...

global___GreenplumConfig6 = GreenplumConfig6

@typing.final
class GreenplumConfigCBDB(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_SLOT_WAL_KEEP_SIZE_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_SEGMENT_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_QUERY_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_FILES_PER_QUERY_FIELD_NUMBER: builtins.int
    MAX_PREPARED_TRANSACTIONS_FIELD_NUMBER: builtins.int
    GP_WORKFILE_COMPRESSION_FIELD_NUMBER: builtins.int
    MAX_STATEMENT_MEM_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    GP_ENABLE_GLOBAL_DEADLOCK_DETECTOR_FIELD_NUMBER: builtins.int
    GP_GLOBAL_DEADLOCK_DETECTOR_PERIOD_FIELD_NUMBER: builtins.int
    GP_MAX_SLICES_FIELD_NUMBER: builtins.int
    GP_CACHED_SEGWORKERS_THRESHOLD_FIELD_NUMBER: builtins.int
    LOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    RUNAWAY_DETECTOR_ACTIVATION_PERCENT_FIELD_NUMBER: builtins.int
    GP_VMEM_PROTECT_SEGWORKER_CACHE_LIMIT_FIELD_NUMBER: builtins.int
    GP_ENABLE_ZSTD_MEMORY_ACCOUNTING_FIELD_NUMBER: builtins.int
    GP_MAX_PLAN_SIZE_FIELD_NUMBER: builtins.int
    GP_AUTOSTATS_MODE_FIELD_NUMBER: builtins.int
    GP_AUTOSTATS_ON_CHANGE_THRESHOLD_FIELD_NUMBER: builtins.int
    GP_RESOURCE_GROUP_MEMORY_LIMIT_FIELD_NUMBER: builtins.int
    LOG_CONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DISCONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_HOSTNAME_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_STATS_FIELD_NUMBER: builtins.int
    LOG_MIN_DURATION_STATEMENT_FIELD_NUMBER: builtins.int
    MASTER_SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    MAX_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    SEGMENT_SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    LOG_ERROR_VERBOSITY_FIELD_NUMBER: builtins.int
    LOG_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    log_statement: global___LogStatement.ValueType
    """Controls which SQL statements are logged. DDL logs all data definition commands like CREATE, ALTER, and DROP commands.
    MOD logs all DDL statements, plus INSERT, UPDATE, DELETE, TRUNCATE, and COPY FROM.
    PREPARE and EXPLAIN ANALYZE statements are also logged if their contained command is of an appropriate type.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_statement
    Default value is ddl
    """
    gp_autostats_mode: global___GPAutostatsMode.ValueType
    """Specifies the mode for triggering automatic statistics collection after DML.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_autostats_mode
    """
    log_error_verbosity: global___LogErrorVerbosity.ValueType
    """Controls the amount of detail written in the server log for each message that is logged.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_error_verbosity
    """
    log_min_messages: global___LogLevelMessage.ValueType
    """Controls which message levels are written to the server log.
    Each level includes all the levels that follow it. The later the level, the fewer messages are sent to the log.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_min_messages
    """
    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of concurrent connections to the database server.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#max_connections
        """

    @property
    def max_slot_wal_keep_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum size in megabytes of Write-Ahead Logging (WAL) files on disk per segment instance that can be reserved
        when Greenplum streams data to the mirror segment instance or standby coordinator to keep it synchronized
        with the corresponding primary segment instance or coordinator.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#max_slot_wal_keep_size
        """

    @property
    def gp_workfile_limit_per_segment(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum total disk size that all running queries are allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_segment
        """

    @property
    def gp_workfile_limit_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum disk size an individual query is allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_query
        """

    @property
    def gp_workfile_limit_files_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of temporary spill files (also known as workfiles) allowed per query per segment.
        Spill files are created when executing a query that requires more memory than it is allocated.
        The current query is terminated when the limit is exceeded.
        Set the value to 0 (zero) to allow an unlimited number of spill files. master session reload
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_files_per_query
        Default value is 10000
        """

    @property
    def max_prepared_transactions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of transactions that can be in the "prepared" state simultaneously
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#max_prepared_transactions
        """

    @property
    def gp_workfile_compression(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies whether the temporary files created, when a hash aggregation or hash join operation spills to disk, are compressed.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_compression
        """

    @property
    def max_statement_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum memory limit for a query. Helps avoid out-of-memory errors on a segment host during query processing as a result of setting statement_mem too high.
        Taking into account the configuration of a single segment host, calculate max_statement_mem as follows:
        (seghost_physical_memory) / (average_number_concurrent_queries)
        When changing both max_statement_mem and statement_mem, max_statement_mem must be changed first, or listed first in the postgresql.conf file.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#max_statement_mem
        Default value is 2097152000 (2000MB)
        in bytes
        """

    @property
    def gp_enable_global_deadlock_detector(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Controls whether the Greenplum Database Global Deadlock Detector is enabled to manage concurrent UPDATE and DELETE operations on heap tables to improve performance. See Inserting, Updating, and Deleting Datain the Greenplum Database Administrator Guide. The default is off, the Global Deadlock Detector is deactivated.
        If the Global Deadlock Detector is deactivated (the default), Greenplum Database runs concurrent update and delete operations on a heap table serially.
        If the Global Deadlock Detector is enabled, concurrent updates are permitted and the Global Deadlock Detector determines when a deadlock exists, and breaks the deadlock by cancelling one or more backend processes associated with the youngest transaction(s) involved.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#gp_enable_global_deadlock_detector
        """

    @property
    def gp_global_deadlock_detector_period(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the executing interval (in seconds) of the global deadlock detector background worker process.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_global_deadlock_detector_period
        """

    @property
    def gp_max_slices(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max amount of slice-processes for one query in one segment.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_max_slices
        """

    @property
    def gp_cached_segworkers_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Define amount of working processes in segment, that keeping in warm cash after end of query for usage again in next queries.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_cached_segworkers_threshold
        """

    @property
    def lock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max time (in ms) which query will wait lock free on object
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#lock_timeout
        """

    @property
    def idle_in_transaction_session_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max time (in ms) which session can idle in open transaction
        https://postgrespro.ru/docs/postgrespro/current/runtime-config-client#GUC-IDLE-IN-TRANSACTION-SESSION-TIMEOUT
        """

    @property
    def runaway_detector_activation_percent(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Percent of utilized Greenplum Database vmem that triggers the termination of queries.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#runaway_detector_activation_percent
        """

    @property
    def gp_vmem_protect_segworker_cache_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Set memory limit (in MB) for working process. If a query executor process consumes more than this configured amount, then the process will not be cached for use in subsequent queries after the process completes.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_vmem_protect_segworker_cache_limit
        """

    @property
    def gp_enable_zstd_memory_accounting(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Forces ZSTD lib use Greenplum memory allocation system."""

    @property
    def gp_max_plan_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the total maximum uncompressed size of a query execution plan multiplied by the number of Motion operators (slices) in the plan.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_max_plan_size
        """

    @property
    def gp_autostats_on_change_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the threshold for automatic statistics collection when gp_autostats_mode is set to on_change.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_autostats_on_change_threshold
        """

    @property
    def gp_resource_group_memory_limit(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Identifies the maximum percentage of system memory resources to allocate to resource groups on each Greenplum Database segment node.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_resource_group_memory_limit
        """

    @property
    def log_connections(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This outputs a line to the server log detailing each successful connection. Some client programs, like psql,
        attempt to connect twice while determining if a password is required, so duplicate "connection received" messages
        do not always indicate a problem.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_connections
        """

    @property
    def log_disconnections(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This outputs a line in the server log at termination of a client session, and includes the duration of the session.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_disconnections
        """

    @property
    def log_hostname(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """By default, connection log messages only show the IP address of the connecting host.
        Turning on this option causes logging of the host name as well. Note that depending on your host name
        resolution setup this might impose a non-negligible performance penalty.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_hostname
        """

    @property
    def log_statement_stats(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """For each query, write total performance statistics of the query parser, planner, and executor to the server log.
        This is a crude profiling instrument.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_statement_stats
        """

    @property
    def log_min_duration_statement(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Logs the statement and its duration on a single log line if its duration is greater than or equal
        to the specified number of milliseconds. Setting this to 0 will print all statements and their durations.
        -1 deactivates the feature. For example, if you set it to 250 then all SQL statements that run 250ms or longer will be logged.
        Enabling this option can be useful in tracking down unoptimized queries in your applications.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_statement_stats
        in milliseconds.
        """

    @property
    def master_shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the amount of memory a Greenplum Database master instance uses for shared memory buffers.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#shared_buffers
        """

    @property
    def max_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The shared lock table is created with room to describe locks on max_locks_per_transaction * (max_connections + max_prepared_transactions) objects,
        so no more than this many distinct objects can be locked at any one time.
        This is not a hard limit on the number of locks taken by any one transaction, but rather a maximum average value.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#max_locks_per_transaction
        """

    @property
    def segment_shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the amount of memory a Greenplum Database segment instance uses for shared memory buffers.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#shared_buffers
        """

    def __init__(
        self,
        *,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_slot_wal_keep_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_segment: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_files_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_transactions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_compression: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_statement_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_statement: global___LogStatement.ValueType = ...,
        gp_enable_global_deadlock_detector: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        gp_global_deadlock_detector_period: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_max_slices: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_cached_segworkers_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        idle_in_transaction_session_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        runaway_detector_activation_percent: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_vmem_protect_segworker_cache_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_enable_zstd_memory_accounting: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        gp_max_plan_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_autostats_mode: global___GPAutostatsMode.ValueType = ...,
        gp_autostats_on_change_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_resource_group_memory_limit: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        log_connections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_disconnections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_hostname: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_statement_stats: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_min_duration_statement: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        master_shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        segment_shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_error_verbosity: global___LogErrorVerbosity.ValueType = ...,
        log_min_messages: global___LogLevelMessage.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gp_autostats_on_change_threshold", b"gp_autostats_on_change_threshold", "gp_cached_segworkers_threshold", b"gp_cached_segworkers_threshold", "gp_enable_global_deadlock_detector", b"gp_enable_global_deadlock_detector", "gp_enable_zstd_memory_accounting", b"gp_enable_zstd_memory_accounting", "gp_global_deadlock_detector_period", b"gp_global_deadlock_detector_period", "gp_max_plan_size", b"gp_max_plan_size", "gp_max_slices", b"gp_max_slices", "gp_resource_group_memory_limit", b"gp_resource_group_memory_limit", "gp_vmem_protect_segworker_cache_limit", b"gp_vmem_protect_segworker_cache_limit", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "lock_timeout", b"lock_timeout", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_hostname", b"log_hostname", "log_min_duration_statement", b"log_min_duration_statement", "log_statement_stats", b"log_statement_stats", "master_shared_buffers", b"master_shared_buffers", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem", "runaway_detector_activation_percent", b"runaway_detector_activation_percent", "segment_shared_buffers", b"segment_shared_buffers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gp_autostats_mode", b"gp_autostats_mode", "gp_autostats_on_change_threshold", b"gp_autostats_on_change_threshold", "gp_cached_segworkers_threshold", b"gp_cached_segworkers_threshold", "gp_enable_global_deadlock_detector", b"gp_enable_global_deadlock_detector", "gp_enable_zstd_memory_accounting", b"gp_enable_zstd_memory_accounting", "gp_global_deadlock_detector_period", b"gp_global_deadlock_detector_period", "gp_max_plan_size", b"gp_max_plan_size", "gp_max_slices", b"gp_max_slices", "gp_resource_group_memory_limit", b"gp_resource_group_memory_limit", "gp_vmem_protect_segworker_cache_limit", b"gp_vmem_protect_segworker_cache_limit", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "lock_timeout", b"lock_timeout", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_error_verbosity", b"log_error_verbosity", "log_hostname", b"log_hostname", "log_min_duration_statement", b"log_min_duration_statement", "log_min_messages", b"log_min_messages", "log_statement", b"log_statement", "log_statement_stats", b"log_statement_stats", "master_shared_buffers", b"master_shared_buffers", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem", "runaway_detector_activation_percent", b"runaway_detector_activation_percent", "segment_shared_buffers", b"segment_shared_buffers"]) -> None: ...

global___GreenplumConfigCBDB = GreenplumConfigCBDB

@typing.final
class GreenplumConfigSet6(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___GreenplumConfig6:
        """Effective settings for a Greenplum (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___GreenplumConfig6:
        """User-defined settings for a Greenplum."""

    @property
    def default_config(self) -> global___GreenplumConfig6:
        """Default configuration for a Greenplum."""

    def __init__(
        self,
        *,
        effective_config: global___GreenplumConfig6 | None = ...,
        user_config: global___GreenplumConfig6 | None = ...,
        default_config: global___GreenplumConfig6 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___GreenplumConfigSet6 = GreenplumConfigSet6

@typing.final
class ConnectionPoolerConfigSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___ConnectionPoolerConfig:
        """Effective settings for an Odyssey® pooler (a combination of settings defined in [ConnectionPoolerConfigSet.user_config] and [ConnectionPoolerConfigSet.default_config])."""

    @property
    def user_config(self) -> global___ConnectionPoolerConfig:
        """User-defined settings for an Odyssey® pooler."""

    @property
    def default_config(self) -> global___ConnectionPoolerConfig:
        """Default configuration for an Odyssey® pooler."""

    def __init__(
        self,
        *,
        effective_config: global___ConnectionPoolerConfig | None = ...,
        user_config: global___ConnectionPoolerConfig | None = ...,
        default_config: global___ConnectionPoolerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___ConnectionPoolerConfigSet = ConnectionPoolerConfigSet

@typing.final
class GreenplumConfigSetCBDB(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___GreenplumConfigCBDB:
        """Effective settings for a Cloudberry (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___GreenplumConfigCBDB:
        """User-defined settings for a Cloudberry."""

    @property
    def default_config(self) -> global___GreenplumConfigCBDB:
        """Default configuration for a Cloudberry."""

    def __init__(
        self,
        *,
        effective_config: global___GreenplumConfigCBDB | None = ...,
        user_config: global___GreenplumConfigCBDB | None = ...,
        default_config: global___GreenplumConfigCBDB | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___GreenplumConfigSetCBDB = GreenplumConfigSetCBDB
