# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/synchronization_session_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/synchronization_session_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp import synchronization_settings_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__settings__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMyandex/cloud/organizationmanager/v1/idp/synchronization_session_service.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x46yandex/cloud/organizationmanager/v1/idp/synchronization_settings.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb2\x01\n\x12OpenSessionRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x08\x61gent_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12P\n\x0csession_type\x18\x03 \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.SessionTypeB\x04\xe8\xc7\x31\x01\"\x8e\x04\n\x16SynchronizationSession\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tclosed_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\tsync_mode\x18\x06 \x01(\x0e\x32\x31.yandex.cloud.organizationmanager.v1.idp.SyncMode\x12\x46\n\x06status\x18\x07 \x01(\x0e\x32\x36.yandex.cloud.organizationmanager.v1.idp.SessionStatus\x12P\n\x10progress_entries\x18\x08 \x03(\x0b\x32\x36.yandex.cloud.organizationmanager.v1.idp.ProgressEntry\x12\x13\n\x0b\x66\x61il_reason\x18\t \x01(\t\x12J\n\x0csession_type\x18\n \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.SessionType\"\x82\x03\n\x13OpenSessionResponse\x12J\n\x06result\x18\x01 \x01(\x0e\x32:.yandex.cloud.organizationmanager.v1.idp.OpenSessionResult\x12Y\n\x0eopened_session\x18\x02 \x01(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionH\x00\x12\x35\n\x0fnext_session_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x19\n\x11replication_token\x18\x04 \x01(\t\x12\x62\n\x18synchronization_settings\x18\x05 \x01(\x0b\x32@.yandex.cloud.organizationmanager.v1.idp.SynchronizationSettingsB\x0e\n\x0csession_info\")\n\x13OpenSessionMetadata\x12\x12\n\nsession_id\x18\x01 \x01(\t\"5\n\x11GetSessionRequest\x12 \n\nsession_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"f\n\x12GetSessionResponse\x12P\n\x07session\x18\x01 \x01(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.SynchronizationSession\"\x9b\x01\n\x1cReportSessionProgressRequest\x12 \n\nsession_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12Y\n\x10progress_entries\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.organizationmanager.v1.idp.ProgressEntryB\x07\x82\xc8\x31\x03\x31-3\"3\n\x1dReportSessionProgressMetadata\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\xb9\x01\n\rProgressEntry\x12U\n\x0bobject_type\x18\x01 \x01(\x0e\x32:.yandex.cloud.organizationmanager.v1.idp.RelatedObjectTypeB\x04\xe8\xc7\x31\x01\x12Q\n\x0b\x63hange_info\x18\x02 \x03(\x0b\x32\x33.yandex.cloud.organizationmanager.v1.idp.ChangeInfoB\x07\x82\xc8\x31\x03\x31-6\"z\n\nChangeInfo\x12H\n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x33.yandex.cloud.organizationmanager.v1.idp.ChangeType\x12\x12\n\nsuccessful\x18\x02 \x01(\x03\x12\x0e\n\x06\x66\x61iled\x18\x03 \x01(\x03\"\x9c\x01\n\x13ListSessionsRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x82\x01\n\x14ListSessionsResponse\x12Q\n\x08sessions\x18\x01 \x03(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.SynchronizationSession\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n\x13\x43loseSessionRequest\x12 \n\nsession_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0e\n\x06\x66\x61iled\x18\x02 \x01(\x08\x12\x1e\n\x0b\x66\x61il_reason\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"*\n\x14\x43loseSessionMetadata\x12\x12\n\nsession_id\x18\x01 \x01(\t\"4\n\x10HeartbeatRequest\x12 \n\nsession_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x11HeartbeatMetadata\x12\x12\n\nsession_id\x18\x01 \x01(\t*o\n\x11OpenSessionResult\x12#\n\x1fOPEN_SESSION_RESULT_UNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x19\n\x15OPENED_SESSION_EXISTS\x10\x02\x12\r\n\tTOO_EARLY\x10\x03*\x85\x01\n\nChangeType\x12\x1b\n\x17\x43HANGE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\x0c\n\x08\x41\x43TIVATE\x10\x04\x12\x0e\n\nDEACTIVATE\x10\x05\x12\x18\n\x14PASSWORD_HASH_UPDATE\x10\x06*]\n\x11RelatedObjectType\x12#\n\x1fRELATED_OBJECT_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04USER\x10\x01\x12\t\n\x05GROUP\x10\x02\x12\x0e\n\nMEMBERSHIP\x10\x03*?\n\x08SyncMode\x12\x19\n\x15SYNC_MODE_UNSPECIFIED\x10\x00\x12\r\n\tFULL_SYNC\x10\x01\x12\t\n\x05\x44\x45LTA\x10\x02*p\n\rSessionStatus\x12\x1e\n\x1aSESSION_STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06OPENED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0b\n\x07\x45XPIRED\x10\x05\x32\xb1\x0b\n\x1dSynchronizationSessionService\x12\xe2\x01\n\x0bOpenSession\x12;.yandex.cloud.organizationmanager.v1.idp.OpenSessionRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2**\n\x13OpenSessionMetadata\x12\x13OpenSessionResponse\x82\xd3\xe4\x93\x02?\":/organization-manager/v1/idp/synchronization-sessions:open:\x01*\x12\xf7\x01\n\x0c\x43loseSession\x12<.yandex.cloud.organizationmanager.v1.idp.CloseSessionRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*.\n\x14\x43loseSessionMetadata\x12\x16SynchronizationSession\x82\xd3\xe4\x93\x02M\"H/organization-manager/v1/idp/synchronization-sessions/{session_id}:close:\x01*\x12\x9b\x02\n\x15ReportSessionProgress\x12\x45.yandex.cloud.organizationmanager.v1.idp.ReportSessionProgressRequest\x1a!.yandex.cloud.operation.Operation\"\x97\x01\xb2\xd2*7\n\x1dReportSessionProgressMetadata\x12\x16SynchronizationSession\x82\xd3\xe4\x93\x02V\"Q/organization-manager/v1/idp/synchronization-sessions/{session_id}:reportProgress:\x01*\x12\xf1\x01\n\tHeartbeat\x12\x39.yandex.cloud.organizationmanager.v1.idp.HeartbeatRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2**\n\x11HeartbeatMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02Q\"L/organization-manager/v1/idp/synchronization-sessions/{session_id}:heartbeat:\x01*\x12\xd1\x01\n\nGetSession\x12:.yandex.cloud.organizationmanager.v1.idp.GetSessionRequest\x1a;.yandex.cloud.organizationmanager.v1.idp.GetSessionResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/organization-manager/v1/idp/synchronization-sessions/{session_id}\x12\xca\x01\n\x0cListSessions\x12<.yandex.cloud.organizationmanager.v1.idp.ListSessionsRequest\x1a=.yandex.cloud.organizationmanager.v1.idp.ListSessionsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/organization-manager/v1/idp/synchronization-sessionsB~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_OPENSESSIONREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_OPENSESSIONREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_OPENSESSIONREQUEST'].fields_by_name['agent_id']._loaded_options = None
  _globals['_OPENSESSIONREQUEST'].fields_by_name['agent_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_OPENSESSIONREQUEST'].fields_by_name['session_type']._loaded_options = None
  _globals['_OPENSESSIONREQUEST'].fields_by_name['session_type']._serialized_options = b'\350\3071\001'
  _globals['_GETSESSIONREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_GETSESSIONREQUEST'].fields_by_name['session_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REPORTSESSIONPROGRESSREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_REPORTSESSIONPROGRESSREQUEST'].fields_by_name['session_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REPORTSESSIONPROGRESSREQUEST'].fields_by_name['progress_entries']._loaded_options = None
  _globals['_REPORTSESSIONPROGRESSREQUEST'].fields_by_name['progress_entries']._serialized_options = b'\202\3101\0031-3'
  _globals['_PROGRESSENTRY'].fields_by_name['object_type']._loaded_options = None
  _globals['_PROGRESSENTRY'].fields_by_name['object_type']._serialized_options = b'\350\3071\001'
  _globals['_PROGRESSENTRY'].fields_by_name['change_info']._loaded_options = None
  _globals['_PROGRESSENTRY'].fields_by_name['change_info']._serialized_options = b'\202\3101\0031-6'
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CLOSESESSIONREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_CLOSESESSIONREQUEST'].fields_by_name['session_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CLOSESESSIONREQUEST'].fields_by_name['fail_reason']._loaded_options = None
  _globals['_CLOSESESSIONREQUEST'].fields_by_name['fail_reason']._serialized_options = b'\212\3101\005<=256'
  _globals['_HEARTBEATREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_HEARTBEATREQUEST'].fields_by_name['session_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['OpenSession']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['OpenSession']._serialized_options = b'\262\322**\n\023OpenSessionMetadata\022\023OpenSessionResponse\202\323\344\223\002?\":/organization-manager/v1/idp/synchronization-sessions:open:\001*'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['CloseSession']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['CloseSession']._serialized_options = b'\262\322*.\n\024CloseSessionMetadata\022\026SynchronizationSession\202\323\344\223\002M\"H/organization-manager/v1/idp/synchronization-sessions/{session_id}:close:\001*'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['ReportSessionProgress']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['ReportSessionProgress']._serialized_options = b'\262\322*7\n\035ReportSessionProgressMetadata\022\026SynchronizationSession\202\323\344\223\002V\"Q/organization-manager/v1/idp/synchronization-sessions/{session_id}:reportProgress:\001*'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['Heartbeat']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['Heartbeat']._serialized_options = b'\262\322**\n\021HeartbeatMetadata\022\025google.protobuf.Empty\202\323\344\223\002Q\"L/organization-manager/v1/idp/synchronization-sessions/{session_id}:heartbeat:\001*'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['GetSession']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['GetSession']._serialized_options = b'\202\323\344\223\002D\022B/organization-manager/v1/idp/synchronization-sessions/{session_id}'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['ListSessions']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['ListSessions']._serialized_options = b'\202\323\344\223\0027\0225/organization-manager/v1/idp/synchronization-sessions'
  _globals['_OPENSESSIONRESULT']._serialized_start=2722
  _globals['_OPENSESSIONRESULT']._serialized_end=2833
  _globals['_CHANGETYPE']._serialized_start=2836
  _globals['_CHANGETYPE']._serialized_end=2969
  _globals['_RELATEDOBJECTTYPE']._serialized_start=2971
  _globals['_RELATEDOBJECTTYPE']._serialized_end=3064
  _globals['_SYNCMODE']._serialized_start=3066
  _globals['_SYNCMODE']._serialized_end=3129
  _globals['_SESSIONSTATUS']._serialized_start=3131
  _globals['_SESSIONSTATUS']._serialized_end=3243
  _globals['_OPENSESSIONREQUEST']._serialized_start=363
  _globals['_OPENSESSIONREQUEST']._serialized_end=541
  _globals['_SYNCHRONIZATIONSESSION']._serialized_start=544
  _globals['_SYNCHRONIZATIONSESSION']._serialized_end=1070
  _globals['_OPENSESSIONRESPONSE']._serialized_start=1073
  _globals['_OPENSESSIONRESPONSE']._serialized_end=1459
  _globals['_OPENSESSIONMETADATA']._serialized_start=1461
  _globals['_OPENSESSIONMETADATA']._serialized_end=1502
  _globals['_GETSESSIONREQUEST']._serialized_start=1504
  _globals['_GETSESSIONREQUEST']._serialized_end=1557
  _globals['_GETSESSIONRESPONSE']._serialized_start=1559
  _globals['_GETSESSIONRESPONSE']._serialized_end=1661
  _globals['_REPORTSESSIONPROGRESSREQUEST']._serialized_start=1664
  _globals['_REPORTSESSIONPROGRESSREQUEST']._serialized_end=1819
  _globals['_REPORTSESSIONPROGRESSMETADATA']._serialized_start=1821
  _globals['_REPORTSESSIONPROGRESSMETADATA']._serialized_end=1872
  _globals['_PROGRESSENTRY']._serialized_start=1875
  _globals['_PROGRESSENTRY']._serialized_end=2060
  _globals['_CHANGEINFO']._serialized_start=2062
  _globals['_CHANGEINFO']._serialized_end=2184
  _globals['_LISTSESSIONSREQUEST']._serialized_start=2187
  _globals['_LISTSESSIONSREQUEST']._serialized_end=2343
  _globals['_LISTSESSIONSRESPONSE']._serialized_start=2346
  _globals['_LISTSESSIONSRESPONSE']._serialized_end=2476
  _globals['_CLOSESESSIONREQUEST']._serialized_start=2478
  _globals['_CLOSESESSIONREQUEST']._serialized_end=2581
  _globals['_CLOSESESSIONMETADATA']._serialized_start=2583
  _globals['_CLOSESESSIONMETADATA']._serialized_end=2625
  _globals['_HEARTBEATREQUEST']._serialized_start=2627
  _globals['_HEARTBEATREQUEST']._serialized_end=2679
  _globals['_HEARTBEATMETADATA']._serialized_start=2681
  _globals['_HEARTBEATMETADATA']._serialized_end=2720
  _globals['_SYNCHRONIZATIONSESSIONSERVICE']._serialized_start=3246
  _globals['_SYNCHRONIZATIONSESSIONSERVICE']._serialized_end=4703
# @@protoc_insertion_point(module_scope)
