# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/application/saml/application.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/application/saml/application.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJyandex/cloud/organizationmanager/v1/idp/application/saml/application.proto\x12\x38yandex.cloud.organizationmanager.v1.idp.application.saml\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x97\x08\n\x0b\x41pplication\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\\\n\x06status\x18\x05 \x01(\x0e\x32L.yandex.cloud.organizationmanager.v1.idp.application.saml.Application.Status\x12\x61\n\x06labels\x18\x06 \x03(\x0b\x32Q.yandex.cloud.organizationmanager.v1.idp.application.saml.Application.LabelsEntry\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x63\n\x10service_provider\x18\t \x01(\x0b\x32I.yandex.cloud.organizationmanager.v1.idp.application.saml.ServiceProvider\x12\x65\n\x11security_settings\x18\n \x01(\x0b\x32J.yandex.cloud.organizationmanager.v1.idp.application.saml.SecuritySettings\x12\x65\n\x11\x61ttribute_mapping\x18\x0b \x01(\x0b\x32J.yandex.cloud.organizationmanager.v1.idp.application.saml.AttributeMapping\x12l\n\x15group_claims_settings\x18\x0c \x01(\x0b\x32M.yandex.cloud.organizationmanager.v1.idp.application.saml.GroupClaimsSettings\x12v\n\x1aidentity_provider_metadata\x18\r \x01(\x0b\x32R.yandex.cloud.organizationmanager.v1.idp.application.saml.IdentityProviderMetadata\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\r\n\tSUSPENDED\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"b\n\x18IdentityProviderMetadata\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07sso_url\x18\x02 \x01(\t\x12\x14\n\x0cmetadata_url\x18\x03 \x01(\t\x12\x0f\n\x07slo_url\x18\x04 \x01(\t\"\x97\x02\n\x0fServiceProvider\x12!\n\tentity_id\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12r\n\x08\x61\x63s_urls\x18\x02 \x03(\x0b\x32U.yandex.cloud.organizationmanager.v1.idp.application.saml.AssertionConsumerServiceURLB\t\x82\xc8\x31\x05\x31-100\x12m\n\x08slo_urls\x18\x03 \x03(\x0b\x32P.yandex.cloud.organizationmanager.v1.idp.application.saml.SingleLogoutServiceURLB\t\x82\xc8\x31\x05\x30-100\"f\n\x1b\x41ssertionConsumerServiceURL\x12\x1b\n\x03url\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12*\n\x05index\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xb1\x02\n\x16SingleLogoutServiceURL\x12\x1b\n\x03url\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12 \n\x0cresponse_url\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=8000\x12\x80\x01\n\x10protocol_binding\x18\x03 \x01(\x0e\x32`.yandex.cloud.organizationmanager.v1.idp.application.saml.SingleLogoutServiceURL.ProtocolBindingB\x04\xe8\xc7\x31\x01\"U\n\x0fProtocolBinding\x12 \n\x1cPROTOCOL_BINDING_UNSPECIFIED\x10\x00\x12\r\n\tHTTP_POST\x10\x01\x12\x11\n\rHTTP_REDIRECT\x10\x02\"\x92\x02\n\x10SecuritySettings\x12p\n\x0esignature_mode\x18\x01 \x01(\x0e\x32X.yandex.cloud.organizationmanager.v1.idp.application.saml.SecuritySettings.SignatureMode\x12 \n\x18signature_certificate_id\x18\x02 \x01(\t\"j\n\rSignatureMode\x12\x1e\n\x1aSIGNATURE_MODE_UNSPECIFIED\x10\x00\x12\x0e\n\nASSERTIONS\x10\x01\x12\x0c\n\x08RESPONSE\x10\x02\x12\x1b\n\x17RESPONSE_AND_ASSERTIONS\x10\x03\"\xce\x01\n\x10\x41ttributeMapping\x12W\n\x07name_id\x18\x01 \x01(\x0b\x32@.yandex.cloud.organizationmanager.v1.idp.application.saml.NameIdB\x04\xe8\xc7\x31\x01\x12\x61\n\nattributes\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.idp.application.saml.AttributeB\x08\x82\xc8\x31\x04<=50\"\xb9\x01\n\x06NameId\x12]\n\x06\x66ormat\x18\x01 \x01(\x0e\x32G.yandex.cloud.organizationmanager.v1.idp.application.saml.NameId.FormatB\x04\xe8\xc7\x31\x01\x12\x13\n\x05value\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\";\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0e\n\nPERSISTENT\x10\x01\x12\t\n\x05\x45MAIL\x10\x02\"F\n\tAttribute\x12\x1c\n\x04name\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12\x1b\n\x05value\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xb1\x01\n\x13GroupClaimsSettings\x12p\n\x17group_distribution_type\x18\x01 \x01(\x0e\x32O.yandex.cloud.organizationmanager.v1.idp.application.saml.GroupDistributionType\x12(\n\x14group_attribute_name\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=8000*o\n\x15GroupDistributionType\x12\'\n#GROUP_DISTRIBUTION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x13\n\x0f\x41SSIGNED_GROUPS\x10\x02\x12\x0e\n\nALL_GROUPS\x10\x03\x42\xa1\x01\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;samlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;saml'
  _globals['_APPLICATION_LABELSENTRY']._loaded_options = None
  _globals['_APPLICATION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SERVICEPROVIDER'].fields_by_name['entity_id']._loaded_options = None
  _globals['_SERVICEPROVIDER'].fields_by_name['entity_id']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_SERVICEPROVIDER'].fields_by_name['acs_urls']._loaded_options = None
  _globals['_SERVICEPROVIDER'].fields_by_name['acs_urls']._serialized_options = b'\202\3101\0051-100'
  _globals['_SERVICEPROVIDER'].fields_by_name['slo_urls']._loaded_options = None
  _globals['_SERVICEPROVIDER'].fields_by_name['slo_urls']._serialized_options = b'\202\3101\0050-100'
  _globals['_ASSERTIONCONSUMERSERVICEURL'].fields_by_name['url']._loaded_options = None
  _globals['_ASSERTIONCONSUMERSERVICEURL'].fields_by_name['url']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['url']._loaded_options = None
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['url']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['response_url']._loaded_options = None
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['response_url']._serialized_options = b'\212\3101\006<=8000'
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['protocol_binding']._loaded_options = None
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['protocol_binding']._serialized_options = b'\350\3071\001'
  _globals['_ATTRIBUTEMAPPING'].fields_by_name['name_id']._loaded_options = None
  _globals['_ATTRIBUTEMAPPING'].fields_by_name['name_id']._serialized_options = b'\350\3071\001'
  _globals['_ATTRIBUTEMAPPING'].fields_by_name['attributes']._loaded_options = None
  _globals['_ATTRIBUTEMAPPING'].fields_by_name['attributes']._serialized_options = b'\202\3101\004<=50'
  _globals['_NAMEID'].fields_by_name['format']._loaded_options = None
  _globals['_NAMEID'].fields_by_name['format']._serialized_options = b'\350\3071\001'
  _globals['_NAMEID'].fields_by_name['value']._loaded_options = None
  _globals['_NAMEID'].fields_by_name['value']._serialized_options = b'\350\3071\001'
  _globals['_ATTRIBUTE'].fields_by_name['name']._loaded_options = None
  _globals['_ATTRIBUTE'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_ATTRIBUTE'].fields_by_name['value']._loaded_options = None
  _globals['_ATTRIBUTE'].fields_by_name['value']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GROUPCLAIMSSETTINGS'].fields_by_name['group_attribute_name']._loaded_options = None
  _globals['_GROUPCLAIMSSETTINGS'].fields_by_name['group_attribute_name']._serialized_options = b'\212\3101\006<=8000'
  _globals['_GROUPDISTRIBUTIONTYPE']._serialized_start=3002
  _globals['_GROUPDISTRIBUTIONTYPE']._serialized_end=3113
  _globals['_APPLICATION']._serialized_start=233
  _globals['_APPLICATION']._serialized_end=1280
  _globals['_APPLICATION_LABELSENTRY']._serialized_start=1146
  _globals['_APPLICATION_LABELSENTRY']._serialized_end=1191
  _globals['_APPLICATION_STATUS']._serialized_start=1193
  _globals['_APPLICATION_STATUS']._serialized_end=1280
  _globals['_IDENTITYPROVIDERMETADATA']._serialized_start=1282
  _globals['_IDENTITYPROVIDERMETADATA']._serialized_end=1380
  _globals['_SERVICEPROVIDER']._serialized_start=1383
  _globals['_SERVICEPROVIDER']._serialized_end=1662
  _globals['_ASSERTIONCONSUMERSERVICEURL']._serialized_start=1664
  _globals['_ASSERTIONCONSUMERSERVICEURL']._serialized_end=1766
  _globals['_SINGLELOGOUTSERVICEURL']._serialized_start=1769
  _globals['_SINGLELOGOUTSERVICEURL']._serialized_end=2074
  _globals['_SINGLELOGOUTSERVICEURL_PROTOCOLBINDING']._serialized_start=1989
  _globals['_SINGLELOGOUTSERVICEURL_PROTOCOLBINDING']._serialized_end=2074
  _globals['_SECURITYSETTINGS']._serialized_start=2077
  _globals['_SECURITYSETTINGS']._serialized_end=2351
  _globals['_SECURITYSETTINGS_SIGNATUREMODE']._serialized_start=2245
  _globals['_SECURITYSETTINGS_SIGNATUREMODE']._serialized_end=2351
  _globals['_ATTRIBUTEMAPPING']._serialized_start=2354
  _globals['_ATTRIBUTEMAPPING']._serialized_end=2560
  _globals['_NAMEID']._serialized_start=2563
  _globals['_NAMEID']._serialized_end=2748
  _globals['_NAMEID_FORMAT']._serialized_start=2689
  _globals['_NAMEID_FORMAT']._serialized_end=2748
  _globals['_ATTRIBUTE']._serialized_start=2750
  _globals['_ATTRIBUTE']._serialized_end=2820
  _globals['_GROUPCLAIMSSETTINGS']._serialized_start=2823
  _globals['_GROUPCLAIMSSETTINGS']._serialized_end=3000
# @@protoc_insertion_point(module_scope)
