"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DeletionProtectionMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeletionProtectionModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeletionProtectionMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DELETION_PROTECTION_MODE_UNSPECIFIED: _DeletionProtectionMode.ValueType  # 0
    DELETION_PROTECTION_MODE_DISABLED: _DeletionProtectionMode.ValueType  # 1
    """Deletion protection is disabled"""
    DELETION_PROTECTION_MODE_ENABLED: _DeletionProtectionMode.ValueType  # 2
    """Deletion protection is enabled"""
    DELETION_PROTECTION_MODE_INHERITED: _DeletionProtectionMode.ValueType  # 3
    """Deletion protection mode is inherited from the cluster"""

class DeletionProtectionMode(_DeletionProtectionMode, metaclass=_DeletionProtectionModeEnumTypeWrapper): ...

DELETION_PROTECTION_MODE_UNSPECIFIED: DeletionProtectionMode.ValueType  # 0
DELETION_PROTECTION_MODE_DISABLED: DeletionProtectionMode.ValueType  # 1
"""Deletion protection is disabled"""
DELETION_PROTECTION_MODE_ENABLED: DeletionProtectionMode.ValueType  # 2
"""Deletion protection is enabled"""
DELETION_PROTECTION_MODE_INHERITED: DeletionProtectionMode.ValueType  # 3
"""Deletion protection mode is inherited from the cluster"""
global___DeletionProtectionMode = DeletionProtectionMode
