# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/usage_records/v1/credit.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/usage_records/v1/credit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.billing.usage_records.v1 import common_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_common__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/billing/usage_records/v1/credit.proto\x12%yandex.cloud.billing.usage_records.v1\x1a\x38yandex/cloud/billing/usage_records/v1/common_types.proto\"\x96\x03\n\rCreditDetails\x12\x44\n\x06\x63redit\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12S\n\x15monetary_grant_credit\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12U\n\x17volume_incentive_credit\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12H\n\ncud_credit\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12I\n\x0b\x66ree_credit\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimalB\x83\x01\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecordsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.usage_records.v1.credit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecords'
  _globals['_CREDITDETAILS']._serialized_start=152
  _globals['_CREDITDETAILS']._serialized_end=558
# @@protoc_insertion_point(module_scope)
