"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2
import yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ApplicationServiceStub:
    """A set of methods for managing OAuth application."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.GetApplicationRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.Application,
    ]
    """Returns the specified OAuth application resource.

    To get the list of available OAuth applications, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsResponse,
    ]
    """Retrieves the list of OAuth applications in the specified organization."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.CreateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OAuth application in the specified organization."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified OAuth application."""

    Suspend: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.SuspendApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets status to SUSPENDED for the specified OAuth application."""

    Reactivate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ReactivateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets status to ACTIVE for the specified OAuth application."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.DeleteApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified OAuth application."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsResponse,
    ]
    """Lists operations for the specified OAuth application."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for the specified OAuth application."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified OAuth application."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified OAuth application."""

    ListAssignments: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsResponse,
    ]
    """Lists assignmnents for the specified OAuth application."""

    UpdateAssignments: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateAssignmentsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates assignmnents for the specified OAuth application."""

class ApplicationServiceAsyncStub:
    """A set of methods for managing OAuth application."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.GetApplicationRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.Application,
    ]
    """Returns the specified OAuth application resource.

    To get the list of available OAuth applications, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsResponse,
    ]
    """Retrieves the list of OAuth applications in the specified organization."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.CreateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OAuth application in the specified organization."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified OAuth application."""

    Suspend: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.SuspendApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets status to SUSPENDED for the specified OAuth application."""

    Reactivate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ReactivateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets status to ACTIVE for the specified OAuth application."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.DeleteApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified OAuth application."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsResponse,
    ]
    """Lists operations for the specified OAuth application."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for the specified OAuth application."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified OAuth application."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified OAuth application."""

    ListAssignments: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsResponse,
    ]
    """Lists assignmnents for the specified OAuth application."""

    UpdateAssignments: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateAssignmentsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates assignmnents for the specified OAuth application."""

class ApplicationServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing OAuth application."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.GetApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.Application, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.Application]]:
        """Returns the specified OAuth application resource.

        To get the list of available OAuth applications, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsResponse]]:
        """Retrieves the list of OAuth applications in the specified organization."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.CreateApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an OAuth application in the specified organization."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified OAuth application."""

    @abc.abstractmethod
    def Suspend(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.SuspendApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets status to SUSPENDED for the specified OAuth application."""

    @abc.abstractmethod
    def Reactivate(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ReactivateApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets status to ACTIVE for the specified OAuth application."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.DeleteApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified OAuth application."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsResponse]]:
        """Lists operations for the specified OAuth application."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists access bindings for the specified OAuth application."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified OAuth application."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified OAuth application."""

    @abc.abstractmethod
    def ListAssignments(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsResponse]]:
        """Lists assignmnents for the specified OAuth application."""

    @abc.abstractmethod
    def UpdateAssignments(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateAssignmentsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates assignmnents for the specified OAuth application."""

def add_ApplicationServiceServicer_to_server(servicer: ApplicationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
