# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/devtools/ycvc/v1/control_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/devtools/ycvc/v1/control_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/devtools/ycvc/v1/control_service.proto\x12\x1dyandex.cloud.devtools.ycvc.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"=\n\x0bInitRequest\x12\x17\n\ttool_name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"\x97\x01\n\x0cInitResponse\x12[\n\x13\x64\x65precation_warning\x18\x01 \x01(\x0b\x32>.yandex.cloud.devtools.ycvc.v1.InitResponse.DeprecationWarning\x1a*\n\x12\x44\x65precationWarning\x12\x14\n\x06reason\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xaf\x01\n\x15VersionControlService\x12\x95\x01\n\x04Init\x12*.yandex.cloud.devtools.ycvc.v1.InitRequest\x1a+.yandex.cloud.devtools.ycvc.v1.InitResponse\"4\x82\xd3\xe4\x93\x02.\")/v1/obsolete_collections/{tool_name}:init:\x01*B\x89\x01\n!yandex.cloud.api.devtools.ycvc.v1B\x1aVersionControlServiceProtoP\x01ZFgithub.com/yandex-cloud/go-genproto/yandex/cloud/devtools/ycvc/v1;ycvcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.devtools.ycvc.v1.control_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.devtools.ycvc.v1B\032VersionControlServiceProtoP\001ZFgithub.com/yandex-cloud/go-genproto/yandex/cloud/devtools/ycvc/v1;ycvc'
  _globals['_INITREQUEST'].fields_by_name['tool_name']._loaded_options = None
  _globals['_INITREQUEST'].fields_by_name['tool_name']._serialized_options = b'\350\3071\001'
  _globals['_INITREQUEST'].fields_by_name['version']._loaded_options = None
  _globals['_INITREQUEST'].fields_by_name['version']._serialized_options = b'\350\3071\001'
  _globals['_INITRESPONSE_DEPRECATIONWARNING'].fields_by_name['reason']._loaded_options = None
  _globals['_INITRESPONSE_DEPRECATIONWARNING'].fields_by_name['reason']._serialized_options = b'\350\3071\001'
  _globals['_VERSIONCONTROLSERVICE'].methods_by_name['Init']._loaded_options = None
  _globals['_VERSIONCONTROLSERVICE'].methods_by_name['Init']._serialized_options = b'\202\323\344\223\002.\")/v1/obsolete_collections/{tool_name}:init:\001*'
  _globals['_INITREQUEST']._serialized_start=147
  _globals['_INITREQUEST']._serialized_end=208
  _globals['_INITRESPONSE']._serialized_start=211
  _globals['_INITRESPONSE']._serialized_end=362
  _globals['_INITRESPONSE_DEPRECATIONWARNING']._serialized_start=320
  _globals['_INITRESPONSE_DEPRECATIONWARNING']._serialized_end=362
  _globals['_VERSIONCONTROLSERVICE']._serialized_start=365
  _globals['_VERSIONCONTROLSERVICE']._serialized_end=540
# @@protoc_insertion_point(module_scope)
