"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry to create a lifecycle policy in."""
    name: builtins.str
    """Name of the lifecycle policy."""
    description: builtins.str
    """Description of the lifecycle policy. 0-1024 characters long."""
    state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType
    """Initial state of the lifecycle policy."""
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecycleRule]:
        """List of lifecycle rules."""

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        rules: collections.abc.Iterable[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecycleRule] | None = ...,
        state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "registry_id", b"registry_id", "rules", b"rules", "state", b"state"]) -> None: ...

global___CreateLifecyclePolicyRequest = CreateLifecyclePolicyRequest

@typing.final
class CreateLifecyclePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy that is being created."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___CreateLifecyclePolicyMetadata = CreateLifecyclePolicyMetadata

@typing.final
class UpdateLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy to update."""
    name: builtins.str
    """Name of the lifecycle policy."""
    description: builtins.str
    """Description of the lifecycle policy. 0-1024 characters long."""
    state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType
    """State of the lifecycle policy."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the lifecycle policy are going to be updated."""

    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecycleRule]:
        """List of lifecycle rules."""

    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        rules: collections.abc.Iterable[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecycleRule] | None = ...,
        state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "policy_id", b"policy_id", "rules", b"rules", "state", b"state", "update_mask", b"update_mask"]) -> None: ...

global___UpdateLifecyclePolicyRequest = UpdateLifecyclePolicyRequest

@typing.final
class UpdateLifecyclePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy that is being updated."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___UpdateLifecyclePolicyMetadata = UpdateLifecyclePolicyMetadata

@typing.final
class DeleteLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy to delete."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___DeleteLifecyclePolicyRequest = DeleteLifecyclePolicyRequest

@typing.final
class DeleteLifecyclePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy that is being deleted."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___DeleteLifecyclePolicyMetadata = DeleteLifecyclePolicyMetadata

@typing.final
class GetLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy to return."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___GetLifecyclePolicyRequest = GetLifecyclePolicyRequest

@typing.final
class ListLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry to list lifecycle policies in."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    page_token: builtins.str
    """Page token. To get the next page of results, set page_token to the
    ListLifecyclePolicyResponse.next_page_token returned by a previous list request.
    """
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "registry_id", b"registry_id"]) -> None: ...

global___ListLifecyclePolicyRequest = ListLifecyclePolicyRequest

@typing.final
class ListLifecyclePolicyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests."""
    @property
    def policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicy]:
        """List of lifecycle policy resources."""

    def __init__(
        self,
        *,
        policies: collections.abc.Iterable[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicy] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "policies", b"policies"]) -> None: ...

global___ListLifecyclePolicyResponse = ListLifecyclePolicyResponse

@typing.final
class ChangeLifecyclePolicyStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy to change state."""
    state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType
    """Target state of the lifecycle policy."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id", "state", b"state"]) -> None: ...

global___ChangeLifecyclePolicyStateRequest = ChangeLifecyclePolicyStateRequest
