"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.resourcemanager.v1.folder_pb2
import yandex.cloud.resourcemanager.v1.folder_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class FolderServiceStub:
    """A set of methods for managing Folder resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.GetFolderRequest,
        yandex.cloud.resourcemanager.v1.folder_pb2.Folder,
    ]
    """Returns the specified Folder resource.

    To get the list of available Folder resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersRequest,
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersResponse,
    ]
    """Retrieves the list of Folder resources in the specified cloud."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.CreateFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a folder in the specified cloud."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.UpdateFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified folder."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.DeleteFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified folder."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsRequest,
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsResponse,
    ]
    """Lists operations for the specified folder."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the specified folder.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified folder."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified folder."""

    ListAccessPolicyBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessPolicyBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessPolicyBindingsResponse,
    ]
    """
    Access policies

    Returns list of access policy bindings for the folder.
    """

    BindAccessPolicy: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.BindAccessPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Binds the access policy template to the folder."""

    UnbindAccessPolicy: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UnbindAccessPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Unbinds the access policy template from the folder."""

    UpdateAccessPolicyBindingParameters: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessPolicyBindingParametersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the access policy binding parameters for the folder."""

class FolderServiceAsyncStub:
    """A set of methods for managing Folder resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.GetFolderRequest,
        yandex.cloud.resourcemanager.v1.folder_pb2.Folder,
    ]
    """Returns the specified Folder resource.

    To get the list of available Folder resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersRequest,
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersResponse,
    ]
    """Retrieves the list of Folder resources in the specified cloud."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.CreateFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a folder in the specified cloud."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.UpdateFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified folder."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.DeleteFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified folder."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsRequest,
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsResponse,
    ]
    """Lists operations for the specified folder."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the specified folder.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified folder."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified folder."""

    ListAccessPolicyBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessPolicyBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessPolicyBindingsResponse,
    ]
    """
    Access policies

    Returns list of access policy bindings for the folder.
    """

    BindAccessPolicy: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.BindAccessPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Binds the access policy template to the folder."""

    UnbindAccessPolicy: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UnbindAccessPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Unbinds the access policy template from the folder."""

    UpdateAccessPolicyBindingParameters: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessPolicyBindingParametersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the access policy binding parameters for the folder."""

class FolderServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Folder resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.GetFolderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.resourcemanager.v1.folder_pb2.Folder, collections.abc.Awaitable[yandex.cloud.resourcemanager.v1.folder_pb2.Folder]]:
        """Returns the specified Folder resource.

        To get the list of available Folder resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersResponse, collections.abc.Awaitable[yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersResponse]]:
        """Retrieves the list of Folder resources in the specified cloud."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.CreateFolderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a folder in the specified cloud."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.UpdateFolderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified folder."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.DeleteFolderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified folder."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsResponse, collections.abc.Awaitable[yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsResponse]]:
        """Lists operations for the specified folder."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the specified folder.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified folder."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified folder."""

    @abc.abstractmethod
    def ListAccessPolicyBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessPolicyBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessPolicyBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessPolicyBindingsResponse]]:
        """
        Access policies

        Returns list of access policy bindings for the folder.
        """

    @abc.abstractmethod
    def BindAccessPolicy(
        self,
        request: yandex.cloud.access.access_pb2.BindAccessPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Binds the access policy template to the folder."""

    @abc.abstractmethod
    def UnbindAccessPolicy(
        self,
        request: yandex.cloud.access.access_pb2.UnbindAccessPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Unbinds the access policy template from the folder."""

    @abc.abstractmethod
    def UpdateAccessPolicyBindingParameters(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessPolicyBindingParametersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the access policy binding parameters for the folder."""

def add_FolderServiceServicer_to_server(servicer: FolderServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
